Module: Aws::CustomerProfiles

Defined in:
lib/aws-sdk-customerprofiles/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/params.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-customerprofiles/plugins/endpoints.rb,
lib/aws-sdk-customerprofiles/endpoint_provider.rb,
lib/aws-sdk-customerprofiles/client_api.rb,
lib/aws-sdk-customerprofiles/endpoints.rb,
lib/aws-sdk-customerprofiles/resource.rb,
lib/aws-sdk-customerprofiles/errors.rb,
lib/aws-sdk-customerprofiles/client.rb,
lib/aws-sdk-customerprofiles/types.rb,
lib/aws-sdk-customerprofiles.rb

Overview

This module provides support for Amazon Connect Customer Profiles. This module is available in the aws-sdk-customerprofiles gem.

Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

customer_profiles = Aws::CustomerProfiles::Client.new
resp = customer_profiles.add_profile_key(params)

See Client for more information.

Errors

Errors returned from Amazon Connect Customer Profiles are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::CustomerProfiles::Errors::ServiceError
  # rescues all Amazon Connect Customer Profiles API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Params, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.91.0'