Class: Aws::CustomerProfiles::Types::AssociateStreamForSegmentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_arnString

The Amazon Resource Name (ARN) of the Amazon Kinesis data stream to deliver segment membership events to. For example, arn:aws:kinesis:region:account-id:stream/stream-name.

Returns:

  • (String)


359
360
361
362
363
364
365
# File 'lib/aws-sdk-customerprofiles/types.rb', line 359

class AssociateStreamForSegmentsRequest < Struct.new(
  :domain_name,
  :destination_arn,
  :destination_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#destination_role_arnString

The Amazon Resource Name (ARN) of the IAM role that allows Customer Profiles service principal to assume the role for conducting AWS Key Management Service (KMS) and Amazon Kinesis operations. The role must grant the following Amazon Kinesis permissions to deliver segment membership events to the stream:

  • kinesis:PutRecord

  • kinesis:PutRecords

  • kinesis:DescribeStream

Returns:

  • (String)


359
360
361
362
363
364
365
# File 'lib/aws-sdk-customerprofiles/types.rb', line 359

class AssociateStreamForSegmentsRequest < Struct.new(
  :domain_name,
  :destination_arn,
  :destination_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


359
360
361
362
363
364
365
# File 'lib/aws-sdk-customerprofiles/types.rb', line 359

class AssociateStreamForSegmentsRequest < Struct.new(
  :domain_name,
  :destination_arn,
  :destination_role_arn)
  SENSITIVE = []
  include Aws::Structure
end