Class: Aws::CustomerProfiles::Types::AssociatedSegment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Represents a segment associated with a membership event stream.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

An optional message providing context, such as a failure reason.

Returns:

  • (String)


398
399
400
401
402
403
404
# File 'lib/aws-sdk-customerprofiles/types.rb', line 398

class AssociatedSegment < Struct.new(
  :segment_name,
  :status,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#segment_nameString

The unique name of the segment definition.

Returns:

  • (String)


398
399
400
401
402
403
404
# File 'lib/aws-sdk-customerprofiles/types.rb', line 398

class AssociatedSegment < Struct.new(
  :segment_name,
  :status,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The subscription status of the segment. The following are valid values:

  • STARTING: The segment is being prepared to publish membership events.

  • RUNNING: The segment is actively publishing membership events to the stream.

  • STOPPED: The segment has stopped publishing membership events.

  • FAILED: The segment failed to publish membership events.

Returns:

  • (String)


398
399
400
401
402
403
404
# File 'lib/aws-sdk-customerprofiles/types.rb', line 398

class AssociatedSegment < Struct.new(
  :segment_name,
  :status,
  :message)
  SENSITIVE = []
  include Aws::Structure
end