Class: Aws::CustomerProfiles::Types::AttributeDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::AttributeDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Mathematical expression and a list of attribute items specified in that expression.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Types::AttributeItem>
A list of attribute items specified in the mathematical expression.
-
#expression ⇒ String
Mathematical expression that is performed on attribute items provided in the attribute list.
Instance Attribute Details
#attributes ⇒ Array<Types::AttributeItem>
A list of attribute items specified in the mathematical expression.
422 423 424 425 426 427 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 422 class AttributeDetails < Struct.new( :attributes, :expression) SENSITIVE = [] include Aws::Structure end |
#expression ⇒ String
Mathematical expression that is performed on attribute items provided in the attribute list. Each element in the expression should follow the structure of \"ObjectTypeName.AttributeName\".
422 423 424 425 426 427 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 422 class AttributeDetails < Struct.new( :attributes, :expression) SENSITIVE = [] include Aws::Structure end |