Class: Aws::CustomerProfiles::Types::BatchGetCalculatedAttributeForProfileError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Error object describing why a specific profile and calculated attribute failed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code ⇒ String

Status code for why a specific profile and calculated attribute failed.

Returns:

  • (String)


655
656
657
658
659
660
661
# File 'lib/aws-sdk-customerprofiles/types.rb', line 655

class BatchGetCalculatedAttributeForProfileError < Struct.new(
  :code,
  :message,
  :profile_id)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

Message describing why a specific profile and calculated attribute failed.

Returns:

  • (String)


655
656
657
658
659
660
661
# File 'lib/aws-sdk-customerprofiles/types.rb', line 655

class BatchGetCalculatedAttributeForProfileError < Struct.new(
  :code,
  :message,
  :profile_id)
  SENSITIVE = []
  include Aws::Structure
end

#profile_id ⇒ String

The profile id that failed.

Returns:

  • (String)


655
656
657
658
659
660
661
# File 'lib/aws-sdk-customerprofiles/types.rb', line 655

class BatchGetCalculatedAttributeForProfileError < Struct.new(
  :code,
  :message,
  :profile_id)
  SENSITIVE = []
  include Aws::Structure
end