Class: Aws::CustomerProfiles::Types::BatchPutProfileObjectErrorItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

An item that failed to be added to the domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeInteger

The HTTP status code for the error.

Returns:

  • (Integer)


718
719
720
721
722
723
724
# File 'lib/aws-sdk-customerprofiles/types.rb', line 718

class BatchPutProfileObjectErrorItem < Struct.new(
  :id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the item in the batch request that failed.

Returns:

  • (String)


718
719
720
721
722
723
724
# File 'lib/aws-sdk-customerprofiles/types.rb', line 718

class BatchPutProfileObjectErrorItem < Struct.new(
  :id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message describing the error.

Returns:

  • (String)


718
719
720
721
722
723
724
# File 'lib/aws-sdk-customerprofiles/types.rb', line 718

class BatchPutProfileObjectErrorItem < Struct.new(
  :id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end