Class: Aws::CustomerProfiles::Types::BatchPutProfileObjectResponseItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

An item that was successfully added to the domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The unique identifier of the item in the batch request.

Returns:

  • (String)


798
799
800
801
802
803
# File 'lib/aws-sdk-customerprofiles/types.rb', line 798

class BatchPutProfileObjectResponseItem < Struct.new(
  :id,
  :profile_object_unique_key)
  SENSITIVE = []
  include Aws::Structure
end

#profile_object_unique_keyString

The unique identifier of the profile object generated by the service.

Returns:

  • (String)


798
799
800
801
802
803
# File 'lib/aws-sdk-customerprofiles/types.rb', line 798

class BatchPutProfileObjectResponseItem < Struct.new(
  :id,
  :profile_object_unique_key)
  SENSITIVE = []
  include Aws::Structure
end