Class: Aws::CustomerProfiles::Types::CalculatedAttributeValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::CalculatedAttributeValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
The object containing the values of a single calculated attribute value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#calculated_attribute_name ⇒ String
The unique name of the calculated attribute.
-
#display_name ⇒ String
The display name of the calculated attribute.
-
#is_data_partial ⇒ String
Indicates whether the calculated attribute's value is based on partial data.
-
#last_object_timestamp ⇒ Time
The timestamp of the newest object included in the calculated attribute calculation.
-
#profile_id ⇒ String
The profile id belonging to this calculated attribute value.
-
#value ⇒ String
The value of the calculated attribute.
Instance Attribute Details
#calculated_attribute_name ⇒ String
The unique name of the calculated attribute.
940 941 942 943 944 945 946 947 948 949 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 940 class CalculatedAttributeValue < Struct.new( :calculated_attribute_name, :display_name, :is_data_partial, :profile_id, :value, :last_object_timestamp) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the calculated attribute.
940 941 942 943 944 945 946 947 948 949 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 940 class CalculatedAttributeValue < Struct.new( :calculated_attribute_name, :display_name, :is_data_partial, :profile_id, :value, :last_object_timestamp) SENSITIVE = [] include Aws::Structure end |
#is_data_partial ⇒ String
Indicates whether the calculated attribute's value is based on partial data. If the data is partial, it is set to true.
940 941 942 943 944 945 946 947 948 949 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 940 class CalculatedAttributeValue < Struct.new( :calculated_attribute_name, :display_name, :is_data_partial, :profile_id, :value, :last_object_timestamp) SENSITIVE = [] include Aws::Structure end |
#last_object_timestamp ⇒ Time
The timestamp of the newest object included in the calculated attribute calculation.
940 941 942 943 944 945 946 947 948 949 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 940 class CalculatedAttributeValue < Struct.new( :calculated_attribute_name, :display_name, :is_data_partial, :profile_id, :value, :last_object_timestamp) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The profile id belonging to this calculated attribute value.
940 941 942 943 944 945 946 947 948 949 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 940 class CalculatedAttributeValue < Struct.new( :calculated_attribute_name, :display_name, :is_data_partial, :profile_id, :value, :last_object_timestamp) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of the calculated attribute.
940 941 942 943 944 945 946 947 948 949 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 940 class CalculatedAttributeValue < Struct.new( :calculated_attribute_name, :display_name, :is_data_partial, :profile_id, :value, :last_object_timestamp) SENSITIVE = [] include Aws::Structure end |