Class: Aws::CustomerProfiles::Types::CatalogItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Represents an item in the catalog with its complete set of attributes and metadata.

Constant Summary collapse

SENSITIVE =
[:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_information ⇒ String

Supplementary information about the catalog item beyond the basic description.

Returns:

  • (String)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

#attributes ⇒ Hash<String,String>

Additional attributes or properties associated with the catalog item stored as key-value pairs.

Returns:

  • (Hash<String,String>)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

#category ⇒ String

The category to which the catalog item belongs.

Returns:

  • (String)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

#code ⇒ String

The product code or SKU of the catalog item.

Returns:

  • (String)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp when the catalog item was created.

Returns:

  • (Time)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

#description ⇒ String

A detailed description of the catalog item.

Returns:

  • (String)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

#id ⇒ String

The unique identifier for the catalog item.

Returns:

  • (String)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

The URL link to the item's image.

Returns:

  • (String)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

The URL link to the item's detailed page or external resource.

Returns:

  • (String)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

#name ⇒ String

The display name of the catalog item.

Returns:

  • (String)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

#price ⇒ String

The price of the catalog item.

Returns:

  • (String)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

#type ⇒ String

The type classification of the catalog item.

Returns:

  • (String)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end

#updated_at ⇒ Time

The timestamp when the catalog item was last updated.

Returns:

  • (Time)


1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1010

class CatalogItem < Struct.new(
  :id,
  :name,
  :code,
  :type,
  :category,
  :description,
  :additional_information,
  :image_link,
  :link,
  :created_at,
  :updated_at,
  :price,
  :attributes)
  SENSITIVE = [:id, :name, :code, :type, :category, :description, :additional_information, :image_link, :link, :price, :attributes]
  include Aws::Structure
end