Class: Aws::CustomerProfiles::Types::Conditions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The conditions including range, object count, and threshold for the calculated attribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#object_count ⇒ Integer

The number of profile objects used for the calculated attribute.

Returns:

  • (Integer)


1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1062

class Conditions < Struct.new(
  :range,
  :object_count,
  :threshold)
  SENSITIVE = []
  include Aws::Structure
end

#range ⇒ Types::Range

The relative time period over which data is included in the aggregation.

Returns:



1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1062

class Conditions < Struct.new(
  :range,
  :object_count,
  :threshold)
  SENSITIVE = []
  include Aws::Structure
end

#threshold ⇒ Types::Threshold

The threshold for the calculated attribute.

Returns:



1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1062

class Conditions < Struct.new(
  :range,
  :object_count,
  :threshold)
  SENSITIVE = []
  include Aws::Structure
end