Class: Aws::CustomerProfiles::Types::ConnectorOperator
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ConnectorOperator
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
The operation to be performed on the provided source fields.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marketo ⇒ String
The operation to be performed on the provided Marketo source fields.
-
#s3 ⇒ String
The operation to be performed on the provided Amazon S3 source fields.
-
#salesforce ⇒ String
The operation to be performed on the provided Salesforce source fields.
-
#service_now ⇒ String
The operation to be performed on the provided ServiceNow source fields.
-
#zendesk ⇒ String
The operation to be performed on the provided Zendesk source fields.
Instance Attribute Details
#marketo ⇒ String
The operation to be performed on the provided Marketo source fields.
1126 1127 1128 1129 1130 1131 1132 1133 1134 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1126 class ConnectorOperator < Struct.new( :marketo, :s3, :salesforce, :service_now, :zendesk) SENSITIVE = [] include Aws::Structure end |
#s3 ⇒ String
The operation to be performed on the provided Amazon S3 source fields.
1126 1127 1128 1129 1130 1131 1132 1133 1134 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1126 class ConnectorOperator < Struct.new( :marketo, :s3, :salesforce, :service_now, :zendesk) SENSITIVE = [] include Aws::Structure end |
#salesforce ⇒ String
The operation to be performed on the provided Salesforce source fields.
1126 1127 1128 1129 1130 1131 1132 1133 1134 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1126 class ConnectorOperator < Struct.new( :marketo, :s3, :salesforce, :service_now, :zendesk) SENSITIVE = [] include Aws::Structure end |
#service_now ⇒ String
The operation to be performed on the provided ServiceNow source fields.
1126 1127 1128 1129 1130 1131 1132 1133 1134 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1126 class ConnectorOperator < Struct.new( :marketo, :s3, :salesforce, :service_now, :zendesk) SENSITIVE = [] include Aws::Structure end |
#zendesk ⇒ String
The operation to be performed on the provided Zendesk source fields.
1126 1127 1128 1129 1130 1131 1132 1133 1134 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1126 class ConnectorOperator < Struct.new( :marketo, :s3, :salesforce, :service_now, :zendesk) SENSITIVE = [] include Aws::Structure end |