Class: Aws::CustomerProfiles::Types::CreateCalculatedAttributeDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::CreateCalculatedAttributeDefinitionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :attribute_details, :conditions, :statistic]
Instance Attribute Summary collapse
-
#attribute_details ⇒ Types::AttributeDetails
Mathematical expression and a list of attribute items specified in that expression.
-
#calculated_attribute_name ⇒ String
The unique name of the calculated attribute.
-
#conditions ⇒ Types::Conditions
The conditions including range, object count, and threshold for the calculated attribute.
-
#created_at ⇒ Time
The timestamp of when the calculated attribute definition was created.
-
#description ⇒ String
The description of the calculated attribute.
-
#display_name ⇒ String
The display name of the calculated attribute.
-
#filter ⇒ Types::Filter
The filter that was used as part of the request.
-
#last_updated_at ⇒ Time
The timestamp of when the calculated attribute definition was most recently edited.
-
#readiness ⇒ Types::Readiness
Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.
-
#statistic ⇒ String
The aggregation operation to perform for the calculated attribute.
-
#status ⇒ String
Status of the Calculated Attribute creation (whether all historical data has been indexed.).
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#use_historical_data ⇒ Boolean
Whether historical data ingested before the Calculated Attribute was created should be included in calculations.
Instance Attribute Details
#attribute_details ⇒ Types::AttributeDetails
Mathematical expression and a list of attribute items specified in that expression.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#calculated_attribute_name ⇒ String
The unique name of the calculated attribute.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#conditions ⇒ Types::Conditions
The conditions including range, object count, and threshold for the calculated attribute.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the calculated attribute definition was created.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#description ⇒ String
The description of the calculated attribute.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#display_name ⇒ String
The display name of the calculated attribute.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#filter ⇒ Types::Filter
The filter that was used as part of the request.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the calculated attribute definition was most recently edited.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#readiness ⇒ Types::Readiness
Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#statistic ⇒ String
The aggregation operation to perform for the calculated attribute.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#status ⇒ String
Status of the Calculated Attribute creation (whether all historical data has been indexed.)
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |
#use_historical_data ⇒ Boolean
Whether historical data ingested before the Calculated Attribute was created should be included in calculations.
1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1225 class CreateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :attribute_details, :conditions, :filter, :statistic, :created_at, :last_updated_at, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :attribute_details, :conditions, :statistic] include Aws::Structure end |