Class: Aws::CustomerProfiles::Types::CreateDomainLayoutRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :layout]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the layout

Returns:

  • (String)


1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1362

class CreateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#display_nameString

The display name of the layout

Returns:

  • (String)


1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1362

class CreateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1362

class CreateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#is_defaultBoolean

If set to true for a layout, this layout will be used by default to view data. If set to false, then the layout will not be used by default, but it can be used to view data by explicitly selecting it in the console.

Returns:

  • (Boolean)


1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1362

class CreateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#layoutString

A customizable layout that can be used to view data under a Customer Profiles domain.

Returns:

  • (String)


1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1362

class CreateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#layout_definition_nameString

The unique name of the layout.

Returns:

  • (String)


1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1362

class CreateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#layout_typeString

The type of layout that can be used to view data under a Customer Profiles domain.

Returns:

  • (String)


1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1362

class CreateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1362

class CreateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end