Class: Aws::CustomerProfiles::Types::CreateDomainResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::CreateDomainResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the domain was created.
-
#data_store ⇒ Types::DataStoreResponse
The data store.
-
#dead_letter_queue_url ⇒ String
The URL of the SQS dead letter queue, which is used for reporting errors associated with ingesting data from third party applications.
-
#default_encryption_key ⇒ String
The default encryption key, which is an AWS managed key, is used when no specific type of encryption key is specified.
-
#default_expiration_days ⇒ Integer
The default number of days until the data within the domain expires.
-
#domain_name ⇒ String
The unique name of the domain.
-
#last_updated_at ⇒ Time
The timestamp of when the domain was most recently edited.
-
#matching ⇒ Types::MatchingResponse
The process of matching duplicate profiles.
-
#rule_based_matching ⇒ Types::RuleBasedMatchingResponse
The process of matching duplicate profiles using the Rule-Based matching.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the domain was created.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1398 class CreateDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#data_store ⇒ Types::DataStoreResponse
The data store.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1398 class CreateDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#dead_letter_queue_url ⇒ String
The URL of the SQS dead letter queue, which is used for reporting errors associated with ingesting data from third party applications.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1398 class CreateDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#default_encryption_key ⇒ String
The default encryption key, which is an AWS managed key, is used when no specific type of encryption key is specified. It is used to encrypt all data before it is placed in permanent or semi-permanent storage.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1398 class CreateDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#default_expiration_days ⇒ Integer
The default number of days until the data within the domain expires.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1398 class CreateDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1398 class CreateDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the domain was most recently edited.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1398 class CreateDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#matching ⇒ Types::MatchingResponse
The process of matching duplicate profiles. If ‘Matching` = `true`, Amazon Connect Customer Profiles starts a weekly batch process called Identity Resolution Job. If you do not specify a date and time for Identity Resolution Job to run, by default it runs every Saturday at 12AM UTC to detect duplicate profiles in your domains.
After the Identity Resolution Job completes, use the [GetMatches] API to return and review the results. Or, if you have configured ‘ExportingConfig` in the `MatchingRequest`, you can download the results from S3.
[1]: docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetMatches.html
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1398 class CreateDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#rule_based_matching ⇒ Types::RuleBasedMatchingResponse
The process of matching duplicate profiles using the Rule-Based matching. If ‘RuleBasedMatching` = true, Amazon Connect Customer Profiles will start to match and merge your profiles according to your configuration in the `RuleBasedMatchingRequest`. You can use the `ListRuleBasedMatches` and `GetSimilarProfiles` API to return and review the results. Also, if you have configured `ExportingConfig` in the `RuleBasedMatchingRequest`, you can download the results from S3.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1398 class CreateDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1398 class CreateDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |