Class: Aws::CustomerProfiles::Types::CreateEventStreamRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::CreateEventStreamRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#event_stream_name ⇒ String
The name of the event stream.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#uri ⇒ String
The StreamARN of the destination to deliver profile events to.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
1536 1537 1538 1539 1540 1541 1542 1543 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1536 class CreateEventStreamRequest < Struct.new( :domain_name, :uri, :event_stream_name, :tags) SENSITIVE = [] include Aws::Structure end |
#event_stream_name ⇒ String
The name of the event stream.
1536 1537 1538 1539 1540 1541 1542 1543 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1536 class CreateEventStreamRequest < Struct.new( :domain_name, :uri, :event_stream_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
1536 1537 1538 1539 1540 1541 1542 1543 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1536 class CreateEventStreamRequest < Struct.new( :domain_name, :uri, :event_stream_name, :tags) SENSITIVE = [] include Aws::Structure end |
#uri ⇒ String
The StreamARN of the destination to deliver profile events to. For example, arn:aws:kinesis:region:account-id:stream/stream-name
1536 1537 1538 1539 1540 1541 1542 1543 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1536 class CreateEventStreamRequest < Struct.new( :domain_name, :uri, :event_stream_name, :tags) SENSITIVE = [] include Aws::Structure end |