Class: Aws::CustomerProfiles::Types::CreateEventTriggerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::CreateEventTriggerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :event_trigger_conditions]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the event trigger.
-
#domain_name ⇒ String
The unique name of the domain.
-
#event_trigger_conditions ⇒ Array<Types::EventTriggerCondition>
A list of conditions that determine when an event should trigger the destination.
-
#event_trigger_limits ⇒ Types::EventTriggerLimits
Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.
-
#event_trigger_name ⇒ String
The unique name of the event trigger.
-
#object_type_name ⇒ String
The unique name of the object type.
-
#segment_filter ⇒ String
The destination is triggered only for profiles that meet the criteria of a segment definition.
-
#tags ⇒ Hash<String,String>
An array of key-value pairs to apply to this resource.
Instance Attribute Details
#description ⇒ String
The description of the event trigger.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1680 class CreateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1680 class CreateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#event_trigger_conditions ⇒ Array<Types::EventTriggerCondition>
A list of conditions that determine when an event should trigger the destination.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1680 class CreateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#event_trigger_limits ⇒ Types::EventTriggerLimits
Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1680 class CreateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#event_trigger_name ⇒ String
The unique name of the event trigger.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1680 class CreateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#object_type_name ⇒ String
The unique name of the object type.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1680 class CreateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#segment_filter ⇒ String
The destination is triggered only for profiles that meet the criteria of a segment definition.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1680 class CreateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An array of key-value pairs to apply to this resource.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1680 class CreateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |