Class: Aws::CustomerProfiles::Types::CreateIntegrationWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::CreateIntegrationWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#integration_config ⇒ Types::IntegrationConfig
Configuration data for integration workflow.
-
#object_type_name ⇒ String
The name of the profile object type.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#workflow_type ⇒ String
The type of workflow.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1700 class CreateIntegrationWorkflowRequest < Struct.new( :domain_name, :workflow_type, :integration_config, :object_type_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#integration_config ⇒ Types::IntegrationConfig
Configuration data for integration workflow.
1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1700 class CreateIntegrationWorkflowRequest < Struct.new( :domain_name, :workflow_type, :integration_config, :object_type_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#object_type_name ⇒ String
The name of the profile object type.
1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1700 class CreateIntegrationWorkflowRequest < Struct.new( :domain_name, :workflow_type, :integration_config, :object_type_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. Customer Profiles assumes this role to create resources on your behalf as part of workflow execution.
1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1700 class CreateIntegrationWorkflowRequest < Struct.new( :domain_name, :workflow_type, :integration_config, :object_type_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1700 class CreateIntegrationWorkflowRequest < Struct.new( :domain_name, :workflow_type, :integration_config, :object_type_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#workflow_type ⇒ String
The type of workflow. The only supported value is APPFLOW_INTEGRATION.
1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1700 class CreateIntegrationWorkflowRequest < Struct.new( :domain_name, :workflow_type, :integration_config, :object_type_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |