Class: Aws::CustomerProfiles::Types::CreateRecommenderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the domain object type.

Returns:

  • (String)


2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2051

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2051

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_configTypes::RecommenderConfig

The recommender configuration.



2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2051

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_nameString

The name of the recommender.

Returns:

  • (String)


2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2051

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_recipe_nameString

The name of the recommeder recipe.

Returns:

  • (String)


2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2051

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_schema_nameString

The name of the recommender schema to use for this recommender. If not specified, the default schema is used.

Returns:

  • (String)


2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2051

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2051

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end