Class: Aws::CustomerProfiles::Types::CreateRecommenderSchemaRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


1921
1922
1923
1924
1925
1926
1927
1928
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1921

class CreateRecommenderSchemaRequest < Struct.new(
  :domain_name,
  :recommender_schema_name,
  :fields,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#fieldsHash<String,Array<Types::RecommenderSchemaField>>

A map of dataset type to column definitions that specifies which data columns to include in the schema. Currently only the ‘_webAnalytics` key is supported.

Returns:



1921
1922
1923
1924
1925
1926
1927
1928
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1921

class CreateRecommenderSchemaRequest < Struct.new(
  :domain_name,
  :recommender_schema_name,
  :fields,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#recommender_schema_nameString

The name of the recommender schema. The name must be unique within the domain.

Returns:

  • (String)


1921
1922
1923
1924
1925
1926
1927
1928
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1921

class CreateRecommenderSchemaRequest < Struct.new(
  :domain_name,
  :recommender_schema_name,
  :fields,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


1921
1922
1923
1924
1925
1926
1927
1928
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1921

class CreateRecommenderSchemaRequest < Struct.new(
  :domain_name,
  :recommender_schema_name,
  :fields,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end