Class: Aws::CustomerProfiles::Types::CreateRecommenderSchemaResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::CreateRecommenderSchemaResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the recommender schema was created.
-
#fields ⇒ Hash<String,Array<Types::RecommenderSchemaField>>
A map of dataset type to column definitions included in the schema.
-
#recommender_schema_arn ⇒ String
The Amazon Resource Name (ARN) of the recommender schema.
-
#recommender_schema_name ⇒ String
The name of the recommender schema.
-
#status ⇒ String
The status of the recommender schema.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the recommender schema was created.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2139 class CreateRecommenderSchemaResponse < Struct.new( :recommender_schema_arn, :recommender_schema_name, :fields, :created_at, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#fields ⇒ Hash<String,Array<Types::RecommenderSchemaField>>
A map of dataset type to column definitions included in the schema.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2139 class CreateRecommenderSchemaResponse < Struct.new( :recommender_schema_arn, :recommender_schema_name, :fields, :created_at, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#recommender_schema_arn ⇒ String
The Amazon Resource Name (ARN) of the recommender schema.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2139 class CreateRecommenderSchemaResponse < Struct.new( :recommender_schema_arn, :recommender_schema_name, :fields, :created_at, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#recommender_schema_name ⇒ String
The name of the recommender schema.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2139 class CreateRecommenderSchemaResponse < Struct.new( :recommender_schema_arn, :recommender_schema_name, :fields, :created_at, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the recommender schema.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2139 class CreateRecommenderSchemaResponse < Struct.new( :recommender_schema_arn, :recommender_schema_name, :fields, :created_at, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2139 class CreateRecommenderSchemaResponse < Struct.new( :recommender_schema_arn, :recommender_schema_name, :fields, :created_at, :status, :tags) SENSITIVE = [] include Aws::Structure end |