Class: Aws::CustomerProfiles::Types::CreateSegmentDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :segment_groups, :segment_sql_query, :segment_sort]

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ String

The description of the segment definition.

Returns:

  • (String)


2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2186

class CreateSegmentDefinitionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :display_name,
  :description,
  :segment_groups,
  :segment_sql_query,
  :segment_sort,
  :tags)
  SENSITIVE = [:description, :segment_groups, :segment_sql_query, :segment_sort]
  include Aws::Structure
end

#display_name ⇒ String

The display name of the segment definition.

Returns:

  • (String)


2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2186

class CreateSegmentDefinitionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :display_name,
  :description,
  :segment_groups,
  :segment_sql_query,
  :segment_sort,
  :tags)
  SENSITIVE = [:description, :segment_groups, :segment_sql_query, :segment_sort]
  include Aws::Structure
end

#domain_name ⇒ String

The unique name of the domain.

Returns:

  • (String)


2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2186

class CreateSegmentDefinitionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :display_name,
  :description,
  :segment_groups,
  :segment_sql_query,
  :segment_sort,
  :tags)
  SENSITIVE = [:description, :segment_groups, :segment_sql_query, :segment_sort]
  include Aws::Structure
end

#segment_definition_name ⇒ String

The unique name of the segment definition.

Returns:

  • (String)


2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2186

class CreateSegmentDefinitionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :display_name,
  :description,
  :segment_groups,
  :segment_sql_query,
  :segment_sort,
  :tags)
  SENSITIVE = [:description, :segment_groups, :segment_sql_query, :segment_sort]
  include Aws::Structure
end

#segment_groups ⇒ Types::SegmentGroup

Specifies the base segments and dimensions for a segment definition along with their respective relationship.

Returns:



2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2186

class CreateSegmentDefinitionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :display_name,
  :description,
  :segment_groups,
  :segment_sql_query,
  :segment_sort,
  :tags)
  SENSITIVE = [:description, :segment_groups, :segment_sql_query, :segment_sort]
  include Aws::Structure
end

#segment_sort ⇒ Types::SegmentSort

The segment sort.

Returns:



2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2186

class CreateSegmentDefinitionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :display_name,
  :description,
  :segment_groups,
  :segment_sql_query,
  :segment_sort,
  :tags)
  SENSITIVE = [:description, :segment_groups, :segment_sql_query, :segment_sort]
  include Aws::Structure
end

#segment_sql_query ⇒ String

The segment SQL query.

Returns:

  • (String)


2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2186

class CreateSegmentDefinitionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :display_name,
  :description,
  :segment_groups,
  :segment_sql_query,
  :segment_sort,
  :tags)
  SENSITIVE = [:description, :segment_groups, :segment_sql_query, :segment_sort]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2186

class CreateSegmentDefinitionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :display_name,
  :description,
  :segment_groups,
  :segment_sql_query,
  :segment_sort,
  :tags)
  SENSITIVE = [:description, :segment_groups, :segment_sql_query, :segment_sort]
  include Aws::Structure
end