Class: Aws::CustomerProfiles::Types::CreateSegmentSnapshotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_format ⇒ String

The format in which the segment will be exported.



2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2314

class CreateSegmentSnapshotRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :data_format,
  :encryption_key,
  :role_arn,
  :destination_uri)
  SENSITIVE = []
  include Aws::Structure
end

#destination_uri ⇒ String

The destination to which the segment will be exported. This field must be provided if the request is not submitted from the Connect Customer Admin Website.



2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2314

class CreateSegmentSnapshotRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :data_format,
  :encryption_key,
  :role_arn,
  :destination_uri)
  SENSITIVE = []
  include Aws::Structure
end

#domain_name ⇒ String

The unique name of the domain.



2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2314

class CreateSegmentSnapshotRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :data_format,
  :encryption_key,
  :role_arn,
  :destination_uri)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key ⇒ String

The Amazon Resource Name (ARN) of the KMS key used to encrypt the exported segment.



2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2314

class CreateSegmentSnapshotRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :data_format,
  :encryption_key,
  :role_arn,
  :destination_uri)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The Amazon Resource Name (ARN) of the IAM role that allows Customer Profiles service principal to assume the role for conducting KMS and S3 operations.



2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2314

class CreateSegmentSnapshotRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :data_format,
  :encryption_key,
  :role_arn,
  :destination_uri)
  SENSITIVE = []
  include Aws::Structure
end

#segment_definition_name ⇒ String

The name of the segment definition used in this snapshot request.



2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2314

class CreateSegmentSnapshotRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :data_format,
  :encryption_key,
  :role_arn,
  :destination_uri)
  SENSITIVE = []
  include Aws::Structure
end