Class: Aws::CustomerProfiles::Types::DataStoreResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The data store response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

True if data store is enabled for this domain

Returns:

  • (Boolean)


2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2334

class DataStoreResponse < Struct.new(
  :enabled,
  :readiness)
  SENSITIVE = []
  include Aws::Structure
end

#readinessTypes::Readiness

Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.

Returns:



2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2334

class DataStoreResponse < Struct.new(
  :enabled,
  :readiness)
  SENSITIVE = []
  include Aws::Structure
end