Class: Aws::CustomerProfiles::Types::DestinationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Summary information about the Kinesis data stream

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#status ⇒ String

The status of enabling the Kinesis stream as a destination for export.

Returns:



2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2922

class DestinationSummary < Struct.new(
  :uri,
  :status,
  :unhealthy_since)
  SENSITIVE = []
  include Aws::Structure
end

#unhealthy_since ⇒ Time

The timestamp when the status last changed to UNHEALHY.

Returns:



2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2922

class DestinationSummary < Struct.new(
  :uri,
  :status,
  :unhealthy_since)
  SENSITIVE = []
  include Aws::Structure
end

#uri ⇒ String

The StreamARN of the destination to deliver profile events to. For example, arn:aws:kinesis:region:account-id:stream/stream-name.

Returns:



2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2922

class DestinationSummary < Struct.new(
  :uri,
  :status,
  :unhealthy_since)
  SENSITIVE = []
  include Aws::Structure
end