Class: Aws::CustomerProfiles::Types::DisassociateStreamForSegmentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::DisassociateStreamForSegmentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A confirmation message indicating the stream was disassociated successfully.
Instance Attribute Details
#message ⇒ String
A confirmation message indicating the stream was disassociated successfully.
3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3034 class DisassociateStreamForSegmentsResponse < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |