Class: Aws::CustomerProfiles::Types::DiversityColumn

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Defines a diversity constraint for a single item column, specifying a cap type and a target value or placeholder that controls how many recommended items may share the same column value.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cap_type ⇒ String

The type of diversity cap to apply. Valid values are PERCENTAGE (interpret Target as a percentage of returned items) and VALUE (interpret Target as an absolute count).

Returns:

  • (String)


3063
3064
3065
3066
3067
3068
3069
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3063

class DiversityColumn < Struct.new(
  :name,
  :cap_type,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the item catalog column on which to apply the diversity cap. The column must be defined in the recommender schema.

Returns:

  • (String)


3063
3064
3065
3066
3067
3068
3069
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3063

class DiversityColumn < Struct.new(
  :name,
  :cap_type,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#target ⇒ String

The diversity cap target. Either an integer literal (for example, "25") or a placeholder expression of the form $name whose value is supplied at inference time through GetProfileRecommendations.

Returns:

  • (String)


3063
3064
3065
3066
3067
3068
3069
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3063

class DiversityColumn < Struct.new(
  :name,
  :cap_type,
  :target)
  SENSITIVE = []
  include Aws::Structure
end