Class: Aws::CustomerProfiles::Types::DomainObjectTypesListItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Represents an item in the list of domain object types, containing basic information about a specific object type within a domain.

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

The timestamp of when the domain object type was created.

Returns:



3147
3148
3149
3150
3151
3152
3153
3154
3155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3147

class DomainObjectTypesListItem < Struct.new(
  :object_type_name,
  :description,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#description ⇒ String

A description explaining the purpose and characteristics of this object type.

Returns:



3147
3148
3149
3150
3151
3152
3153
3154
3155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3147

class DomainObjectTypesListItem < Struct.new(
  :object_type_name,
  :description,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#last_updated_at ⇒ Time

The timestamp of when the domain object type was most recently edited.

Returns:



3147
3148
3149
3150
3151
3152
3153
3154
3155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3147

class DomainObjectTypesListItem < Struct.new(
  :object_type_name,
  :description,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#object_type_name ⇒ String

The name that identifies the object type within the domain.

Returns:



3147
3148
3149
3150
3151
3152
3153
3154
3155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3147

class DomainObjectTypesListItem < Struct.new(
  :object_type_name,
  :description,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:



3147
3148
3149
3150
3151
3152
3153
3154
3155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3147

class DomainObjectTypesListItem < Struct.new(
  :object_type_name,
  :description,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end