Class: Aws::CustomerProfiles::Types::DomainStats
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::DomainStats
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Usage-specific statistics about the domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metering_profile_count ⇒ Integer
The number of profiles that you are currently paying for in the domain.
-
#object_count ⇒ Integer
The total number of objects in domain.
-
#profile_count ⇒ Integer
The total number of profiles currently in the domain.
-
#total_size ⇒ Integer
The total size, in bytes, of all objects in the domain.
Instance Attribute Details
#metering_profile_count ⇒ Integer
The number of profiles that you are currently paying for in the domain. If you have more than 100 objects associated with a single profile, that profile counts as two profiles. If you have more than 200 objects, that profile counts as three, and so on.
3180 3181 3182 3183 3184 3185 3186 3187 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3180 class DomainStats < Struct.new( :profile_count, :metering_profile_count, :object_count, :total_size) SENSITIVE = [] include Aws::Structure end |
#object_count ⇒ Integer
The total number of objects in domain.
3180 3181 3182 3183 3184 3185 3186 3187 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3180 class DomainStats < Struct.new( :profile_count, :metering_profile_count, :object_count, :total_size) SENSITIVE = [] include Aws::Structure end |
#profile_count ⇒ Integer
The total number of profiles currently in the domain.
3180 3181 3182 3183 3184 3185 3186 3187 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3180 class DomainStats < Struct.new( :profile_count, :metering_profile_count, :object_count, :total_size) SENSITIVE = [] include Aws::Structure end |
#total_size ⇒ Integer
The total size, in bytes, of all objects in the domain.
3180 3181 3182 3183 3184 3185 3186 3187 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3180 class DomainStats < Struct.new( :profile_count, :metering_profile_count, :object_count, :total_size) SENSITIVE = [] include Aws::Structure end |