Class: Aws::CustomerProfiles::Types::FieldSourceProfileIds
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::FieldSourceProfileIds
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
A duplicate customer profile that is to be merged into a main profile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_number ⇒ String
A unique identifier for the account number field to be merged.
-
#additional_information ⇒ String
A unique identifier for the additional information field to be merged.
-
#address ⇒ String
A unique identifier for the party type field to be merged.
-
#attributes ⇒ Hash<String,String>
A unique identifier for the attributes field to be merged.
-
#billing_address ⇒ String
A unique identifier for the billing type field to be merged.
-
#birth_date ⇒ String
A unique identifier for the birthdate field to be merged.
-
#business_email_address ⇒ String
A unique identifier for the party type field to be merged.
-
#business_name ⇒ String
A unique identifier for the business name field to be merged.
-
#business_phone_number ⇒ String
A unique identifier for the business phone number field to be merged.
-
#email_address ⇒ String
A unique identifier for the email address field to be merged.
-
#engagement_preferences ⇒ String
A unique identifier for the engagement preferences field to be merged.
-
#first_name ⇒ String
A unique identifier for the first name field to be merged.
-
#gender ⇒ String
A unique identifier for the gender field to be merged.
-
#home_phone_number ⇒ String
A unique identifier for the home phone number field to be merged.
-
#last_name ⇒ String
A unique identifier for the last name field to be merged.
-
#mailing_address ⇒ String
A unique identifier for the mailing address field to be merged.
-
#middle_name ⇒ String
A unique identifier for the middle name field to be merged.
-
#mobile_phone_number ⇒ String
A unique identifier for the mobile phone number field to be merged.
-
#party_type ⇒ String
A unique identifier for the party type field to be merged.
-
#personal_email_address ⇒ String
A unique identifier for the personal email address field to be merged.
-
#phone_number ⇒ String
A unique identifier for the phone number field to be merged.
-
#profile_type ⇒ String
A unique identifier for the profile type field to be merged.
-
#shipping_address ⇒ String
A unique identifier for the shipping address field to be merged.
Instance Attribute Details
#account_number ⇒ String
A unique identifier for the account number field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#additional_information ⇒ String
A unique identifier for the additional information field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#address ⇒ String
A unique identifier for the party type field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#attributes ⇒ Hash<String,String>
A unique identifier for the attributes field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#billing_address ⇒ String
A unique identifier for the billing type field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#birth_date ⇒ String
A unique identifier for the birthdate field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#business_email_address ⇒ String
A unique identifier for the party type field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#business_name ⇒ String
A unique identifier for the business name field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#business_phone_number ⇒ String
A unique identifier for the business phone number field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#email_address ⇒ String
A unique identifier for the email address field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#engagement_preferences ⇒ String
A unique identifier for the engagement preferences field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#first_name ⇒ String
A unique identifier for the first name field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#gender ⇒ String
A unique identifier for the gender field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#home_phone_number ⇒ String
A unique identifier for the home phone number field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#last_name ⇒ String
A unique identifier for the last name field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#mailing_address ⇒ String
A unique identifier for the mailing address field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#middle_name ⇒ String
A unique identifier for the middle name field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#mobile_phone_number ⇒ String
A unique identifier for the mobile phone number field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#party_type ⇒ String
A unique identifier for the party type field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#personal_email_address ⇒ String
A unique identifier for the personal email address field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#phone_number ⇒ String
A unique identifier for the phone number field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#profile_type ⇒ String
A unique identifier for the profile type field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |
#shipping_address ⇒ String
A unique identifier for the shipping address field to be merged.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3399 class FieldSourceProfileIds < Struct.new( :account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type, :engagement_preferences) SENSITIVE = [] include Aws::Structure end |