Class: Aws::CustomerProfiles::Types::FlowDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The configurations that control how Customer Profiles retrieves data from the source, Amazon AppFlow. Customer Profiles uses this information to create an AppFlow flow on behalf of customers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the flow you want to create.

Returns:

  • (String)


3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3535

class FlowDefinition < Struct.new(
  :description,
  :flow_name,
  :kms_arn,
  :source_flow_config,
  :tasks,
  :trigger_config)
  SENSITIVE = []
  include Aws::Structure
end

#flow_nameString

The specified name of the flow. Use underscores (_) or hyphens (-) only. Spaces are not allowed.

Returns:

  • (String)


3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3535

class FlowDefinition < Struct.new(
  :description,
  :flow_name,
  :kms_arn,
  :source_flow_config,
  :tasks,
  :trigger_config)
  SENSITIVE = []
  include Aws::Structure
end

#kms_arnString

The Amazon Resource Name of the AWS Key Management Service (KMS) key you provide for encryption.

Returns:

  • (String)


3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3535

class FlowDefinition < Struct.new(
  :description,
  :flow_name,
  :kms_arn,
  :source_flow_config,
  :tasks,
  :trigger_config)
  SENSITIVE = []
  include Aws::Structure
end

#source_flow_configTypes::SourceFlowConfig

The configuration that controls how Customer Profiles retrieves data from the source.



3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3535

class FlowDefinition < Struct.new(
  :description,
  :flow_name,
  :kms_arn,
  :source_flow_config,
  :tasks,
  :trigger_config)
  SENSITIVE = []
  include Aws::Structure
end

#tasksArray<Types::Task>

A list of tasks that Customer Profiles performs while transferring the data in the flow run.

Returns:



3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3535

class FlowDefinition < Struct.new(
  :description,
  :flow_name,
  :kms_arn,
  :source_flow_config,
  :tasks,
  :trigger_config)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_configTypes::TriggerConfig

The trigger settings that determine how and when the flow runs.



3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3535

class FlowDefinition < Struct.new(
  :description,
  :flow_name,
  :kms_arn,
  :source_flow_config,
  :tasks,
  :trigger_config)
  SENSITIVE = []
  include Aws::Structure
end