Class: Aws::CustomerProfiles::Types::GetCalculatedAttributeForProfileResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#calculated_attribute_nameString

The unique name of the calculated attribute.

Returns:

  • (String)


3960
3961
3962
3963
3964
3965
3966
3967
3968
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3960

class GetCalculatedAttributeForProfileResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :is_data_partial,
  :value,
  :last_object_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The display name of the calculated attribute.

Returns:

  • (String)


3960
3961
3962
3963
3964
3965
3966
3967
3968
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3960

class GetCalculatedAttributeForProfileResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :is_data_partial,
  :value,
  :last_object_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#is_data_partialString

Indicates whether the calculated attribute’s value is based on partial data. If data is partial, it is set to true.

Returns:

  • (String)


3960
3961
3962
3963
3964
3965
3966
3967
3968
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3960

class GetCalculatedAttributeForProfileResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :is_data_partial,
  :value,
  :last_object_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#last_object_timestampTime

The timestamp of the newest object included in the calculated attribute calculation.

Returns:

  • (Time)


3960
3961
3962
3963
3964
3965
3966
3967
3968
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3960

class GetCalculatedAttributeForProfileResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :is_data_partial,
  :value,
  :last_object_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the calculated attribute.

Returns:

  • (String)


3960
3961
3962
3963
3964
3965
3966
3967
3968
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3960

class GetCalculatedAttributeForProfileResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :is_data_partial,
  :value,
  :last_object_timestamp)
  SENSITIVE = []
  include Aws::Structure
end