Class: Aws::CustomerProfiles::Types::GetDomainResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetDomainResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the domain was created.
-
#data_store ⇒ Types::DataStoreResponse
True if data store is enabled for this domain.
-
#dead_letter_queue_url ⇒ String
The URL of the SQS dead letter queue, which is used for reporting errors associated with ingesting data from third party applications.
-
#default_encryption_key ⇒ String
The default encryption key, which is an AWS managed key, is used when no specific type of encryption key is specified.
-
#default_expiration_days ⇒ Integer
The default number of days until the data within the domain expires.
-
#domain_name ⇒ String
The unique name of the domain.
-
#last_updated_at ⇒ Time
The timestamp of when the domain was most recently edited.
-
#matching ⇒ Types::MatchingResponse
The process of matching duplicate profiles.
-
#rule_based_matching ⇒ Types::RuleBasedMatchingResponse
The process of matching duplicate profiles using the Rule-Based matching.
-
#stats ⇒ Types::DomainStats
Usage-specific statistics about the domain.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the domain was created.
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#data_store ⇒ Types::DataStoreResponse
True if data store is enabled for this domain.
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#dead_letter_queue_url ⇒ String
The URL of the SQS dead letter queue, which is used for reporting errors associated with ingesting data from third party applications.
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#default_encryption_key ⇒ String
The default encryption key, which is an AWS managed key, is used when no specific type of encryption key is specified. It is used to encrypt all data before it is placed in permanent or semi-permanent storage.
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#default_expiration_days ⇒ Integer
The default number of days until the data within the domain expires.
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the domain was most recently edited.
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#matching ⇒ Types::MatchingResponse
The process of matching duplicate profiles. If ‘Matching` = `true`, Amazon Connect Customer Profiles starts a weekly batch process called Identity Resolution Job. If you do not specify a date and time for Identity Resolution Job to run, by default it runs every Saturday at 12AM UTC to detect duplicate profiles in your domains.
After the Identity Resolution Job completes, use the [GetMatches] API to return and review the results. Or, if you have configured ‘ExportingConfig` in the `MatchingRequest`, you can download the results from S3.
[1]: docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetMatches.html
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#rule_based_matching ⇒ Types::RuleBasedMatchingResponse
The process of matching duplicate profiles using the Rule-Based matching. If ‘RuleBasedMatching` = true, Connect Customer Customer Profiles will start to match and merge your profiles according to your configuration in the `RuleBasedMatchingRequest`. You can use the `ListRuleBasedMatches` and `GetSimilarProfiles` API to return and review the results. Also, if you have configured `ExportingConfig` in the `RuleBasedMatchingRequest`, you can download the results from S3.
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#stats ⇒ Types::DomainStats
Usage-specific statistics about the domain.
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4008 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |