Class: Aws::CustomerProfiles::Types::GetIntegrationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the domain was created.

Returns:

  • (Time)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#event_trigger_namesArray<String>

A list of unique names for active event triggers associated with the integration. This list would be empty if no Event Trigger is associated with the integration.

Returns:

  • (Array<String>)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#is_unstructuredBoolean

Boolean that shows if the Flow that's associated with the Integration is created in Amazon Appflow, or with ObjectTypeName equals _unstructured via API/CLI in flowDefinition.

Returns:

  • (Boolean)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the domain was most recently edited.

Returns:

  • (Time)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#object_type_nameString

The name of the profile object type.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#object_type_namesHash<String,String>

A map in which each key is an event type from an external application such as Segment or Shopify, and each value is an ObjectTypeName (template) used to ingest the event. It supports the following event types: SegmentIdentify, ShopifyCreateCustomers, ShopifyUpdateCustomers, ShopifyCreateDraftOrders, ShopifyUpdateDraftOrders, ShopifyCreateOrders, and ShopifyUpdatedOrders.

Returns:

  • (Hash<String,String>)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role. The Integration uses this role to make Customer Profiles requests on your behalf.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether the integration applies to profile level data (associated with profiles) or domain level data (not associated with any specific profile). The default value is PROFILE.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#uriString

The URI of the S3 bucket or any other type of data source.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_idString

Unique identifier for the workflow.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4532

class GetIntegrationResponse < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end