Class: Aws::CustomerProfiles::Types::GetProfileObjectTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetProfileObjectTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :fields, :keys]
Instance Attribute Summary collapse
-
#allow_profile_creation ⇒ Boolean
Indicates whether a profile should be created when data is received if one doesn’t exist for an object of this type.
-
#created_at ⇒ Time
The timestamp of when the domain was created.
-
#description ⇒ String
The description of the profile object type.
-
#encryption_key ⇒ String
The customer-provided key to encrypt the profile object that will be created in this profile object type.
-
#expiration_days ⇒ Integer
The number of days until the data in the object expires.
-
#fields ⇒ Hash<String,Types::ObjectTypeField>
A map of the name and ObjectType field.
-
#keys ⇒ Hash<String,Array<Types::ObjectTypeKey>>
A list of unique keys that can be used to map data to the profile.
-
#last_updated_at ⇒ Time
The timestamp of when the domain was most recently edited.
-
#max_available_profile_object_count ⇒ Integer
The amount of provisioned profile object max count available.
-
#max_profile_object_count ⇒ Integer
The amount of profile object max count assigned to the object type.
-
#object_type_name ⇒ String
The name of the profile object type.
-
#source_last_updated_timestamp_format ⇒ String
The format of your ‘sourceLastUpdatedTimestamp` that was previously set up.
-
#source_priority ⇒ Integer
An integer that determines the priority of this object type when data from multiple sources is ingested.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#template_id ⇒ String
A unique identifier for the object template.
Instance Attribute Details
#allow_profile_creation ⇒ Boolean
Indicates whether a profile should be created when data is received if one doesn’t exist for an object of this type. The default is ‘FALSE`. If the AllowProfileCreation flag is set to `FALSE`, then the service tries to fetch a standard profile and associate this object with the profile. If it is set to `TRUE`, and if no match is found, then the service creates a new standard profile.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the domain was created.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#description ⇒ String
The description of the profile object type.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#encryption_key ⇒ String
The customer-provided key to encrypt the profile object that will be created in this profile object type.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#expiration_days ⇒ Integer
The number of days until the data in the object expires.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#fields ⇒ Hash<String,Types::ObjectTypeField>
A map of the name and ObjectType field.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#keys ⇒ Hash<String,Array<Types::ObjectTypeKey>>
A list of unique keys that can be used to map data to the profile.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the domain was most recently edited.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#max_available_profile_object_count ⇒ Integer
The amount of provisioned profile object max count available.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#max_profile_object_count ⇒ Integer
The amount of profile object max count assigned to the object type.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#object_type_name ⇒ String
The name of the profile object type.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#source_last_updated_timestamp_format ⇒ String
The format of your ‘sourceLastUpdatedTimestamp` that was previously set up.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#source_priority ⇒ Integer
An integer that determines the priority of this object type when data from multiple sources is ingested. Lower values take priority. Object types without a specified source priority default to the lowest priority.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#template_id ⇒ String
A unique identifier for the object template.
4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4583 class GetProfileObjectTypeResponse < Struct.new( :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_available_profile_object_count, :max_profile_object_count, :source_priority, :fields, :keys, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |