Class: Aws::CustomerProfiles::Types::GetProfileObjectTypeTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetProfileObjectTypeTemplateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:fields, :keys]
Instance Attribute Summary collapse
-
#allow_profile_creation ⇒ Boolean
Indicates whether a profile should be created when data is received if one doesn’t exist for an object of this type.
-
#fields ⇒ Hash<String,Types::ObjectTypeField>
A map of the name and ObjectType field.
-
#keys ⇒ Hash<String,Array<Types::ObjectTypeKey>>
A list of unique keys that can be used to map data to the profile.
-
#source_last_updated_timestamp_format ⇒ String
The format of your
sourceLastUpdatedTimestampthat was previously set up. -
#source_name ⇒ String
The name of the source of the object template.
-
#source_object ⇒ String
The source of the object template.
-
#template_id ⇒ String
A unique identifier for the object template.
Instance Attribute Details
#allow_profile_creation ⇒ Boolean
Indicates whether a profile should be created when data is received
if one doesn’t exist for an object of this type. The default is
FALSE. If the AllowProfileCreation flag is set to FALSE, then
the service tries to fetch a standard profile and associate this
object with the profile. If it is set to TRUE, and if no match is
found, then the service creates a new standard profile.
4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4942 class GetProfileObjectTypeTemplateResponse < Struct.new( :template_id, :source_name, :source_object, :allow_profile_creation, :source_last_updated_timestamp_format, :fields, :keys) SENSITIVE = [:fields, :keys] include Aws::Structure end |
#fields ⇒ Hash<String,Types::ObjectTypeField>
A map of the name and ObjectType field.
4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4942 class GetProfileObjectTypeTemplateResponse < Struct.new( :template_id, :source_name, :source_object, :allow_profile_creation, :source_last_updated_timestamp_format, :fields, :keys) SENSITIVE = [:fields, :keys] include Aws::Structure end |
#keys ⇒ Hash<String,Array<Types::ObjectTypeKey>>
A list of unique keys that can be used to map data to the profile.
4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4942 class GetProfileObjectTypeTemplateResponse < Struct.new( :template_id, :source_name, :source_object, :allow_profile_creation, :source_last_updated_timestamp_format, :fields, :keys) SENSITIVE = [:fields, :keys] include Aws::Structure end |
#source_last_updated_timestamp_format ⇒ String
The format of your sourceLastUpdatedTimestamp that was previously
set up.
4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4942 class GetProfileObjectTypeTemplateResponse < Struct.new( :template_id, :source_name, :source_object, :allow_profile_creation, :source_last_updated_timestamp_format, :fields, :keys) SENSITIVE = [:fields, :keys] include Aws::Structure end |
#source_name ⇒ String
The name of the source of the object template.
4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4942 class GetProfileObjectTypeTemplateResponse < Struct.new( :template_id, :source_name, :source_object, :allow_profile_creation, :source_last_updated_timestamp_format, :fields, :keys) SENSITIVE = [:fields, :keys] include Aws::Structure end |
#source_object ⇒ String
The source of the object template.
4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4942 class GetProfileObjectTypeTemplateResponse < Struct.new( :template_id, :source_name, :source_object, :allow_profile_creation, :source_last_updated_timestamp_format, :fields, :keys) SENSITIVE = [:fields, :keys] include Aws::Structure end |
#template_id ⇒ String
A unique identifier for the object template.
4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4942 class GetProfileObjectTypeTemplateResponse < Struct.new( :template_id, :source_name, :source_object, :allow_profile_creation, :source_last_updated_timestamp_format, :fields, :keys) SENSITIVE = [:fields, :keys] include Aws::Structure end |