Class: Aws::CustomerProfiles::Types::GetProfileRecommendationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:context]

Instance Attribute Summary collapse

Instance Attribute Details

#candidate_idsArray<String>

A list of item IDs to rank for the user. Use this when you want to re-rank a specific set of items rather than getting recommendations from the full item catalog. Required for personalized-ranking use cases.

Returns:

  • (Array<String>)


5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5010

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config,
  :diversity_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#contextHash<String,String>

The contextual metadata used to provide dynamic runtime information to tailor recommendations.

Returns:

  • (Hash<String,String>)


5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5010

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config,
  :diversity_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#diversity_configTypes::RecommendationDiversityConfig

Runtime diversity configuration for this request. Enables diversity-aware recommendations and optionally supplies values for placeholder-based diversity caps configured on the recommender.



5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5010

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config,
  :diversity_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5010

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config,
  :diversity_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#max_resultsInteger

The maximum number of recommendations to return. The default value is 10.

Returns:

  • (Integer)


5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5010

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config,
  :diversity_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#metadata_configTypes::MetadataConfig

Configuration for including item metadata in the recommendation response. Use this to specify which metadata columns to return alongside recommended items.



5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5010

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config,
  :diversity_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#profile_idString

The unique identifier of the profile for which to retrieve recommendations.

Returns:

  • (String)


5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5010

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config,
  :diversity_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#recommender_filtersArray<Types::RecommenderFilter>

A list of filters to apply to the returned recommendations. Filters define criteria for including or excluding items from the recommendation results.

Returns:



5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5010

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config,
  :diversity_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#recommender_nameString

The unique name of the recommender.

Returns:

  • (String)


5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5010

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config,
  :diversity_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#recommender_promotional_filtersArray<Types::RecommenderPromotionalFilter>

A list of promotional filters to apply to the recommendations. Promotional filters allow you to promote specific items within a configurable subset of recommendation results.



5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5010

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config,
  :diversity_config)
  SENSITIVE = [:context]
  include Aws::Structure
end