Class: Aws::CustomerProfiles::Types::GetRecommenderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetRecommenderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#recommender_name ⇒ String
The name of the recommender.
-
#training_metrics_count ⇒ Integer
The number of training metrics to retrieve for the recommender.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
4713 4714 4715 4716 4717 4718 4719 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713 class GetRecommenderRequest < Struct.new( :domain_name, :recommender_name, :training_metrics_count) SENSITIVE = [] include Aws::Structure end |
#recommender_name ⇒ String
The name of the recommender.
4713 4714 4715 4716 4717 4718 4719 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713 class GetRecommenderRequest < Struct.new( :domain_name, :recommender_name, :training_metrics_count) SENSITIVE = [] include Aws::Structure end |
#training_metrics_count ⇒ Integer
The number of training metrics to retrieve for the recommender.
4713 4714 4715 4716 4717 4718 4719 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713 class GetRecommenderRequest < Struct.new( :domain_name, :recommender_name, :training_metrics_count) SENSITIVE = [] include Aws::Structure end |