Class: Aws::CustomerProfiles::Types::GetRecommenderResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#active_recommender_version_nameString

The name of the recommender version currently serving recommendations. Omitted when no active recommender version is set.

Returns:

  • (String)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_atTime

The timestamp of when the recommender was created.

Returns:

  • (Time)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

A detailed description of the recommender providing information about its purpose and functionality.

Returns:

  • (String)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#failure_reasonString

If the recommender fails, provides the reason for the failure.

Returns:

  • (String)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the recommender was edited.

Returns:

  • (Time)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#latest_recommender_updateTypes::RecommenderUpdate

Information about the most recent update performed on the recommender, including status and timestamp.



5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_configTypes::RecommenderConfig

The configuration settings for the recommender, including parameters and settings that define its behavior.



5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_nameString

The name of the recommender.

Returns:

  • (String)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_recipe_nameString

The name of the recipe used by the recommender to generate recommendations.

Returns:

  • (String)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_schema_nameString

The name of the recommender schema associated with this recommender.

Returns:

  • (String)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#statusString

The current status of the recommender, indicating whether it is active, creating, updating, or in another state.

Returns:

  • (String)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#training_metricsArray<Types::TrainingMetrics>

A set of metrics that provide information about the recommender's training performance and accuracy.

Returns:



5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :active_recommender_version_name,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end