Class: Aws::CustomerProfiles::Types::GetSegmentMembershipResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failuresArray<Types::ProfileQueryFailures>

An array of maps where each contains a response per profile failed for the request.

Returns:



5124
5125
5126
5127
5128
5129
5130
5131
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5124

class GetSegmentMembershipResponse < Struct.new(
  :segment_definition_name,
  :profiles,
  :failures,
  :last_computed_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_computed_atTime

The timestamp indicating when the segment membership was last computed or updated.

Returns:

  • (Time)


5124
5125
5126
5127
5128
5129
5130
5131
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5124

class GetSegmentMembershipResponse < Struct.new(
  :segment_definition_name,
  :profiles,
  :failures,
  :last_computed_at)
  SENSITIVE = []
  include Aws::Structure
end

#profilesArray<Types::ProfileQueryResult>

An array of maps where each contains a response per profile requested.

Returns:



5124
5125
5126
5127
5128
5129
5130
5131
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5124

class GetSegmentMembershipResponse < Struct.new(
  :segment_definition_name,
  :profiles,
  :failures,
  :last_computed_at)
  SENSITIVE = []
  include Aws::Structure
end

#segment_definition_nameString

The unique name of the segment definition.

Returns:

  • (String)


5124
5125
5126
5127
5128
5129
5130
5131
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5124

class GetSegmentMembershipResponse < Struct.new(
  :segment_definition_name,
  :profiles,
  :failures,
  :last_computed_at)
  SENSITIVE = []
  include Aws::Structure
end