Class: Aws::CustomerProfiles::Types::GetSegmentSnapshotResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetSegmentSnapshotResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_format ⇒ String
The format in which the segment will be exported.
-
#destination_uri ⇒ String
The destination to which the segment will be exported.
-
#encryption_key ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the exported segment.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that allows Customer Profiles service principal to assume the role for conducting KMS and S3 operations.
-
#snapshot_id ⇒ String
The unique identifier of the segment snapshot.
-
#status ⇒ String
The status of the asynchronous job for exporting the segment snapshot.
-
#status_message ⇒ String
The status message of the asynchronous job for exporting the segment snapshot.
Instance Attribute Details
#data_format ⇒ String
The format in which the segment will be exported.
5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5496 class GetSegmentSnapshotResponse < Struct.new( :snapshot_id, :status, :status_message, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#destination_uri ⇒ String
The destination to which the segment will be exported. This field must be provided if the request is not submitted from the Connect Customer Admin Website.
5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5496 class GetSegmentSnapshotResponse < Struct.new( :snapshot_id, :status, :status_message, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#encryption_key ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the exported segment.
5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5496 class GetSegmentSnapshotResponse < Struct.new( :snapshot_id, :status, :status_message, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that allows Customer Profiles service principal to assume the role for conducting KMS and S3 operations.
5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5496 class GetSegmentSnapshotResponse < Struct.new( :snapshot_id, :status, :status_message, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The unique identifier of the segment snapshot.
5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5496 class GetSegmentSnapshotResponse < Struct.new( :snapshot_id, :status, :status_message, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the asynchronous job for exporting the segment snapshot.
5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5496 class GetSegmentSnapshotResponse < Struct.new( :snapshot_id, :status, :status_message, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status message of the asynchronous job for exporting the segment snapshot.
5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5496 class GetSegmentSnapshotResponse < Struct.new( :snapshot_id, :status, :status_message, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |