Class: Aws::CustomerProfiles::Types::GetSegmentSubscriptionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_updated_atTime

The timestamp of the most recent configuration change.

Returns:

  • (Time)


5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563

class GetSegmentSubscriptionResponse < Struct.new(
  :status,
  :message,
  :schedule_configuration,
  :scheduled_executions,
  :started_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A status message providing additional context, such as a failure reason.

Returns:

  • (String)


5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563

class GetSegmentSubscriptionResponse < Struct.new(
  :status,
  :message,
  :schedule_configuration,
  :scheduled_executions,
  :started_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_configurationTypes::ScheduleConfiguration

The schedule configuration for periodic membership event notifications.



5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563

class GetSegmentSubscriptionResponse < Struct.new(
  :status,
  :message,
  :schedule_configuration,
  :scheduled_executions,
  :started_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_executionsTypes::ScheduledExecutions

Information about scheduled execution timestamps.



5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563

class GetSegmentSubscriptionResponse < Struct.new(
  :status,
  :message,
  :schedule_configuration,
  :scheduled_executions,
  :started_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp of when the subscription was first started.

Returns:

  • (Time)


5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563

class GetSegmentSubscriptionResponse < Struct.new(
  :status,
  :message,
  :schedule_configuration,
  :scheduled_executions,
  :started_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current lifecycle status of the subscription. The following are valid values:

  • STARTING: Initial snapshot is in progress.

  • RUNNING: Notifications are active and running.

  • STOPPED: Notifications have been stopped.

  • FAILED: Notifications failed (for example, the Amazon Kinesis data stream became inaccessible).

Returns:

  • (String)


5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563

class GetSegmentSubscriptionResponse < Struct.new(
  :status,
  :message,
  :schedule_configuration,
  :scheduled_executions,
  :started_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end