Class: Aws::CustomerProfiles::Types::GetSimilarProfilesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_name ⇒ String

The unique name of the domain.



5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5601

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#match_type ⇒ String

Specify the type of matching to get similar profiles for.



5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5601

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of objects returned per page.



5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5601

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token from the previous GetSimilarProfiles API call.



5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5601

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#search_key ⇒ String

The string indicating the search key to be used.



5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5601

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#search_value ⇒ String

The string based on SearchKey to be searched for similar profiles.



5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5601

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end