Class: Aws::CustomerProfiles::Types::GetSimilarProfilesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#confidence_score ⇒ Float

It only has value when the MatchType is ML_BASED_MATCHING.A number between 0 and 1, where a higher score means higher similarity. Examining match confidence scores lets you distinguish between groups of similar records in which the system is highly confident (which you may decide to merge), groups of similar records about which the system is uncertain (which you may decide to have reviewed by a human), and groups of similar records that the system deems to be unlikely (which you may decide to reject). Given confidence scores vary as per the data input, it should not be used as an absolute measure of matching quality.

Returns:

  • (Float)


5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5648

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#match_id ⇒ String

The string matchId that the similar profiles belong to.

Returns:

  • (String)


5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5648

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#match_type ⇒ String

Specify the type of matching to get similar profiles for.

Returns:

  • (String)


5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5648

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token from the previous GetSimilarProfiles API call.

Returns:

  • (String)


5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5648

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#profile_ids ⇒ Array<String>

Set of profileIds that belong to the same matching group.

Returns:

  • (Array<String>)


5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5648

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#rule_level ⇒ Integer

The integer rule level that the profiles matched on.

Returns:

  • (Integer)


5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5648

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end