Class: Aws::CustomerProfiles::Types::GetStreamForSegmentsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_atTime

The timestamp of when the stream was associated.

Returns:

  • (Time)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5718

class GetStreamForSegmentsResponse < Struct.new(
  :associated_at,
  :associated_segments,
  :domain_name,
  :destination_arn,
  :destination_role_arn,
  :state,
  :disassociated_at,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#associated_segmentsArray<Types::AssociatedSegment>

A list of segments currently associated with the stream and their subscription status.

Returns:



5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5718

class GetStreamForSegmentsResponse < Struct.new(
  :associated_at,
  :associated_segments,
  :domain_name,
  :destination_arn,
  :destination_role_arn,
  :state,
  :disassociated_at,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#destination_arnString

The Amazon Resource Name (ARN) of the Amazon Kinesis data stream receiving segment membership events.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5718

class GetStreamForSegmentsResponse < Struct.new(
  :associated_at,
  :associated_segments,
  :domain_name,
  :destination_arn,
  :destination_role_arn,
  :state,
  :disassociated_at,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#destination_role_arnString

The Amazon Resource Name (ARN) of the IAM role used for Amazon Kinesis and AWS Key Management Service (KMS) operations.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5718

class GetStreamForSegmentsResponse < Struct.new(
  :associated_at,
  :associated_segments,
  :domain_name,
  :destination_arn,
  :destination_role_arn,
  :state,
  :disassociated_at,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#disassociated_atTime

The timestamp of when the stream was disassociated.

Returns:

  • (Time)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5718

class GetStreamForSegmentsResponse < Struct.new(
  :associated_at,
  :associated_segments,
  :domain_name,
  :destination_arn,
  :destination_role_arn,
  :state,
  :disassociated_at,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5718

class GetStreamForSegmentsResponse < Struct.new(
  :associated_at,
  :associated_segments,
  :domain_name,
  :destination_arn,
  :destination_role_arn,
  :state,
  :disassociated_at,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason why the stream is in an unhealthy state, if applicable.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5718

class GetStreamForSegmentsResponse < Struct.new(
  :associated_at,
  :associated_segments,
  :domain_name,
  :destination_arn,
  :destination_role_arn,
  :state,
  :disassociated_at,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The operational state of the destination stream. The following are valid values:

  • RUNNING: The stream is associated and healthy. Segment membership events are being published.

  • UNHEALTHY: The stream is associated but events cannot currently be published. See FailureReason for details.

  • STOPPED: The stream is no longer publishing segment membership events.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5718

class GetStreamForSegmentsResponse < Struct.new(
  :associated_at,
  :associated_segments,
  :domain_name,
  :destination_arn,
  :destination_role_arn,
  :state,
  :disassociated_at,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end