Class: Aws::CustomerProfiles::Types::GetUploadJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetUploadJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:fields]
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp when the upload job was completed.
-
#created_at ⇒ Time
The timestamp when the upload job was created.
-
#data_expiry ⇒ Integer
The expiry duration for the profiles ingested with the upload job.
-
#display_name ⇒ String
The unique name of the upload job.
-
#fields ⇒ Hash<String,Types::ObjectTypeField>
The mapping between CSV Columns and Profile Object attributes for the upload job.
-
#job_id ⇒ String
The unique identifier of the upload job.
-
#results_summary ⇒ Types::ResultsSummary
The summary of results for the upload job, including the number of updated, created, and failed records.
-
#status ⇒ String
The status describing the status for the upload job.
-
#status_reason ⇒ String
The reason for the current status of the upload job.
-
#unique_key ⇒ String
The unique key columns used for de-duping the keys in the upload job.
Instance Attribute Details
#completed_at ⇒ Time
The timestamp when the upload job was completed.
5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5427 class GetUploadJobResponse < Struct.new( :job_id, :display_name, :status, :status_reason, :created_at, :completed_at, :fields, :unique_key, :results_summary, :data_expiry) SENSITIVE = [:fields] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the upload job was created.
5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5427 class GetUploadJobResponse < Struct.new( :job_id, :display_name, :status, :status_reason, :created_at, :completed_at, :fields, :unique_key, :results_summary, :data_expiry) SENSITIVE = [:fields] include Aws::Structure end |
#data_expiry ⇒ Integer
The expiry duration for the profiles ingested with the upload job.
5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5427 class GetUploadJobResponse < Struct.new( :job_id, :display_name, :status, :status_reason, :created_at, :completed_at, :fields, :unique_key, :results_summary, :data_expiry) SENSITIVE = [:fields] include Aws::Structure end |
#display_name ⇒ String
The unique name of the upload job. Could be a file name to identify the upload job.
5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5427 class GetUploadJobResponse < Struct.new( :job_id, :display_name, :status, :status_reason, :created_at, :completed_at, :fields, :unique_key, :results_summary, :data_expiry) SENSITIVE = [:fields] include Aws::Structure end |
#fields ⇒ Hash<String,Types::ObjectTypeField>
The mapping between CSV Columns and Profile Object attributes for the upload job.
5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5427 class GetUploadJobResponse < Struct.new( :job_id, :display_name, :status, :status_reason, :created_at, :completed_at, :fields, :unique_key, :results_summary, :data_expiry) SENSITIVE = [:fields] include Aws::Structure end |
#job_id ⇒ String
The unique identifier of the upload job.
5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5427 class GetUploadJobResponse < Struct.new( :job_id, :display_name, :status, :status_reason, :created_at, :completed_at, :fields, :unique_key, :results_summary, :data_expiry) SENSITIVE = [:fields] include Aws::Structure end |
#results_summary ⇒ Types::ResultsSummary
The summary of results for the upload job, including the number of updated, created, and failed records.
5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5427 class GetUploadJobResponse < Struct.new( :job_id, :display_name, :status, :status_reason, :created_at, :completed_at, :fields, :unique_key, :results_summary, :data_expiry) SENSITIVE = [:fields] include Aws::Structure end |
#status ⇒ String
The status describing the status for the upload job. The following are Valid Values:
-
CREATED: The upload job has been created, but has not started processing yet.
-
IN_PROGRESS: The upload job is currently in progress, ingesting and processing the profile data.
-
PARTIALLY_SUCCEEDED: The upload job has successfully completed the ingestion and processing of all profile data.
-
SUCCEEDED: The upload job has successfully completed the ingestion and processing of all profile data.
-
FAILED: The upload job has failed to complete.
-
STOPPED: The upload job has been manually stopped or terminated before completion.
5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5427 class GetUploadJobResponse < Struct.new( :job_id, :display_name, :status, :status_reason, :created_at, :completed_at, :fields, :unique_key, :results_summary, :data_expiry) SENSITIVE = [:fields] include Aws::Structure end |
#status_reason ⇒ String
The reason for the current status of the upload job. Possible reasons:
-
VALIDATION_FAILURE: The upload job has encountered an error or issue and was unable to complete the profile data ingestion.
-
INTERNAL_FAILURE: Failure caused from service side
5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5427 class GetUploadJobResponse < Struct.new( :job_id, :display_name, :status, :status_reason, :created_at, :completed_at, :fields, :unique_key, :results_summary, :data_expiry) SENSITIVE = [:fields] include Aws::Structure end |
#unique_key ⇒ String
The unique key columns used for de-duping the keys in the upload job.
5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5427 class GetUploadJobResponse < Struct.new( :job_id, :display_name, :status, :status_reason, :created_at, :completed_at, :fields, :unique_key, :results_summary, :data_expiry) SENSITIVE = [:fields] include Aws::Structure end |