Class: Aws::CustomerProfiles::Types::ListDomainObjectTypesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_name ⇒ String

The unique name of the domain.

Returns:

  • (String)


6575
6576
6577
6578
6579
6580
6581
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6575

class ListDomainObjectTypesRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of domain object types returned per page.

Returns:

  • (Integer)


6575
6576
6577
6578
6579
6580
6581
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6575

class ListDomainObjectTypesRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token from the previous call to ListDomainObjectTypes.

Returns:

  • (String)


6575
6576
6577
6578
6579
6580
6581
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6575

class ListDomainObjectTypesRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end