Class: Aws::CustomerProfiles::Types::ListIntegrationItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

An integration in list of integrations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

The timestamp of when the domain was created.

Returns:

  • (Time)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#domain_name ⇒ String

The unique name of the domain.

Returns:

  • (String)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#event_trigger_names ⇒ Array<String>

A list of unique names for active event triggers associated with the integration.

Returns:

  • (Array<String>)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#is_unstructured ⇒ Boolean

Boolean that shows if the Flow that's associated with the Integration is created in Amazon Appflow, or with ObjectTypeName equals _unstructured via API/CLI in flowDefinition.

Returns:

  • (Boolean)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The timestamp of when the integration was most recently edited.

Returns:

  • (Time)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#object_type_name ⇒ String

The name of the profile object type.

Returns:

  • (String)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#object_type_names ⇒ Hash<String,String>

A map in which each key is an event type from an external application such as Segment or Shopify, and each value is an ObjectTypeName (template) used to ingest the event. It supports the following event types: SegmentIdentify, ShopifyCreateCustomers, ShopifyUpdateCustomers, ShopifyCreateDraftOrders, ShopifyUpdateDraftOrders, ShopifyCreateOrders, and ShopifyUpdatedOrders.

Returns:

  • (Hash<String,String>)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The Amazon Resource Name (ARN) of the IAM role. The Integration uses this role to make Customer Profiles requests on your behalf.

Returns:

  • (String)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#scope ⇒ String

The scope or boundary of the integration item's applicability.

Returns:

  • (String)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#uri ⇒ String

The URI of the S3 bucket or any other type of data source.

Returns:

  • (String)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_id ⇒ String

Unique identifier for the workflow.

Returns:

  • (String)


6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6818

class ListIntegrationItem < Struct.new(
  :domain_name,
  :uri,
  :object_type_name,
  :created_at,
  :last_updated_at,
  :tags,
  :object_type_names,
  :workflow_id,
  :is_unstructured,
  :role_arn,
  :event_trigger_names,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end