Class: Aws::CustomerProfiles::Types::ListObjectTypeAttributeValuesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#items ⇒ Array<Types::ListObjectTypeAttributeValuesItem>

A list of unique attribute values sorted on the basis of LastUpdatedAt.



6966
6967
6968
6969
6970
6971
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6966

class ListObjectTypeAttributeValuesResponse < Struct.new(
  :items,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token from the previous call to call ListObjectTypeAttributeValues.

Returns:

  • (String)


6966
6967
6968
6969
6970
6971
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6966

class ListObjectTypeAttributeValuesResponse < Struct.new(
  :items,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end