Class: Aws::CustomerProfiles::Types::ListProfileObjectsItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ListProfileObjectsItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
A ProfileObject in a list of ProfileObjects.
Constant Summary collapse
- SENSITIVE =
[:object]
Instance Attribute Summary collapse
-
#object ⇒ String
A JSON representation of a ProfileObject that belongs to a profile.
-
#object_type_name ⇒ String
Specifies the kind of object being added to a profile, such as "Salesforce-Account.".
-
#profile_object_unique_key ⇒ String
The unique identifier of the ProfileObject generated by the service.
Instance Attribute Details
#object ⇒ String
A JSON representation of a ProfileObject that belongs to a profile.
7255 7256 7257 7258 7259 7260 7261 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7255 class ListProfileObjectsItem < Struct.new( :object_type_name, :profile_object_unique_key, :object) SENSITIVE = [:object] include Aws::Structure end |
#object_type_name ⇒ String
Specifies the kind of object being added to a profile, such as "Salesforce-Account."
7255 7256 7257 7258 7259 7260 7261 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7255 class ListProfileObjectsItem < Struct.new( :object_type_name, :profile_object_unique_key, :object) SENSITIVE = [:object] include Aws::Structure end |
#profile_object_unique_key ⇒ String
The unique identifier of the ProfileObject generated by the service.
7255 7256 7257 7258 7259 7260 7261 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7255 class ListProfileObjectsItem < Struct.new( :object_type_name, :profile_object_unique_key, :object) SENSITIVE = [:object] include Aws::Structure end |