Class: Aws::CustomerProfiles::Types::ListRecommenderSchemasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_name ⇒ String

The unique name of the domain.

Returns:

  • (String)


7414
7415
7416
7417
7418
7419
7420
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7414

class ListRecommenderSchemasRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of recommender schemas to return in the response. The default value is 100.

Returns:

  • (Integer)


7414
7415
7416
7417
7418
7419
7420
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7414

class ListRecommenderSchemasRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token received from a previous ListRecommenderSchemas call to retrieve the next page of results.

Returns:

  • (String)


7414
7415
7416
7417
7418
7419
7420
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7414

class ListRecommenderSchemasRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end