Class: Aws::CustomerProfiles::Types::ListRecommenderSchemasResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

A token to retrieve the next page of results. Null if there are no more results to retrieve.

Returns:

  • (String)


7434
7435
7436
7437
7438
7439
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7434

class ListRecommenderSchemasResponse < Struct.new(
  :next_token,
  :recommender_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#recommender_schemas ⇒ Array<Types::RecommenderSchemaSummary>

A list of recommender schemas and their properties in the specified domain.



7434
7435
7436
7437
7438
7439
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7434

class ListRecommenderSchemasResponse < Struct.new(
  :next_token,
  :recommender_schemas)
  SENSITIVE = []
  include Aws::Structure
end