Class: Aws::CustomerProfiles::Types::ListRecommendersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_name ⇒ String

The unique name of the domain.

Returns:

  • (String)


7457
7458
7459
7460
7461
7462
7463
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7457

class ListRecommendersRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of recommenders to return in the response. The default value is 100.

Returns:

  • (Integer)


7457
7458
7459
7460
7461
7462
7463
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7457

class ListRecommendersRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token received from a previous ListRecommenders call to retrieve the next page of results.

Returns:

  • (String)


7457
7458
7459
7460
7461
7462
7463
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7457

class ListRecommendersRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end