Class: Aws::CustomerProfiles::Types::ListRecommendersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

A token to retrieve the next page of results. Null if there are no more results to retrieve.

Returns:

  • (String)


7476
7477
7478
7479
7480
7481
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7476

class ListRecommendersResponse < Struct.new(
  :next_token,
  :recommenders)
  SENSITIVE = []
  include Aws::Structure
end

#recommenders ⇒ Array<Types::RecommenderSummary>

A list of recommenders and their properties in the specified domain.

Returns:



7476
7477
7478
7479
7480
7481
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7476

class ListRecommendersResponse < Struct.new(
  :next_token,
  :recommenders)
  SENSITIVE = []
  include Aws::Structure
end