Class: Aws::CustomerProfiles::Types::ListUploadJobsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_name ⇒ String

The unique name of the domain to list upload jobs for.

Returns:

  • (String)


7648
7649
7650
7651
7652
7653
7654
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7648

class ListUploadJobsRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of upload jobs to return per page.

Returns:

  • (Integer)


7648
7649
7650
7651
7652
7653
7654
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7648

class ListUploadJobsRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token from the previous call to retrieve the next page of results.

Returns:

  • (String)


7648
7649
7650
7651
7652
7653
7654
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7648

class ListUploadJobsRequest < Struct.new(
  :domain_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end