Class: Aws::CustomerProfiles::Types::ListUploadJobsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#items ⇒ Array<Types::UploadJobItem>

The list of upload jobs for the specified domain.

Returns:



7666
7667
7668
7669
7670
7671
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7666

class ListUploadJobsResponse < Struct.new(
  :next_token,
  :items)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token to use to retrieve the next page of results.

Returns:

  • (String)


7666
7667
7668
7669
7670
7671
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7666

class ListUploadJobsResponse < Struct.new(
  :next_token,
  :items)
  SENSITIVE = []
  include Aws::Structure
end