Class: Aws::CustomerProfiles::Types::MetadataConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::MetadataConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Configuration for metadata to include in recommendation responses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metadata_columns ⇒ Array<String>
A list of metadata column names from your Items dataset to include in the recommendation response.
Instance Attribute Details
#metadata_columns ⇒ Array<String>
A list of metadata column names from your Items dataset to include in the recommendation response.
7300 7301 7302 7303 7304 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7300 class MetadataConfig < Struct.new( :metadata_columns) SENSITIVE = [] include Aws::Structure end |