Class: Aws::CustomerProfiles::Types::Profile

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The standard profile of a customer.

Constant Summary collapse

SENSITIVE =
[:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]

Instance Attribute Summary collapse

Instance Attribute Details

#account_numberString

An account number that you have assigned to the customer.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#additional_informationString

Any additional information relevant to the customer’s profile.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#addressTypes::Address

A generic address associated with the customer that is not mailing, shipping, or billing.

Returns:



7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#attributesHash<String,String>

A key value pair of attributes of a customer profile.

Returns:

  • (Hash<String,String>)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#billing_addressTypes::Address

The customer’s billing address.

Returns:



7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#birth_dateString

The customer’s birth date.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#business_email_addressString

The customer’s business email address.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#business_nameString

The name of the customer’s business.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#business_phone_numberString

The customer’s home phone number.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#email_addressString

The customer’s email address, which has not been specified as a personal or business address.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#engagement_preferencesTypes::EngagementPreferences

The customer or account’s engagement preferences.



7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#first_nameString

The customer’s first name.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#found_by_itemsArray<Types::FoundByKeyValue>

A list of items used to find a profile returned in a

SearchProfiles][1

response. An item is a key-value(s) pair that

matches an attribute in the profile.

If the optional ‘AdditionalSearchKeys` parameter was included in the

SearchProfiles][1

request, the ‘FoundByItems` list should be

interpreted based on the ‘LogicalOperator` used in the request:

  • ‘AND` - The profile included in the response matched all of the search keys specified in the request. The `FoundByItems` will include all of the key-value(s) pairs that were specified in the request (as this is a requirement of `AND` search logic).

  • ‘OR` - The profile included in the response matched at least one of the search keys specified in the request. The `FoundByItems` will include each of the key-value(s) pairs that the profile was found by.

The ‘OR` relationship is the default behavior if the `LogicalOperator` parameter is not included in the

SearchProfiles][1

request.

[1]: docs.aws.amazon.com/customerprofiles/latest/APIReference/API_SearchProfiles.html

Returns:



7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#genderString

The gender with which the customer identifies.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#gender_stringString

An alternative to Gender which accepts any string as input.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#home_phone_numberString

The customer’s home phone number.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#last_nameString

The customer’s last name.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#mailing_addressTypes::Address

The customer’s mailing address.

Returns:



7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#middle_nameString

The customer’s middle name.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#mobile_phone_numberString

The customer’s mobile phone number.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#party_typeString

The type of profile used to describe the customer.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#party_type_stringString

An alternative to PartyType which accepts any string as input.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#personal_email_addressString

The customer’s personal email address.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#phone_numberString

The customer’s phone number, which has not been specified as a mobile, home, or business number.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#profile_idString

The unique identifier of a customer profile.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#profile_typeString

The type of the profile.

Returns:

  • (String)


7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end

#shipping_addressTypes::Address

The customer’s shipping address.

Returns:



7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7891

class Profile < Struct.new(
  :profile_id,
  :account_number,
  :additional_information,
  :party_type,
  :business_name,
  :first_name,
  :middle_name,
  :last_name,
  :birth_date,
  :gender,
  :phone_number,
  :mobile_phone_number,
  :home_phone_number,
  :business_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :found_by_items,
  :party_type_string,
  :gender_string,
  :profile_type,
  :engagement_preferences)
  SENSITIVE = [:account_number, :additional_information, :party_type, :business_name, :first_name, :middle_name, :last_name, :birth_date, :gender, :phone_number, :mobile_phone_number, :home_phone_number, :business_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :party_type_string, :gender_string, :profile_type, :engagement_preferences]
  include Aws::Structure
end