Class: Aws::CustomerProfiles::Types::ProfileAttributes

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The object used to segment on attributes within the customer profile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_numberTypes::ProfileDimension

A field to describe values to segment on within account number.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#additional_informationTypes::ExtraLengthValueProfileDimension

A field to describe values to segment on within additional information.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#addressTypes::AddressDimension

A field to describe values to segment on within address.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#attributesHash<String,Types::AttributeDimension>

A field to describe values to segment on within attributes.

Returns:



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#billing_addressTypes::AddressDimension

A field to describe values to segment on within billing address.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#birth_dateTypes::DateDimension

A field to describe values to segment on within birthDate.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#business_email_addressTypes::ProfileDimension

A field to describe values to segment on within business email address.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#business_nameTypes::ProfileDimension

A field to describe values to segment on within business name.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#business_phone_numberTypes::ProfileDimension

A field to describe values to segment on within business phone number.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#email_addressTypes::ProfileDimension

A field to describe values to segment on within email address.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#first_nameTypes::ProfileDimension

A field to describe values to segment on within first name.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#gender_stringTypes::ProfileDimension

A field to describe values to segment on within genderString.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#home_phone_numberTypes::ProfileDimension

A field to describe values to segment on within home phone number.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#last_nameTypes::ProfileDimension

A field to describe values to segment on within last name.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#mailing_addressTypes::AddressDimension

A field to describe values to segment on within mailing address.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#middle_nameTypes::ProfileDimension

A field to describe values to segment on within middle name.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#mobile_phone_numberTypes::ProfileDimension

A field to describe values to segment on within mobile phone number.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#party_type_stringTypes::ProfileDimension

A field to describe values to segment on within partyTypeString.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#personal_email_addressTypes::ProfileDimension

A field to describe values to segment on within personal email address.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#phone_numberTypes::ProfileDimension

A field to describe values to segment on within phone number.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#profile_typeTypes::ProfileTypeDimension

A field to describe values to segment on within profile type.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end

#shipping_addressTypes::AddressDimension

A field to describe values to segment on within shipping address.



8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8063

class ProfileAttributes < Struct.new(
  :account_number,
  :additional_information,
  :first_name,
  :last_name,
  :middle_name,
  :gender_string,
  :party_type_string,
  :birth_date,
  :phone_number,
  :business_name,
  :business_phone_number,
  :home_phone_number,
  :mobile_phone_number,
  :email_address,
  :personal_email_address,
  :business_email_address,
  :address,
  :shipping_address,
  :mailing_address,
  :billing_address,
  :attributes,
  :profile_type)
  SENSITIVE = []
  include Aws::Structure
end