Class: Aws::CustomerProfiles::Types::PutDomainObjectTypeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the domain object type.

Returns:

  • (String)


8251
8252
8253
8254
8255
8256
8257
8258
8259
8260
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8251

class PutDomainObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :encryption_key,
  :fields,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


8251
8252
8253
8254
8255
8256
8257
8258
8259
8260
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8251

class PutDomainObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :encryption_key,
  :fields,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#encryption_keyString

The customer provided KMS key used to encrypt this type of domain object.

Returns:

  • (String)


8251
8252
8253
8254
8255
8256
8257
8258
8259
8260
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8251

class PutDomainObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :encryption_key,
  :fields,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#fieldsHash<String,Types::DomainObjectTypeField>

A map of field names to their corresponding domain object type field definitions.

Returns:



8251
8252
8253
8254
8255
8256
8257
8258
8259
8260
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8251

class PutDomainObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :encryption_key,
  :fields,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#object_type_nameString

The unique name of the domain object type.

Returns:

  • (String)


8251
8252
8253
8254
8255
8256
8257
8258
8259
8260
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8251

class PutDomainObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :encryption_key,
  :fields,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


8251
8252
8253
8254
8255
8256
8257
8258
8259
8260
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8251

class PutDomainObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :encryption_key,
  :fields,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end