Class: Aws::CustomerProfiles::Types::PutIntegrationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::PutIntegrationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the domain was created.
-
#domain_name ⇒ String
The unique name of the domain.
-
#event_trigger_names ⇒ Array<String>
A list of unique names for active event triggers associated with the integration.
-
#is_unstructured ⇒ Boolean
Boolean that shows if the Flow that's associated with the Integration is created in Amazon Appflow, or with ObjectTypeName equals _unstructured via API/CLI in flowDefinition.
-
#last_updated_at ⇒ Time
The timestamp of when the domain was most recently edited.
-
#object_type_name ⇒ String
The name of the profile object type.
-
#object_type_names ⇒ Hash<String,String>
A map in which each key is an event type from an external application such as Segment or Shopify, and each value is an
ObjectTypeName(template) used to ingest the event. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#scope ⇒ String
Specifies whether the integration applies to profile level data (associated with profiles) or domain level data (not associated with any specific profile).
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#uri ⇒ String
The URI of the S3 bucket or any other type of data source.
-
#workflow_id ⇒ String
Unique identifier for the workflow.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the domain was created.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#event_trigger_names ⇒ Array<String>
A list of unique names for active event triggers associated with the integration. This list would be empty if no Event Trigger is associated with the integration.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#is_unstructured ⇒ Boolean
Boolean that shows if the Flow that's associated with the Integration is created in Amazon Appflow, or with ObjectTypeName equals _unstructured via API/CLI in flowDefinition.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the domain was most recently edited.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#object_type_name ⇒ String
The name of the profile object type.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#object_type_names ⇒ Hash<String,String>
A map in which each key is an event type from an external
application such as Segment or Shopify, and each value is an
ObjectTypeName (template) used to ingest the event. It supports
the following event types: SegmentIdentify,
ShopifyCreateCustomers, ShopifyUpdateCustomers,
ShopifyCreateDraftOrders, ShopifyUpdateDraftOrders,
ShopifyCreateOrders, and ShopifyUpdatedOrders.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. The Integration uses this role to make Customer Profiles requests on your behalf.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether the integration applies to profile level data (associated with profiles) or domain level data (not associated with any specific profile). The default value is PROFILE.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#uri ⇒ String
The URI of the S3 bucket or any other type of data source.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |
#workflow_id ⇒ String
Unique identifier for the workflow.
8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8823 class PutIntegrationResponse < Struct.new( :domain_name, :uri, :object_type_name, :created_at, :last_updated_at, :tags, :object_type_names, :workflow_id, :is_unstructured, :role_arn, :event_trigger_names, :scope) SENSITIVE = [] include Aws::Structure end |