Class: Aws::CustomerProfiles::Types::PutProfileObjectTypeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :fields, :keys]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_profile_creationBoolean

Indicates whether a profile should be created when data is received if one doesn’t exist for an object of this type. The default is FALSE. If the AllowProfileCreation flag is set to FALSE, then the service tries to fetch a standard profile and associate this object with the profile. If it is set to TRUE, and if no match is found, then the service creates a new standard profile.

Returns:

  • (Boolean)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#created_atTime

The timestamp of when the domain was created.

Returns:

  • (Time)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#descriptionString

Description of the profile object type.

Returns:

  • (String)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#encryption_keyString

The customer-provided key to encrypt the profile object that will be created in this profile object type.

Returns:

  • (String)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#expiration_daysInteger

The number of days until the data in the object expires.

Returns:

  • (Integer)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#fieldsHash<String,Types::ObjectTypeField>

A map of the name and ObjectType field.

Returns:



9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#keysHash<String,Array<Types::ObjectTypeKey>>

A list of unique keys that can be used to map data to the profile.

Returns:



9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the domain was most recently edited.

Returns:

  • (Time)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#max_available_profile_object_countInteger

The amount of provisioned profile object max count available.

Returns:

  • (Integer)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#max_profile_object_countInteger

The amount of profile object max count assigned to the object type.

Returns:

  • (Integer)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#object_type_nameString

The name of the profile object type.

Returns:

  • (String)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#source_last_updated_timestamp_formatString

The format of your sourceLastUpdatedTimestamp that was previously set up in fields that were parsed using SimpleDateFormat. If you have sourceLastUpdatedTimestamp in your field, you must set up sourceLastUpdatedTimestampFormat.

Returns:

  • (String)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#source_priorityInteger

An integer that determines the priority of this object type when data from multiple sources is ingested. Lower values take priority. Object types without a specified source priority default to the lowest priority.

Returns:

  • (Integer)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#template_idString

A unique identifier for the object template.

Returns:

  • (String)


9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9044

class PutProfileObjectTypeResponse < Struct.new(
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :max_available_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end