Class: Aws::CustomerProfiles::Types::PutSegmentSubscriptionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


9080
9081
9082
9083
9084
9085
9086
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9080

class PutSegmentSubscriptionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :schedule_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_configurationTypes::ScheduleConfiguration

The optional schedule configuration that controls how often membership snapshots are run. If not provided, the subscription defaults to a 24-hour interval.



9080
9081
9082
9083
9084
9085
9086
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9080

class PutSegmentSubscriptionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :schedule_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#segment_definition_nameString

The unique name of the segment definition.

Returns:

  • (String)


9080
9081
9082
9083
9084
9085
9086
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9080

class PutSegmentSubscriptionRequest < Struct.new(
  :domain_name,
  :segment_definition_name,
  :schedule_configuration)
  SENSITIVE = []
  include Aws::Structure
end