Class: Aws::CustomerProfiles::Types::Range
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::Range
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
The relative time period over which data is included in the aggregation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#timestamp_format ⇒ String
The format the timestamp field in your JSON object is specified.
-
#timestamp_source ⇒ String
An expression specifying the field in your JSON object from which the date should be parsed.
-
#unit ⇒ String
The unit of time.
-
#value ⇒ Integer
The amount of time of the specified unit.
-
#value_range ⇒ Types::ValueRange
A structure letting customers specify a relative time window over which over which data is included in the Calculated Attribute.
Instance Attribute Details
#timestamp_format ⇒ String
The format the timestamp field in your JSON object is specified. This value should be one of EPOCHMILLI (for Unix epoch timestamps with second/millisecond level precision) or ISO_8601 (following ISO_8601 format with second/millisecond level precision, with an optional offset of Z or in the format HH:MM or HHMM.). E.g. if your object type is MyType and source JSON is {"timestamp": "2001-07-04T12:08:56.235-0700"}, then TimestampFormat should be "ISO_8601".
8780 8781 8782 8783 8784 8785 8786 8787 8788 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8780 class Range < Struct.new( :value, :unit, :value_range, :timestamp_source, :timestamp_format) SENSITIVE = [] include Aws::Structure end |
#timestamp_source ⇒ String
An expression specifying the field in your JSON object from which the date should be parsed. The expression should follow the structure of \"of timestamp field in JSON pointer format>\". E.g. if your object type is MyType and source JSON is {"timestamp": "1737587945945"}, then TimestampSource should be "MyType.generatedAt.timestamp".
8780 8781 8782 8783 8784 8785 8786 8787 8788 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8780 class Range < Struct.new( :value, :unit, :value_range, :timestamp_source, :timestamp_format) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The unit of time.
8780 8781 8782 8783 8784 8785 8786 8787 8788 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8780 class Range < Struct.new( :value, :unit, :value_range, :timestamp_source, :timestamp_format) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Integer
The amount of time of the specified unit.
8780 8781 8782 8783 8784 8785 8786 8787 8788 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8780 class Range < Struct.new( :value, :unit, :value_range, :timestamp_source, :timestamp_format) SENSITIVE = [] include Aws::Structure end |
#value_range ⇒ Types::ValueRange
A structure letting customers specify a relative time window over which over which data is included in the Calculated Attribute. Use positive numbers to indicate that the endpoint is in the past, and negative numbers to indicate it is in the future. ValueRange overrides Value.
8780 8781 8782 8783 8784 8785 8786 8787 8788 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8780 class Range < Struct.new( :value, :unit, :value_range, :timestamp_source, :timestamp_format) SENSITIVE = [] include Aws::Structure end |