Class: Aws::CustomerProfiles::Types::Readiness

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ String

Any customer messaging.

Returns:

  • (String)


9210
9211
9212
9213
9214
9215
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9210

class Readiness < Struct.new(
  :progress_percentage,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#progress_percentage ⇒ Integer

Approximately how far the Calculated Attribute creation is from completion.

Returns:

  • (Integer)


9210
9211
9212
9213
9214
9215
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9210

class Readiness < Struct.new(
  :progress_percentage,
  :message)
  SENSITIVE = []
  include Aws::Structure
end