Class: Aws::CustomerProfiles::Types::RecommendationMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::RecommendationMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Configuration for metadata to include in recommendation responses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#columns ⇒ Array<String>
A list of metadata column names from your Items dataset to include in the recommendation response.
Instance Attribute Details
#columns ⇒ Array<String>
A list of metadata column names from your Items dataset to include in the recommendation response.
9270 9271 9272 9273 9274 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9270 class RecommendationMetadata < Struct.new( :columns) SENSITIVE = [] include Aws::Structure end |