Class: Aws::CustomerProfiles::Types::RecommenderSchemaField
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::RecommenderSchemaField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Defines a column in a recommender schema, including the target field name and optional feature and content type settings for training.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type ⇒ String
The data type of the column value.
-
#feature_type ⇒ String
How the column is treated for model training.
-
#target_field_name ⇒ String
The name of the target field in the dataset, such as ‘Location.City` or `Attributes.MealTime`.
Instance Attribute Details
#content_type ⇒ String
The data type of the column value. Valid values are ‘String` and `Number`. The default value is `String`.
9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9002 class RecommenderSchemaField < Struct.new( :target_field_name, :content_type, :feature_type) SENSITIVE = [] include Aws::Structure end |
#feature_type ⇒ String
How the column is treated for model training. Valid values are ‘CATEGORICAL` and `TEXTUAL`.
9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9002 class RecommenderSchemaField < Struct.new( :target_field_name, :content_type, :feature_type) SENSITIVE = [] include Aws::Structure end |
#target_field_name ⇒ String
The name of the target field in the dataset, such as ‘Location.City` or `Attributes.MealTime`.
9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9002 class RecommenderSchemaField < Struct.new( :target_field_name, :content_type, :feature_type) SENSITIVE = [] include Aws::Structure end |