Class: Aws::CustomerProfiles::Types::RecommenderSchemaSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::RecommenderSchemaSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Provides a summary of a recommender schema’s configuration and current state.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the recommender schema was created.
-
#fields ⇒ Hash<String,Array<Types::RecommenderSchemaField>>
A map of dataset type to column definitions included in the schema.
-
#recommender_schema_name ⇒ String
The name of the recommender schema.
-
#status ⇒ String
The current operational status of the recommender schema.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the recommender schema was created.
8912 8913 8914 8915 8916 8917 8918 8919 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8912 class RecommenderSchemaSummary < Struct.new( :recommender_schema_name, :fields, :created_at, :status) SENSITIVE = [] include Aws::Structure end |
#fields ⇒ Hash<String,Array<Types::RecommenderSchemaField>>
A map of dataset type to column definitions included in the schema.
8912 8913 8914 8915 8916 8917 8918 8919 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8912 class RecommenderSchemaSummary < Struct.new( :recommender_schema_name, :fields, :created_at, :status) SENSITIVE = [] include Aws::Structure end |
#recommender_schema_name ⇒ String
The name of the recommender schema.
8912 8913 8914 8915 8916 8917 8918 8919 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8912 class RecommenderSchemaSummary < Struct.new( :recommender_schema_name, :fields, :created_at, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current operational status of the recommender schema.
8912 8913 8914 8915 8916 8917 8918 8919 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8912 class RecommenderSchemaSummary < Struct.new( :recommender_schema_name, :fields, :created_at, :status) SENSITIVE = [] include Aws::Structure end |