Class: Aws::CustomerProfiles::Types::RecommenderUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Contains information about an update operation performed on a recommender.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

The timestamp when this recommender update was initiated.



9655
9656
9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9655

class RecommenderUpdate < Struct.new(
  :recommender_config,
  :status,
  :created_at,
  :last_updated_at,
  :failure_reason,
  :recommender_version_name)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

If the update operation failed, provides the reason for the failure.



9655
9656
9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9655

class RecommenderUpdate < Struct.new(
  :recommender_config,
  :status,
  :created_at,
  :last_updated_at,
  :failure_reason,
  :recommender_version_name)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The timestamp of when the recommender was edited.



9655
9656
9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9655

class RecommenderUpdate < Struct.new(
  :recommender_config,
  :status,
  :created_at,
  :last_updated_at,
  :failure_reason,
  :recommender_version_name)
  SENSITIVE = []
  include Aws::Structure
end

#recommender_config ⇒ Types::RecommenderConfig

The updated configuration settings applied to the recommender during this update.



9655
9656
9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9655

class RecommenderUpdate < Struct.new(
  :recommender_config,
  :status,
  :created_at,
  :last_updated_at,
  :failure_reason,
  :recommender_version_name)
  SENSITIVE = []
  include Aws::Structure
end

#recommender_version_name ⇒ String

The name of the recommender version associated with this update operation.



9655
9656
9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9655

class RecommenderUpdate < Struct.new(
  :recommender_config,
  :status,
  :created_at,
  :last_updated_at,
  :failure_reason,
  :recommender_version_name)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the recommender update operation.



9655
9656
9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9655

class RecommenderUpdate < Struct.new(
  :recommender_config,
  :status,
  :created_at,
  :last_updated_at,
  :failure_reason,
  :recommender_version_name)
  SENSITIVE = []
  include Aws::Structure
end