Class: Aws::CustomerProfiles::Types::S3ExportingLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The S3 location where Identity Resolution Jobs write result files.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_bucket_name ⇒ String

The name of the S3 bucket name where Identity Resolution Jobs write result files.

Returns:

  • (String)


9898
9899
9900
9901
9902
9903
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9898

class S3ExportingLocation < Struct.new(
  :s3_bucket_name,
  :s3_key_name)
  SENSITIVE = []
  include Aws::Structure
end

#s3_key_name ⇒ String

The S3 key name of the location where Identity Resolution Jobs write result files.

Returns:

  • (String)


9898
9899
9900
9901
9902
9903
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9898

class S3ExportingLocation < Struct.new(
  :s3_bucket_name,
  :s3_key_name)
  SENSITIVE = []
  include Aws::Structure
end