Class: Aws::CustomerProfiles::Types::SalesforceSourceProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The properties that are applied when Salesforce is being used as a source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_dynamic_field_update ⇒ Boolean

The flag that enables dynamic fetching of new (recently added) fields in the Salesforce objects while running a flow.

Returns:

  • (Boolean)


9945
9946
9947
9948
9949
9950
9951
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9945

class SalesforceSourceProperties < Struct.new(
  :object,
  :enable_dynamic_field_update,
  :include_deleted_records)
  SENSITIVE = []
  include Aws::Structure
end

#include_deleted_records ⇒ Boolean

Indicates whether Amazon AppFlow includes deleted files in the flow run.

Returns:

  • (Boolean)


9945
9946
9947
9948
9949
9950
9951
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9945

class SalesforceSourceProperties < Struct.new(
  :object,
  :enable_dynamic_field_update,
  :include_deleted_records)
  SENSITIVE = []
  include Aws::Structure
end

#object ⇒ String

The object specified in the Salesforce flow source.

Returns:

  • (String)


9945
9946
9947
9948
9949
9950
9951
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9945

class SalesforceSourceProperties < Struct.new(
  :object,
  :enable_dynamic_field_update,
  :include_deleted_records)
  SENSITIVE = []
  include Aws::Structure
end