Class: Aws::CustomerProfiles::Types::SearchRecommendationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:key_values, :context]

Instance Attribute Summary collapse

Instance Attribute Details

#candidate_ids ⇒ Array<String>

A list of item IDs to rank for the user. Use this when you want to re-rank a specific set of items rather than getting recommendations from the full item catalog. Required for personalized-ranking use cases.

Returns:

  • (Array<String>)


10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10182

class SearchRecommendationsRequest < Struct.new(
  :domain_name,
  :key_name,
  :key_values,
  :recommender,
  :candidate_ids,
  :context,
  :diversity,
  :metadata,
  :max_recommendations)
  SENSITIVE = [:key_values, :context]
  include Aws::Structure
end

#context ⇒ Hash<String,String>

The contextual metadata used to provide dynamic runtime information to tailor recommendations.

Returns:

  • (Hash<String,String>)


10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10182

class SearchRecommendationsRequest < Struct.new(
  :domain_name,
  :key_name,
  :key_values,
  :recommender,
  :candidate_ids,
  :context,
  :diversity,
  :metadata,
  :max_recommendations)
  SENSITIVE = [:key_values, :context]
  include Aws::Structure
end

#diversity ⇒ Types::RecommendationDiversityConfig

Runtime diversity configuration for this request. Enables diversity-aware recommendations and optionally supplies values for placeholder-based diversity caps configured on the recommender.



10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10182

class SearchRecommendationsRequest < Struct.new(
  :domain_name,
  :key_name,
  :key_values,
  :recommender,
  :candidate_ids,
  :context,
  :diversity,
  :metadata,
  :max_recommendations)
  SENSITIVE = [:key_values, :context]
  include Aws::Structure
end

#domain_name ⇒ String

The unique name of the domain.

Returns:

  • (String)


10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10182

class SearchRecommendationsRequest < Struct.new(
  :domain_name,
  :key_name,
  :key_values,
  :recommender,
  :candidate_ids,
  :context,
  :diversity,
  :metadata,
  :max_recommendations)
  SENSITIVE = [:key_values, :context]
  include Aws::Structure
end

#key_name ⇒ String

A searchable identifier of a customer profile. You can use a predefined key, such as _profileId, _phone, or _email, or a custom-defined key.

Returns:

  • (String)


10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10182

class SearchRecommendationsRequest < Struct.new(
  :domain_name,
  :key_name,
  :key_values,
  :recommender,
  :candidate_ids,
  :context,
  :diversity,
  :metadata,
  :max_recommendations)
  SENSITIVE = [:key_values, :context]
  include Aws::Structure
end

#key_values ⇒ Array<String>

A list of key values. Provide one value for each field of the search key.

Returns:

  • (Array<String>)


10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10182

class SearchRecommendationsRequest < Struct.new(
  :domain_name,
  :key_name,
  :key_values,
  :recommender,
  :candidate_ids,
  :context,
  :diversity,
  :metadata,
  :max_recommendations)
  SENSITIVE = [:key_values, :context]
  include Aws::Structure
end

#max_recommendations ⇒ Integer

The maximum number of recommendations to return. The default value is 5.

Returns:

  • (Integer)


10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10182

class SearchRecommendationsRequest < Struct.new(
  :domain_name,
  :key_name,
  :key_values,
  :recommender,
  :candidate_ids,
  :context,
  :diversity,
  :metadata,
  :max_recommendations)
  SENSITIVE = [:key_values, :context]
  include Aws::Structure
end

#metadata ⇒ Types::RecommendationMetadata

Configuration for metadata to include in recommendation responses.



10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10182

class SearchRecommendationsRequest < Struct.new(
  :domain_name,
  :key_name,
  :key_values,
  :recommender,
  :candidate_ids,
  :context,
  :diversity,
  :metadata,
  :max_recommendations)
  SENSITIVE = [:key_values, :context]
  include Aws::Structure
end

#recommender ⇒ Types::Recommender

The recommender used to generate the recommendations.

Returns:



10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10182

class SearchRecommendationsRequest < Struct.new(
  :domain_name,
  :key_name,
  :key_values,
  :recommender,
  :candidate_ids,
  :context,
  :diversity,
  :metadata,
  :max_recommendations)
  SENSITIVE = [:key_values, :context]
  include Aws::Structure
end