Class: Aws::CustomerProfiles::Types::SourceConnectorProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Specifies the information that is required to query a particular Amazon AppFlow connector. Customer Profiles supports Salesforce, Zendesk, Marketo, ServiceNow and Amazon S3.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#marketo ⇒ Types::MarketoSourceProperties

The properties that are applied when Marketo is being used as a source.



10392
10393
10394
10395
10396
10397
10398
10399
10400
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10392

class SourceConnectorProperties < Struct.new(
  :marketo,
  :s3,
  :salesforce,
  :service_now,
  :zendesk)
  SENSITIVE = []
  include Aws::Structure
end

#s3 ⇒ Types::S3SourceProperties

The properties that are applied when Amazon S3 is being used as the flow source.



10392
10393
10394
10395
10396
10397
10398
10399
10400
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10392

class SourceConnectorProperties < Struct.new(
  :marketo,
  :s3,
  :salesforce,
  :service_now,
  :zendesk)
  SENSITIVE = []
  include Aws::Structure
end

#salesforce ⇒ Types::SalesforceSourceProperties

The properties that are applied when Salesforce is being used as a source.



10392
10393
10394
10395
10396
10397
10398
10399
10400
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10392

class SourceConnectorProperties < Struct.new(
  :marketo,
  :s3,
  :salesforce,
  :service_now,
  :zendesk)
  SENSITIVE = []
  include Aws::Structure
end

#service_now ⇒ Types::ServiceNowSourceProperties

The properties that are applied when ServiceNow is being used as a source.



10392
10393
10394
10395
10396
10397
10398
10399
10400
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10392

class SourceConnectorProperties < Struct.new(
  :marketo,
  :s3,
  :salesforce,
  :service_now,
  :zendesk)
  SENSITIVE = []
  include Aws::Structure
end

#zendesk ⇒ Types::ZendeskSourceProperties

The properties that are applied when using Zendesk as a flow source.



10392
10393
10394
10395
10396
10397
10398
10399
10400
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10392

class SourceConnectorProperties < Struct.new(
  :marketo,
  :s3,
  :salesforce,
  :service_now,
  :zendesk)
  SENSITIVE = []
  include Aws::Structure
end