Class: Aws::CustomerProfiles::Types::StartUploadJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The unique name of the domain containing the upload job to start.

Returns:

  • (String)


9016
9017
9018
9019
9020
9021
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9016

class StartUploadJobRequest < Struct.new(
  :domain_name,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier of the upload job to start.

Returns:

  • (String)


9016
9017
9018
9019
9020
9021
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9016

class StartUploadJobRequest < Struct.new(
  :domain_name,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end