Class: Aws::CustomerProfiles::Types::SubscriptionEventItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Represents a single segment membership event.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eventString

Whether the profile joined or left the segment. The following are valid values:

  • JOINED: The profile joined the segment.

  • LEFT: The profile left the segment.

Returns:

  • (String)


10442
10443
10444
10445
10446
10447
10448
10449
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10442

class SubscriptionEventItem < Struct.new(
  :profile_id,
  :updated_at,
  :event_type,
  :event)
  SENSITIVE = []
  include Aws::Structure
end

#event_typeString

The type of event that triggered the membership change. The following are valid values:

  • LIVE: Real-time event triggered by a profile or calculated attribute change (Classic segments only).

  • SCHEDULE: Event generated during a scheduled execution.

Returns:

  • (String)


10442
10443
10444
10445
10446
10447
10448
10449
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10442

class SubscriptionEventItem < Struct.new(
  :profile_id,
  :updated_at,
  :event_type,
  :event)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idString

The unique identifier of a customer profile.

Returns:

  • (String)


10442
10443
10444
10445
10446
10447
10448
10449
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10442

class SubscriptionEventItem < Struct.new(
  :profile_id,
  :updated_at,
  :event_type,
  :event)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when the membership change was detected.

Returns:

  • (Time)


10442
10443
10444
10445
10446
10447
10448
10449
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10442

class SubscriptionEventItem < Struct.new(
  :profile_id,
  :updated_at,
  :event_type,
  :event)
  SENSITIVE = []
  include Aws::Structure
end