Class: Aws::CustomerProfiles::Types::TrainingMetrics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Contains metrics and performance indicators from the training of a recommender model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metrics ⇒ Hash<String,Float>

A collection of performance metrics and statistics from the training process.

Returns:

  • (Hash<String,Float>)


10685
10686
10687
10688
10689
10690
10691
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10685

class TrainingMetrics < Struct.new(
  :time,
  :metrics,
  :recommender_version_name)
  SENSITIVE = []
  include Aws::Structure
end

#recommender_version_name ⇒ String

The name of the recommender version that produced these training metrics.

Returns:

  • (String)


10685
10686
10687
10688
10689
10690
10691
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10685

class TrainingMetrics < Struct.new(
  :time,
  :metrics,
  :recommender_version_name)
  SENSITIVE = []
  include Aws::Structure
end

#time ⇒ Time

The timestamp when these training metrics were recorded.

Returns:

  • (Time)


10685
10686
10687
10688
10689
10690
10691
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10685

class TrainingMetrics < Struct.new(
  :time,
  :metrics,
  :recommender_version_name)
  SENSITIVE = []
  include Aws::Structure
end