Class: Aws::CustomerProfiles::Types::TriggerConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The trigger settings that determine how and when Amazon AppFlow runs the specified flow.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#trigger_properties ⇒ Types::TriggerProperties

Specifies the configuration details of a schedule-triggered flow that you define. Currently, these settings only apply to the Scheduled trigger type.



10709
10710
10711
10712
10713
10714
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10709

class TriggerConfig < Struct.new(
  :trigger_type,
  :trigger_properties)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_type ⇒ String

Specifies the type of flow trigger. It can be OnDemand, Scheduled, or Event.

Returns:

  • (String)


10709
10710
10711
10712
10713
10714
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10709

class TriggerConfig < Struct.new(
  :trigger_type,
  :trigger_properties)
  SENSITIVE = []
  include Aws::Structure
end