Class: Aws::CustomerProfiles::Types::UpdateCalculatedAttributeDefinitionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :statistic, :conditions, :attribute_details]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_details ⇒ Types::AttributeDetails

The mathematical expression and a list of attribute items specified in that expression.



10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#calculated_attribute_name ⇒ String

The unique name of the calculated attribute.

Returns:

  • (String)


10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#conditions ⇒ Types::Conditions

The conditions including range, object count, and threshold for the calculated attribute.

Returns:



10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp of when the calculated attribute definition was created.

Returns:

  • (Time)


10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#description ⇒ String

The description of the calculated attribute.

Returns:

  • (String)


10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#display_name ⇒ String

The display name of the calculated attribute.

Returns:

  • (String)


10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#last_updated_at ⇒ Time

The timestamp of when the calculated attribute definition was most recently edited.

Returns:

  • (Time)


10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#readiness ⇒ Types::Readiness

Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.

Returns:



10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#statistic ⇒ String

The aggregation operation to perform for the calculated attribute.

Returns:

  • (String)


10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#status ⇒ String

Status of the Calculated Attribute creation (whether all historical data has been indexed.)

Returns:

  • (String)


10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end

#use_historical_data ⇒ Boolean

Whether historical data ingested before the Calculated Attribute was created should be included in calculations.

Returns:

  • (Boolean)


10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10904

class UpdateCalculatedAttributeDefinitionResponse < Struct.new(
  :calculated_attribute_name,
  :display_name,
  :description,
  :created_at,
  :last_updated_at,
  :statistic,
  :conditions,
  :attribute_details,
  :use_historical_data,
  :status,
  :readiness,
  :tags)
  SENSITIVE = [:description, :statistic, :conditions, :attribute_details]
  include Aws::Structure
end