Class: Aws::CustomerProfiles::Types::UpdateDomainLayoutRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :layout]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the layout

Returns:

  • (String)


10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10163

class UpdateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#display_nameString

The display name of the layout

Returns:

  • (String)


10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10163

class UpdateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10163

class UpdateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#is_defaultBoolean

If set to true for a layout, this layout will be used by default to view data. If set to false, then the layout will not be used by default, but it can be used to view data by explicitly selecting it in the console.

Returns:

  • (Boolean)


10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10163

class UpdateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#layoutString

A customizable layout that can be used to view data under a Customer Profiles domain.

Returns:

  • (String)


10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10163

class UpdateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#layout_definition_nameString

The unique name of the layout.

Returns:

  • (String)


10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10163

class UpdateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#layout_typeString

The type of layout that can be used to view data under a Customer Profiles domain.

Returns:

  • (String)


10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10163

class UpdateDomainLayoutRequest < Struct.new(
  :domain_name,
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end