Class: Aws::CustomerProfiles::Types::UpdateDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_storeTypes::DataStoreRequest

Set to true to enabled data store for this domain.



9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9584

class UpdateDomainRequest < Struct.new(
  :domain_name,
  :default_expiration_days,
  :default_encryption_key,
  :dead_letter_queue_url,
  :matching,
  :rule_based_matching,
  :data_store,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#dead_letter_queue_urlString

The URL of the SQS dead letter queue, which is used for reporting errors associated with ingesting data from third party applications. If specified as an empty string, it will clear any existing value. You must set up a policy on the DeadLetterQueue for the SendMessage operation to enable Amazon Connect Customer Profiles to send messages to the DeadLetterQueue.

Returns:

  • (String)


9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9584

class UpdateDomainRequest < Struct.new(
  :domain_name,
  :default_expiration_days,
  :default_encryption_key,
  :dead_letter_queue_url,
  :matching,
  :rule_based_matching,
  :data_store,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_encryption_keyString

The default encryption key, which is an AWS managed key, is used when no specific type of encryption key is specified. It is used to encrypt all data before it is placed in permanent or semi-permanent storage. If specified as an empty string, it will clear any existing value.

Returns:

  • (String)


9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9584

class UpdateDomainRequest < Struct.new(
  :domain_name,
  :default_expiration_days,
  :default_encryption_key,
  :dead_letter_queue_url,
  :matching,
  :rule_based_matching,
  :data_store,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_expiration_daysInteger

The default number of days until the data within the domain expires.

Returns:

  • (Integer)


9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9584

class UpdateDomainRequest < Struct.new(
  :domain_name,
  :default_expiration_days,
  :default_encryption_key,
  :dead_letter_queue_url,
  :matching,
  :rule_based_matching,
  :data_store,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9584

class UpdateDomainRequest < Struct.new(
  :domain_name,
  :default_expiration_days,
  :default_encryption_key,
  :dead_letter_queue_url,
  :matching,
  :rule_based_matching,
  :data_store,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#matchingTypes::MatchingRequest

The process of matching duplicate profiles. If ‘Matching` = `true`, Amazon Connect Customer Profiles starts a weekly batch process called Identity Resolution Job. If you do not specify a date and time for Identity Resolution Job to run, by default it runs every Saturday at 12AM UTC to detect duplicate profiles in your domains.

After the Identity Resolution Job completes, use the [GetMatches] API to return and review the results. Or, if you have configured ‘ExportingConfig` in the `MatchingRequest`, you can download the results from S3.

[1]: docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetMatches.html



9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9584

class UpdateDomainRequest < Struct.new(
  :domain_name,
  :default_expiration_days,
  :default_encryption_key,
  :dead_letter_queue_url,
  :matching,
  :rule_based_matching,
  :data_store,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rule_based_matchingTypes::RuleBasedMatchingRequest

The process of matching duplicate profiles using the rule-Based matching. If ‘RuleBasedMatching` = true, Amazon Connect Customer Profiles will start to match and merge your profiles according to your configuration in the `RuleBasedMatchingRequest`. You can use the `ListRuleBasedMatches` and `GetSimilarProfiles` API to return and review the results. Also, if you have configured `ExportingConfig` in the `RuleBasedMatchingRequest`, you can download the results from S3.



9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9584

class UpdateDomainRequest < Struct.new(
  :domain_name,
  :default_expiration_days,
  :default_encryption_key,
  :dead_letter_queue_url,
  :matching,
  :rule_based_matching,
  :data_store,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9584

class UpdateDomainRequest < Struct.new(
  :domain_name,
  :default_expiration_days,
  :default_encryption_key,
  :dead_letter_queue_url,
  :matching,
  :rule_based_matching,
  :data_store,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end