Class: Aws::CustomerProfiles::Types::UploadJobItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The summary information for an individual upload job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completed_at ⇒ Time

The timestamp when the upload job was completed.

Returns:

  • (Time)


11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
# File 'lib/aws-sdk-customerprofiles/types.rb', line 11528

class UploadJobItem < Struct.new(
  :job_id,
  :display_name,
  :status,
  :status_reason,
  :created_at,
  :completed_at,
  :data_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp when the upload job was created.

Returns:

  • (Time)


11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
# File 'lib/aws-sdk-customerprofiles/types.rb', line 11528

class UploadJobItem < Struct.new(
  :job_id,
  :display_name,
  :status,
  :status_reason,
  :created_at,
  :completed_at,
  :data_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#data_expiry ⇒ Integer

The expiry duration for the profiles ingested with the upload job.

Returns:

  • (Integer)


11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
# File 'lib/aws-sdk-customerprofiles/types.rb', line 11528

class UploadJobItem < Struct.new(
  :job_id,
  :display_name,
  :status,
  :status_reason,
  :created_at,
  :completed_at,
  :data_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#display_name ⇒ String

The name of the upload job.

Returns:

  • (String)


11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
# File 'lib/aws-sdk-customerprofiles/types.rb', line 11528

class UploadJobItem < Struct.new(
  :job_id,
  :display_name,
  :status,
  :status_reason,
  :created_at,
  :completed_at,
  :data_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#job_id ⇒ String

The unique identifier of the upload job.

Returns:

  • (String)


11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
# File 'lib/aws-sdk-customerprofiles/types.rb', line 11528

class UploadJobItem < Struct.new(
  :job_id,
  :display_name,
  :status,
  :status_reason,
  :created_at,
  :completed_at,
  :data_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the upload job.

Returns:

  • (String)


11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
# File 'lib/aws-sdk-customerprofiles/types.rb', line 11528

class UploadJobItem < Struct.new(
  :job_id,
  :display_name,
  :status,
  :status_reason,
  :created_at,
  :completed_at,
  :data_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#status_reason ⇒ String

The reason for the current status of the upload job.

Returns:

  • (String)


11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
# File 'lib/aws-sdk-customerprofiles/types.rb', line 11528

class UploadJobItem < Struct.new(
  :job_id,
  :display_name,
  :status,
  :status_reason,
  :created_at,
  :completed_at,
  :data_expiry)
  SENSITIVE = []
  include Aws::Structure
end