Class: Aws::CustomerProfiles::Types::ValueRange
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ValueRange
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
A structure letting customers specify a relative time window over which over which data is included in the Calculated Attribute. Use positive numbers to indicate that the endpoint is in the past, and negative numbers to indicate it is in the future. ValueRange overrides Value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end ⇒ Integer
The end time of when to include objects.
-
#start ⇒ Integer
The start time of when to include objects.
Instance Attribute Details
#end ⇒ Integer
The end time of when to include objects. Use positive numbers to indicate that the starting point is in the past, and negative numbers to indicate it is in the future.
10042 10043 10044 10045 10046 10047 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10042 class ValueRange < Struct.new( :start, :end) SENSITIVE = [] include Aws::Structure end |
#start ⇒ Integer
The start time of when to include objects. Use positive numbers to indicate that the starting point is in the past, and negative numbers to indicate it is in the future.
10042 10043 10044 10045 10046 10047 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10042 class ValueRange < Struct.new( :start, :end) SENSITIVE = [] include Aws::Structure end |