Class: Aws::CustomerProfiles::Types::AssociateStreamForSegmentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::AssociateStreamForSegmentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Kinesis data stream to deliver segment membership events to.
-
#destination_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that allows Customer Profiles service principal to assume the role for conducting AWS Key Management Service (KMS) and Amazon Kinesis operations.
-
#domain_name ⇒ String
The unique name of the domain.
Instance Attribute Details
#destination_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Kinesis data stream to
deliver segment membership events to. For example,
arn:aws:kinesis:region:account-id:stream/stream-name.
359 360 361 362 363 364 365 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 359 class AssociateStreamForSegmentsRequest < Struct.new( :domain_name, :destination_arn, :destination_role_arn) SENSITIVE = [] include Aws::Structure end |
#destination_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that allows Customer Profiles service principal to assume the role for conducting AWS Key Management Service (KMS) and Amazon Kinesis operations. The role must grant the following Amazon Kinesis permissions to deliver segment membership events to the stream:
-
kinesis:PutRecord -
kinesis:PutRecords -
kinesis:DescribeStream
359 360 361 362 363 364 365 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 359 class AssociateStreamForSegmentsRequest < Struct.new( :domain_name, :destination_arn, :destination_role_arn) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
359 360 361 362 363 364 365 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 359 class AssociateStreamForSegmentsRequest < Struct.new( :domain_name, :destination_arn, :destination_role_arn) SENSITIVE = [] include Aws::Structure end |