Class: Aws::CustomerProfiles::Types::BatchPutProfileObjectErrorItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::BatchPutProfileObjectErrorItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
An item that failed to be added to the domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ Integer
The HTTP status code for the error.
-
#id ⇒ String
The unique identifier of the item in the batch request that failed.
-
#message ⇒ String
A message describing the error.
Instance Attribute Details
#code ⇒ Integer
The HTTP status code for the error.
718 719 720 721 722 723 724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 718 class BatchPutProfileObjectErrorItem < Struct.new( :id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the item in the batch request that failed.
718 719 720 721 722 723 724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 718 class BatchPutProfileObjectErrorItem < Struct.new( :id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message describing the error.
718 719 720 721 722 723 724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 718 class BatchPutProfileObjectErrorItem < Struct.new( :id, :code, :message) SENSITIVE = [] include Aws::Structure end |