Class: Aws::CustomerProfiles::Types::BatchPutProfileObjectResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::BatchPutProfileObjectResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed ⇒ Array<Types::BatchPutProfileObjectErrorItem>
A list of items that failed to be added to the domain.
-
#successful ⇒ Array<Types::BatchPutProfileObjectResponseItem>
A list of items that were successfully added to the domain.
Instance Attribute Details
#failed ⇒ Array<Types::BatchPutProfileObjectErrorItem>
A list of items that failed to be added to the domain.
778 779 780 781 782 783 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 778 class BatchPutProfileObjectResponse < Struct.new( :successful, :failed) SENSITIVE = [] include Aws::Structure end |
#successful ⇒ Array<Types::BatchPutProfileObjectResponseItem>
A list of items that were successfully added to the domain.
778 779 780 781 782 783 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 778 class BatchPutProfileObjectResponse < Struct.new( :successful, :failed) SENSITIVE = [] include Aws::Structure end |