Class: Aws::CustomerProfiles::Types::BatchPutProfileObjectResponseItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::BatchPutProfileObjectResponseItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
An item that was successfully added to the domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier of the item in the batch request.
-
#profile_object_unique_key ⇒ String
The unique identifier of the profile object generated by the service.
Instance Attribute Details
#id ⇒ String
The unique identifier of the item in the batch request.
798 799 800 801 802 803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 798 class BatchPutProfileObjectResponseItem < Struct.new( :id, :profile_object_unique_key) SENSITIVE = [] include Aws::Structure end |
#profile_object_unique_key ⇒ String
The unique identifier of the profile object generated by the service.
798 799 800 801 802 803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 798 class BatchPutProfileObjectResponseItem < Struct.new( :id, :profile_object_unique_key) SENSITIVE = [] include Aws::Structure end |