Class: Aws::CustomerProfiles::Types::CreateDomainLayoutRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::CreateDomainLayoutRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :layout]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the layout.
-
#display_name ⇒ String
The display name of the layout.
-
#domain_name ⇒ String
The unique name of the domain.
-
#is_default ⇒ Boolean
If set to true for a layout, this layout will be used by default to view data.
-
#layout ⇒ String
A customizable layout that can be used to view data under a Customer Profiles domain.
-
#layout_definition_name ⇒ String
The unique name of the layout.
-
#layout_type ⇒ String
The type of layout that can be used to view data under a Customer Profiles domain.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#description ⇒ String
The description of the layout
1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1283 class CreateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#display_name ⇒ String
The display name of the layout
1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1283 class CreateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1283 class CreateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#is_default ⇒ Boolean
If set to true for a layout, this layout will be used by default to view data. If set to false, then the layout will not be used by default, but it can be used to view data by explicitly selecting it in the console.
1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1283 class CreateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#layout ⇒ String
A customizable layout that can be used to view data under a Customer Profiles domain.
1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1283 class CreateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#layout_definition_name ⇒ String
The unique name of the layout.
1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1283 class CreateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#layout_type ⇒ String
The type of layout that can be used to view data under a Customer Profiles domain.
1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1283 class CreateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1283 class CreateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |