Class: Aws::CustomerProfiles::Types::CreateEventTriggerResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :event_trigger_conditions]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the event trigger was created.

Returns:

  • (Time)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1656

class CreateEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#descriptionString

The description of the event trigger.

Returns:

  • (String)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1656

class CreateEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#event_trigger_conditionsArray<Types::EventTriggerCondition>

A list of conditions that determine when an event should trigger the destination.

Returns:



1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1656

class CreateEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#event_trigger_limitsTypes::EventTriggerLimits

Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.



1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1656

class CreateEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#event_trigger_nameString

The unique name of the event trigger.

Returns:

  • (String)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1656

class CreateEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the event trigger was most recently updated.

Returns:

  • (Time)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1656

class CreateEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#object_type_nameString

The unique name of the object type.

Returns:

  • (String)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1656

class CreateEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#segment_filterString

The destination is triggered only for profiles that meet the criteria of a segment definition.

Returns:

  • (String)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1656

class CreateEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#tagsHash<String,String>

An array of key-value pairs to apply to this resource.

Returns:

  • (Hash<String,String>)


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1656

class CreateEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end