Class: Aws::CustomerProfiles::Types::CreateRecommenderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the domain object type.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1972

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1972

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_configTypes::RecommenderConfig

The recommender configuration.



1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1972

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_nameString

The name of the recommender.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1972

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_recipe_nameString

The name of the recommeder recipe.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1972

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_schema_nameString

The name of the recommender schema to use for this recommender. If not specified, the default schema is used.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1972

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1972

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end