Class: Aws::CustomerProfiles::Types::CreateRecommenderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the domain object type.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1869

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1869

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_configTypes::RecommenderConfig

The recommender configuration.



1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1869

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_nameString

The name of the recommender.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1869

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_recipe_nameString

The name of the recommeder recipe.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1869

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_schema_nameString

The name of the recommender schema to use for this recommender. If not specified, the default schema is used.

Returns:

  • (String)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1869

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1869

class CreateRecommenderRequest < Struct.new(
  :domain_name,
  :recommender_name,
  :recommender_recipe_name,
  :recommender_config,
  :description,
  :recommender_schema_name,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end