Class: Aws::CustomerProfiles::Types::CreateRecommenderSchemaRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::CreateRecommenderSchemaRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#fields ⇒ Hash<String,Array<Types::RecommenderSchemaField>>
A map of dataset type to column definitions that specifies which data columns to include in the schema.
-
#recommender_schema_name ⇒ String
The name of the recommender schema.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
1921 1922 1923 1924 1925 1926 1927 1928 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1921 class CreateRecommenderSchemaRequest < Struct.new( :domain_name, :recommender_schema_name, :fields, :tags) SENSITIVE = [] include Aws::Structure end |
#fields ⇒ Hash<String,Array<Types::RecommenderSchemaField>>
A map of dataset type to column definitions that specifies which data columns to include in the schema. Currently only the ‘_webAnalytics` key is supported.
1921 1922 1923 1924 1925 1926 1927 1928 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1921 class CreateRecommenderSchemaRequest < Struct.new( :domain_name, :recommender_schema_name, :fields, :tags) SENSITIVE = [] include Aws::Structure end |
#recommender_schema_name ⇒ String
The name of the recommender schema. The name must be unique within the domain.
1921 1922 1923 1924 1925 1926 1927 1928 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1921 class CreateRecommenderSchemaRequest < Struct.new( :domain_name, :recommender_schema_name, :fields, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
1921 1922 1923 1924 1925 1926 1927 1928 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 1921 class CreateRecommenderSchemaRequest < Struct.new( :domain_name, :recommender_schema_name, :fields, :tags) SENSITIVE = [] include Aws::Structure end |