Class: Aws::CustomerProfiles::Types::CreateRecommenderSchemaResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the recommender schema was created.

Returns:

  • (Time)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2060

class CreateRecommenderSchemaResponse < Struct.new(
  :recommender_schema_arn,
  :recommender_schema_name,
  :fields,
  :created_at,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#fieldsHash<String,Array<Types::RecommenderSchemaField>>

A map of dataset type to column definitions included in the schema.

Returns:



2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2060

class CreateRecommenderSchemaResponse < Struct.new(
  :recommender_schema_arn,
  :recommender_schema_name,
  :fields,
  :created_at,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#recommender_schema_arnString

The Amazon Resource Name (ARN) of the recommender schema.

Returns:

  • (String)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2060

class CreateRecommenderSchemaResponse < Struct.new(
  :recommender_schema_arn,
  :recommender_schema_name,
  :fields,
  :created_at,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#recommender_schema_nameString

The name of the recommender schema.

Returns:

  • (String)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2060

class CreateRecommenderSchemaResponse < Struct.new(
  :recommender_schema_arn,
  :recommender_schema_name,
  :fields,
  :created_at,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the recommender schema.

Returns:

  • (String)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2060

class CreateRecommenderSchemaResponse < Struct.new(
  :recommender_schema_arn,
  :recommender_schema_name,
  :fields,
  :created_at,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2060

class CreateRecommenderSchemaResponse < Struct.new(
  :recommender_schema_arn,
  :recommender_schema_name,
  :fields,
  :created_at,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end