Class: Aws::CustomerProfiles::Types::CreateSegmentSnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::CreateSegmentSnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_format ⇒ String
The format in which the segment will be exported.
-
#destination_uri ⇒ String
The destination to which the segment will be exported.
-
#domain_name ⇒ String
The unique name of the domain.
-
#encryption_key ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the exported segment.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that allows Customer Profiles service principal to assume the role for conducting KMS and S3 operations.
-
#segment_definition_name ⇒ String
The name of the segment definition used in this snapshot request.
Instance Attribute Details
#data_format ⇒ String
The format in which the segment will be exported.
2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2132 class CreateSegmentSnapshotRequest < Struct.new( :domain_name, :segment_definition_name, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#destination_uri ⇒ String
The destination to which the segment will be exported. This field must be provided if the request is not submitted from the Amazon Connect Admin Website.
2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2132 class CreateSegmentSnapshotRequest < Struct.new( :domain_name, :segment_definition_name, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2132 class CreateSegmentSnapshotRequest < Struct.new( :domain_name, :segment_definition_name, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#encryption_key ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the exported segment.
2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2132 class CreateSegmentSnapshotRequest < Struct.new( :domain_name, :segment_definition_name, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that allows Customer Profiles service principal to assume the role for conducting KMS and S3 operations.
2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2132 class CreateSegmentSnapshotRequest < Struct.new( :domain_name, :segment_definition_name, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |
#segment_definition_name ⇒ String
The name of the segment definition used in this snapshot request.
2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2132 class CreateSegmentSnapshotRequest < Struct.new( :domain_name, :segment_definition_name, :data_format, :encryption_key, :role_arn, :destination_uri) SENSITIVE = [] include Aws::Structure end |