Class: Aws::CustomerProfiles::Types::DataStoreResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::DataStoreResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
The data store response.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
True if data store is enabled for this domain.
-
#readiness ⇒ Types::Readiness
Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.
Instance Attribute Details
#enabled ⇒ Boolean
True if data store is enabled for this domain
2150 2151 2152 2153 2154 2155 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2150 class DataStoreResponse < Struct.new( :enabled, :readiness) SENSITIVE = [] include Aws::Structure end |
#readiness ⇒ Types::Readiness
Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.
2150 2151 2152 2153 2154 2155 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2150 class DataStoreResponse < Struct.new( :enabled, :readiness) SENSITIVE = [] include Aws::Structure end |