Class: Aws::CustomerProfiles::Types::Dimension

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Note:

Dimension is a union - when making an API calls you must set exactly one of the members.

Note:

Dimension is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Dimension corresponding to the set member.

Object that holds what profile and calculated attributes to segment on.

Direct Known Subclasses

CalculatedAttributes, ProfileAttributes, Unknown

Defined Under Namespace

Classes: CalculatedAttributes, ProfileAttributes, Unknown

Constant Summary collapse

SENSITIVE =
[:profile_attributes]

Instance Attribute Summary collapse

Instance Attribute Details

#calculated_attributesHash<String,Types::CalculatedAttributeDimension>

Object that holds the calculated attributes to segment on.

Returns:



2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2787

class Dimension < Struct.new(
  :profile_attributes,
  :calculated_attributes,
  :unknown)
  SENSITIVE = [:profile_attributes]
  include Aws::Structure
  include Aws::Structure::Union

  class ProfileAttributes < Dimension; end
  class CalculatedAttributes < Dimension; end
  class Unknown < Dimension; end
end

#profile_attributesTypes::ProfileAttributes

Object that holds the profile attributes to segment on.



2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2787

class Dimension < Struct.new(
  :profile_attributes,
  :calculated_attributes,
  :unknown)
  SENSITIVE = [:profile_attributes]
  include Aws::Structure
  include Aws::Structure::Union

  class ProfileAttributes < Dimension; end
  class CalculatedAttributes < Dimension; end
  class Unknown < Dimension; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2787
2788
2789
# File 'lib/aws-sdk-customerprofiles/types.rb', line 2787

def unknown
  @unknown
end