Class: Aws::CustomerProfiles::Types::FlowDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::FlowDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
The configurations that control how Customer Profiles retrieves data from the source, Amazon AppFlow. Customer Profiles uses this information to create an AppFlow flow on behalf of customers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the flow you want to create.
-
#flow_name ⇒ String
The specified name of the flow.
-
#kms_arn ⇒ String
The Amazon Resource Name of the AWS Key Management Service (KMS) key you provide for encryption.
-
#source_flow_config ⇒ Types::SourceFlowConfig
The configuration that controls how Customer Profiles retrieves data from the source.
-
#tasks ⇒ Array<Types::Task>
A list of tasks that Customer Profiles performs while transferring the data in the flow run.
-
#trigger_config ⇒ Types::TriggerConfig
The trigger settings that determine how and when the flow runs.
Instance Attribute Details
#description ⇒ String
A description of the flow you want to create.
3432 3433 3434 3435 3436 3437 3438 3439 3440 3441 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3432 class FlowDefinition < Struct.new( :description, :flow_name, :kms_arn, :source_flow_config, :tasks, :trigger_config) SENSITIVE = [] include Aws::Structure end |
#flow_name ⇒ String
The specified name of the flow. Use underscores (_) or hyphens (-) only. Spaces are not allowed.
3432 3433 3434 3435 3436 3437 3438 3439 3440 3441 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3432 class FlowDefinition < Struct.new( :description, :flow_name, :kms_arn, :source_flow_config, :tasks, :trigger_config) SENSITIVE = [] include Aws::Structure end |
#kms_arn ⇒ String
The Amazon Resource Name of the AWS Key Management Service (KMS) key you provide for encryption.
3432 3433 3434 3435 3436 3437 3438 3439 3440 3441 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3432 class FlowDefinition < Struct.new( :description, :flow_name, :kms_arn, :source_flow_config, :tasks, :trigger_config) SENSITIVE = [] include Aws::Structure end |
#source_flow_config ⇒ Types::SourceFlowConfig
The configuration that controls how Customer Profiles retrieves data from the source.
3432 3433 3434 3435 3436 3437 3438 3439 3440 3441 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3432 class FlowDefinition < Struct.new( :description, :flow_name, :kms_arn, :source_flow_config, :tasks, :trigger_config) SENSITIVE = [] include Aws::Structure end |
#tasks ⇒ Array<Types::Task>
A list of tasks that Customer Profiles performs while transferring the data in the flow run.
3432 3433 3434 3435 3436 3437 3438 3439 3440 3441 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3432 class FlowDefinition < Struct.new( :description, :flow_name, :kms_arn, :source_flow_config, :tasks, :trigger_config) SENSITIVE = [] include Aws::Structure end |
#trigger_config ⇒ Types::TriggerConfig
The trigger settings that determine how and when the flow runs.
3432 3433 3434 3435 3436 3437 3438 3439 3440 3441 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3432 class FlowDefinition < Struct.new( :description, :flow_name, :kms_arn, :source_flow_config, :tasks, :trigger_config) SENSITIVE = [] include Aws::Structure end |