Class: Aws::CustomerProfiles::Types::GetCalculatedAttributeDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetCalculatedAttributeDefinitionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :statistic, :conditions, :attribute_details]
Instance Attribute Summary collapse
-
#attribute_details ⇒ Types::AttributeDetails
Mathematical expression and a list of attribute items specified in that expression.
-
#calculated_attribute_name ⇒ String
The unique name of the calculated attribute.
-
#conditions ⇒ Types::Conditions
The conditions including range, object count, and threshold for the calculated attribute.
-
#created_at ⇒ Time
The timestamp of when the calculated attribute definition was created.
-
#description ⇒ String
The description of the calculated attribute.
-
#display_name ⇒ String
The display name of the calculated attribute.
-
#filter ⇒ Types::Filter
The filter assigned to this calculated attribute definition.
-
#last_updated_at ⇒ Time
The timestamp of when the calculated attribute definition was most recently edited.
-
#readiness ⇒ Types::Readiness
Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.
-
#statistic ⇒ String
The aggregation operation to perform for the calculated attribute.
-
#status ⇒ String
Status of the Calculated Attribute creation (whether all historical data has been indexed).
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#use_historical_data ⇒ Boolean
Whether historical data ingested before the Calculated Attribute was created should be included in calculations.
Instance Attribute Details
#attribute_details ⇒ Types::AttributeDetails
Mathematical expression and a list of attribute items specified in that expression.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#calculated_attribute_name ⇒ String
The unique name of the calculated attribute.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#conditions ⇒ Types::Conditions
The conditions including range, object count, and threshold for the calculated attribute.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the calculated attribute definition was created.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#description ⇒ String
The description of the calculated attribute.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#display_name ⇒ String
The display name of the calculated attribute.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#filter ⇒ Types::Filter
The filter assigned to this calculated attribute definition.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the calculated attribute definition was most recently edited.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#readiness ⇒ Types::Readiness
Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#statistic ⇒ String
The aggregation operation to perform for the calculated attribute.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#status ⇒ String
Status of the Calculated Attribute creation (whether all historical data has been indexed).
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#use_historical_data ⇒ Boolean
Whether historical data ingested before the Calculated Attribute was created should be included in calculations.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3503 class GetCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :filter, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |