Class: Aws::CustomerProfiles::Types::GetDomainResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetDomainResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the domain was created.
-
#data_store ⇒ Types::DataStoreResponse
True if data store is enabled for this domain.
-
#dead_letter_queue_url ⇒ String
The URL of the SQS dead letter queue, which is used for reporting errors associated with ingesting data from third party applications.
-
#default_encryption_key ⇒ String
The default encryption key, which is an AWS managed key, is used when no specific type of encryption key is specified.
-
#default_expiration_days ⇒ Integer
The default number of days until the data within the domain expires.
-
#domain_name ⇒ String
The unique name of the domain.
-
#last_updated_at ⇒ Time
The timestamp of when the domain was most recently edited.
-
#matching ⇒ Types::MatchingResponse
The process of matching duplicate profiles.
-
#rule_based_matching ⇒ Types::RuleBasedMatchingResponse
The process of matching duplicate profiles using the Rule-Based matching.
-
#stats ⇒ Types::DomainStats
Usage-specific statistics about the domain.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the domain was created.
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#data_store ⇒ Types::DataStoreResponse
True if data store is enabled for this domain.
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#dead_letter_queue_url ⇒ String
The URL of the SQS dead letter queue, which is used for reporting errors associated with ingesting data from third party applications.
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#default_encryption_key ⇒ String
The default encryption key, which is an AWS managed key, is used when no specific type of encryption key is specified. It is used to encrypt all data before it is placed in permanent or semi-permanent storage.
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#default_expiration_days ⇒ Integer
The default number of days until the data within the domain expires.
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the domain was most recently edited.
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#matching ⇒ Types::MatchingResponse
The process of matching duplicate profiles. If ‘Matching` = `true`, Amazon Connect Customer Profiles starts a weekly batch process called Identity Resolution Job. If you do not specify a date and time for Identity Resolution Job to run, by default it runs every Saturday at 12AM UTC to detect duplicate profiles in your domains.
After the Identity Resolution Job completes, use the [GetMatches] API to return and review the results. Or, if you have configured ‘ExportingConfig` in the `MatchingRequest`, you can download the results from S3.
[1]: docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetMatches.html
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#rule_based_matching ⇒ Types::RuleBasedMatchingResponse
The process of matching duplicate profiles using the Rule-Based matching. If ‘RuleBasedMatching` = true, Amazon Connect Customer Profiles will start to match and merge your profiles according to your configuration in the `RuleBasedMatchingRequest`. You can use the `ListRuleBasedMatches` and `GetSimilarProfiles` API to return and review the results. Also, if you have configured `ExportingConfig` in the `RuleBasedMatchingRequest`, you can download the results from S3.
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#stats ⇒ Types::DomainStats
Usage-specific statistics about the domain.
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 3710 class GetDomainResponse < Struct.new( :domain_name, :default_expiration_days, :default_encryption_key, :dead_letter_queue_url, :stats, :matching, :rule_based_matching, :data_store, :created_at, :last_updated_at, :tags) SENSITIVE = [] include Aws::Structure end |