Class: Aws::CustomerProfiles::Types::GetEventTriggerResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetEventTriggerResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :event_trigger_conditions]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the event trigger was created.
-
#description ⇒ String
The description of the event trigger.
-
#event_trigger_conditions ⇒ Array<Types::EventTriggerCondition>
A list of conditions that determine when an event should trigger the destination.
-
#event_trigger_limits ⇒ Types::EventTriggerLimits
Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.
-
#event_trigger_name ⇒ String
The unique name of the event trigger.
-
#last_updated_at ⇒ Time
The timestamp of when the event trigger was most recently updated.
-
#object_type_name ⇒ String
The unique name of the object type.
-
#segment_filter ⇒ String
The destination is triggered only for profiles that meet the criteria of a segment definition.
-
#tags ⇒ Hash<String,String>
An array of key-value pairs to apply to this resource.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the event trigger was created.
4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4331 class GetEventTriggerResponse < Struct.new( :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#description ⇒ String
The description of the event trigger.
4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4331 class GetEventTriggerResponse < Struct.new( :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#event_trigger_conditions ⇒ Array<Types::EventTriggerCondition>
A list of conditions that determine when an event should trigger the destination.
4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4331 class GetEventTriggerResponse < Struct.new( :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#event_trigger_limits ⇒ Types::EventTriggerLimits
Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.
4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4331 class GetEventTriggerResponse < Struct.new( :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#event_trigger_name ⇒ String
The unique name of the event trigger.
4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4331 class GetEventTriggerResponse < Struct.new( :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the event trigger was most recently updated.
4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4331 class GetEventTriggerResponse < Struct.new( :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#object_type_name ⇒ String
The unique name of the object type.
4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4331 class GetEventTriggerResponse < Struct.new( :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#segment_filter ⇒ String
The destination is triggered only for profiles that meet the criteria of a segment definition.
4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4331 class GetEventTriggerResponse < Struct.new( :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An array of key-value pairs to apply to this resource.
4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4331 class GetEventTriggerResponse < Struct.new( :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |