Class: Aws::CustomerProfiles::Types::GetEventTriggerResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :event_trigger_conditions]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the event trigger was created.

Returns:

  • (Time)


4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4143

class GetEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#descriptionString

The description of the event trigger.

Returns:

  • (String)


4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4143

class GetEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#event_trigger_conditionsArray<Types::EventTriggerCondition>

A list of conditions that determine when an event should trigger the destination.

Returns:



4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4143

class GetEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#event_trigger_limitsTypes::EventTriggerLimits

Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.



4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4143

class GetEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#event_trigger_nameString

The unique name of the event trigger.

Returns:

  • (String)


4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4143

class GetEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the event trigger was most recently updated.

Returns:

  • (Time)


4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4143

class GetEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#object_type_nameString

The unique name of the object type.

Returns:

  • (String)


4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4143

class GetEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#segment_filterString

The destination is triggered only for profiles that meet the criteria of a segment definition.

Returns:

  • (String)


4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4143

class GetEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end

#tagsHash<String,String>

An array of key-value pairs to apply to this resource.

Returns:

  • (Hash<String,String>)


4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4143

class GetEventTriggerResponse < Struct.new(
  :event_trigger_name,
  :object_type_name,
  :description,
  :event_trigger_conditions,
  :segment_filter,
  :event_trigger_limits,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :event_trigger_conditions]
  include Aws::Structure
end