Class: Aws::CustomerProfiles::Types::GetMatchesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetMatchesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
4274 4275 4276 4277 4278 4279 4280 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4274 class GetMatchesRequest < Struct.new( :next_token, :max_results, :domain_name) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
4274 4275 4276 4277 4278 4279 4280 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4274 class GetMatchesRequest < Struct.new( :next_token, :max_results, :domain_name) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
4274 4275 4276 4277 4278 4279 4280 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4274 class GetMatchesRequest < Struct.new( :next_token, :max_results, :domain_name) SENSITIVE = [] include Aws::Structure end |