Class: Aws::CustomerProfiles::Types::GetProfileRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetProfileRecommendationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:context]
Instance Attribute Summary collapse
-
#candidate_ids ⇒ Array<String>
A list of item IDs to rank for the user.
-
#context ⇒ Hash<String,String>
The contextual metadata used to provide dynamic runtime information to tailor recommendations.
-
#diversity_config ⇒ Types::RecommendationDiversityConfig
Runtime diversity configuration for this request.
-
#domain_name ⇒ String
The unique name of the domain.
-
#max_results ⇒ Integer
The maximum number of recommendations to return.
-
#metadata_config ⇒ Types::MetadataConfig
Configuration for including item metadata in the recommendation response.
-
#profile_id ⇒ String
The unique identifier of the profile for which to retrieve recommendations.
-
#recommender_filters ⇒ Array<Types::RecommenderFilter>
A list of filters to apply to the returned recommendations.
-
#recommender_name ⇒ String
The unique name of the recommender.
-
#recommender_promotional_filters ⇒ Array<Types::RecommenderPromotionalFilter>
A list of promotional filters to apply to the recommendations.
Instance Attribute Details
#candidate_ids ⇒ Array<String>
A list of item IDs to rank for the user. Use this when you want to re-rank a specific set of items rather than getting recommendations from the full item catalog. Required for personalized-ranking use cases.
4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4870 class GetProfileRecommendationsRequest < Struct.new( :domain_name, :profile_id, :recommender_name, :context, :recommender_filters, :recommender_promotional_filters, :candidate_ids, :max_results, :metadata_config, :diversity_config) SENSITIVE = [:context] include Aws::Structure end |
#context ⇒ Hash<String,String>
The contextual metadata used to provide dynamic runtime information to tailor recommendations.
4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4870 class GetProfileRecommendationsRequest < Struct.new( :domain_name, :profile_id, :recommender_name, :context, :recommender_filters, :recommender_promotional_filters, :candidate_ids, :max_results, :metadata_config, :diversity_config) SENSITIVE = [:context] include Aws::Structure end |
#diversity_config ⇒ Types::RecommendationDiversityConfig
Runtime diversity configuration for this request. Enables diversity-aware recommendations and optionally supplies values for placeholder-based diversity caps configured on the recommender.
4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4870 class GetProfileRecommendationsRequest < Struct.new( :domain_name, :profile_id, :recommender_name, :context, :recommender_filters, :recommender_promotional_filters, :candidate_ids, :max_results, :metadata_config, :diversity_config) SENSITIVE = [:context] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4870 class GetProfileRecommendationsRequest < Struct.new( :domain_name, :profile_id, :recommender_name, :context, :recommender_filters, :recommender_promotional_filters, :candidate_ids, :max_results, :metadata_config, :diversity_config) SENSITIVE = [:context] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of recommendations to return. The default value is 10.
4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4870 class GetProfileRecommendationsRequest < Struct.new( :domain_name, :profile_id, :recommender_name, :context, :recommender_filters, :recommender_promotional_filters, :candidate_ids, :max_results, :metadata_config, :diversity_config) SENSITIVE = [:context] include Aws::Structure end |
#metadata_config ⇒ Types::MetadataConfig
Configuration for including item metadata in the recommendation response. Use this to specify which metadata columns to return alongside recommended items.
4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4870 class GetProfileRecommendationsRequest < Struct.new( :domain_name, :profile_id, :recommender_name, :context, :recommender_filters, :recommender_promotional_filters, :candidate_ids, :max_results, :metadata_config, :diversity_config) SENSITIVE = [:context] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier of the profile for which to retrieve recommendations.
4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4870 class GetProfileRecommendationsRequest < Struct.new( :domain_name, :profile_id, :recommender_name, :context, :recommender_filters, :recommender_promotional_filters, :candidate_ids, :max_results, :metadata_config, :diversity_config) SENSITIVE = [:context] include Aws::Structure end |
#recommender_filters ⇒ Array<Types::RecommenderFilter>
A list of filters to apply to the returned recommendations. Filters define criteria for including or excluding items from the recommendation results.
4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4870 class GetProfileRecommendationsRequest < Struct.new( :domain_name, :profile_id, :recommender_name, :context, :recommender_filters, :recommender_promotional_filters, :candidate_ids, :max_results, :metadata_config, :diversity_config) SENSITIVE = [:context] include Aws::Structure end |
#recommender_name ⇒ String
The unique name of the recommender.
4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4870 class GetProfileRecommendationsRequest < Struct.new( :domain_name, :profile_id, :recommender_name, :context, :recommender_filters, :recommender_promotional_filters, :candidate_ids, :max_results, :metadata_config, :diversity_config) SENSITIVE = [:context] include Aws::Structure end |
#recommender_promotional_filters ⇒ Array<Types::RecommenderPromotionalFilter>
A list of promotional filters to apply to the recommendations. Promotional filters allow you to promote specific items within a configurable subset of recommendation results.
4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4870 class GetProfileRecommendationsRequest < Struct.new( :domain_name, :profile_id, :recommender_name, :context, :recommender_filters, :recommender_promotional_filters, :candidate_ids, :max_results, :metadata_config, :diversity_config) SENSITIVE = [:context] include Aws::Structure end |