Class: Aws::CustomerProfiles::Types::GetProfileRecommendationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:context]

Instance Attribute Summary collapse

Instance Attribute Details

#candidate_idsArray<String>

A list of item IDs to rank for the user. Use this when you want to re-rank a specific set of items rather than getting recommendations from the full item catalog. Required for personalized-ranking use cases.

Returns:

  • (Array<String>)


4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#contextHash<String,String>

The contextual metadata used to provide dynamic runtime information to tailor recommendations.

Returns:

  • (Hash<String,String>)


4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#max_resultsInteger

The maximum number of recommendations to return. The default value is 10.

Returns:

  • (Integer)


4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#metadata_configTypes::MetadataConfig

Configuration for including item metadata in the recommendation response. Use this to specify which metadata columns to return alongside recommended items.



4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#profile_idString

The unique identifier of the profile for which to retrieve recommendations.

Returns:

  • (String)


4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#recommender_filtersArray<Types::RecommenderFilter>

A list of filters to apply to the returned recommendations. Filters define criteria for including or excluding items from the recommendation results.

Returns:



4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#recommender_nameString

The unique name of the recommender.

Returns:

  • (String)


4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config)
  SENSITIVE = [:context]
  include Aws::Structure
end

#recommender_promotional_filtersArray<Types::RecommenderPromotionalFilter>

A list of promotional filters to apply to the recommendations. Promotional filters allow you to promote specific items within a configurable subset of recommendation results.



4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4713

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :recommender_filters,
  :recommender_promotional_filters,
  :candidate_ids,
  :max_results,
  :metadata_config)
  SENSITIVE = [:context]
  include Aws::Structure
end