Class: Aws::CustomerProfiles::Types::GetProfileRecommendationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:context]

Instance Attribute Summary collapse

Instance Attribute Details

#contextHash<String,String>

The contextual metadata used to provide dynamic runtime information to tailor recommendations.

Returns:

  • (Hash<String,String>)


4493
4494
4495
4496
4497
4498
4499
4500
4501
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4493

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :max_results)
  SENSITIVE = [:context]
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


4493
4494
4495
4496
4497
4498
4499
4500
4501
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4493

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :max_results)
  SENSITIVE = [:context]
  include Aws::Structure
end

#max_resultsInteger

The maximum number of recommendations to return. The default value is 10.

Returns:

  • (Integer)


4493
4494
4495
4496
4497
4498
4499
4500
4501
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4493

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :max_results)
  SENSITIVE = [:context]
  include Aws::Structure
end

#profile_idString

The unique identifier of the profile for which to retrieve recommendations.

Returns:

  • (String)


4493
4494
4495
4496
4497
4498
4499
4500
4501
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4493

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :max_results)
  SENSITIVE = [:context]
  include Aws::Structure
end

#recommender_nameString

The unique name of the recommender.

Returns:

  • (String)


4493
4494
4495
4496
4497
4498
4499
4500
4501
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4493

class GetProfileRecommendationsRequest < Struct.new(
  :domain_name,
  :profile_id,
  :recommender_name,
  :context,
  :max_results)
  SENSITIVE = [:context]
  include Aws::Structure
end