Class: Aws::CustomerProfiles::Types::GetRecommenderResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetRecommenderResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#active_recommender_version_name ⇒ String
The name of the recommender version currently serving recommendations.
-
#created_at ⇒ Time
The timestamp of when the recommender was created.
-
#description ⇒ String
A detailed description of the recommender providing information about its purpose and functionality.
-
#failure_reason ⇒ String
If the recommender fails, provides the reason for the failure.
-
#last_updated_at ⇒ Time
The timestamp of when the recommender was edited.
-
#latest_recommender_update ⇒ Types::RecommenderUpdate
Information about the most recent update performed on the recommender, including status and timestamp.
-
#recommender_config ⇒ Types::RecommenderConfig
The configuration settings for the recommender, including parameters and settings that define its behavior.
-
#recommender_name ⇒ String
The name of the recommender.
-
#recommender_recipe_name ⇒ String
The name of the recipe used by the recommender to generate recommendations.
-
#recommender_schema_name ⇒ String
The name of the recommender schema associated with this recommender.
-
#status ⇒ String
The current status of the recommender, indicating whether it is active, creating, updating, or in another state.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#training_metrics ⇒ Array<Types::TrainingMetrics>
A set of metrics that provide information about the recommender's training performance and accuracy.
Instance Attribute Details
#active_recommender_version_name ⇒ String
The name of the recommender version currently serving recommendations. Omitted when no active recommender version is set.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the recommender was created.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A detailed description of the recommender providing information about its purpose and functionality.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#failure_reason ⇒ String
If the recommender fails, provides the reason for the failure.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the recommender was edited.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#latest_recommender_update ⇒ Types::RecommenderUpdate
Information about the most recent update performed on the recommender, including status and timestamp.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_config ⇒ Types::RecommenderConfig
The configuration settings for the recommender, including parameters and settings that define its behavior.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_name ⇒ String
The name of the recommender.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_recipe_name ⇒ String
The name of the recipe used by the recommender to generate recommendations.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_schema_name ⇒ String
The name of the recommender schema associated with this recommender.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
The current status of the recommender, indicating whether it is active, creating, updating, or in another state.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#training_metrics ⇒ Array<Types::TrainingMetrics>
A set of metrics that provide information about the recommender's training performance and accuracy.
5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5189 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :active_recommender_version_name, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |