Class: Aws::CustomerProfiles::Types::GetRecommenderResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the recommender was created.

Returns:

  • (Time)


4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

A detailed description of the recommender providing information about its purpose and functionality.

Returns:

  • (String)


4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#failure_reasonString

If the recommender fails, provides the reason for the failure.

Returns:

  • (String)


4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the recommender was edited.

Returns:

  • (Time)


4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#latest_recommender_updateTypes::RecommenderUpdate

Information about the most recent update performed on the recommender, including status and timestamp.



4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_configTypes::RecommenderConfig

The configuration settings for the recommender, including parameters and settings that define its behavior.



4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_nameString

The name of the recommender.

Returns:

  • (String)


4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_recipe_nameString

The name of the recipe used by the recommender to generate recommendations.

Returns:

  • (String)


4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_schema_nameString

The name of the recommender schema associated with this recommender.

Returns:

  • (String)


4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#statusString

The current status of the recommender, indicating whether it is active, creating, updating, or in another state.

Returns:

  • (String)


4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#training_metricsArray<Types::TrainingMetrics>

A set of metrics that provide information about the recommender’s training performance and accuracy.

Returns:



4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989

class GetRecommenderResponse < Struct.new(
  :recommender_name,
  :recommender_recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :description,
  :status,
  :last_updated_at,
  :created_at,
  :failure_reason,
  :latest_recommender_update,
  :training_metrics,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end