Class: Aws::CustomerProfiles::Types::GetRecommenderResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetRecommenderResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the recommender was created.
-
#description ⇒ String
A detailed description of the recommender providing information about its purpose and functionality.
-
#failure_reason ⇒ String
If the recommender fails, provides the reason for the failure.
-
#last_updated_at ⇒ Time
The timestamp of when the recommender was edited.
-
#latest_recommender_update ⇒ Types::RecommenderUpdate
Information about the most recent update performed on the recommender, including status and timestamp.
-
#recommender_config ⇒ Types::RecommenderConfig
The configuration settings for the recommender, including parameters and settings that define its behavior.
-
#recommender_name ⇒ String
The name of the recommender.
-
#recommender_recipe_name ⇒ String
The name of the recipe used by the recommender to generate recommendations.
-
#recommender_schema_name ⇒ String
The name of the recommender schema associated with this recommender.
-
#status ⇒ String
The current status of the recommender, indicating whether it is active, creating, updating, or in another state.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#training_metrics ⇒ Array<Types::TrainingMetrics>
A set of metrics that provide information about the recommender’s training performance and accuracy.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the recommender was created.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A detailed description of the recommender providing information about its purpose and functionality.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#failure_reason ⇒ String
If the recommender fails, provides the reason for the failure.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the recommender was edited.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#latest_recommender_update ⇒ Types::RecommenderUpdate
Information about the most recent update performed on the recommender, including status and timestamp.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_config ⇒ Types::RecommenderConfig
The configuration settings for the recommender, including parameters and settings that define its behavior.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_name ⇒ String
The name of the recommender.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_recipe_name ⇒ String
The name of the recipe used by the recommender to generate recommendations.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_schema_name ⇒ String
The name of the recommender schema associated with this recommender.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
The current status of the recommender, indicating whether it is active, creating, updating, or in another state.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#training_metrics ⇒ Array<Types::TrainingMetrics>
A set of metrics that provide information about the recommender’s training performance and accuracy.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4989 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_schema_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |