Class: Aws::CustomerProfiles::Types::GetRecommenderResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetRecommenderResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the recommender was created.
-
#description ⇒ String
A detailed description of the recommender providing information about its purpose and functionality.
-
#failure_reason ⇒ String
If the recommender fails, provides the reason for the failure.
-
#last_updated_at ⇒ Time
The timestamp of when the recommender was edited.
-
#latest_recommender_update ⇒ Types::RecommenderUpdate
Information about the most recent update performed on the recommender, including status and timestamp.
-
#recommender_config ⇒ Types::RecommenderConfig
The configuration settings for the recommender, including parameters and settings that define its behavior.
-
#recommender_name ⇒ String
The name of the recommender.
-
#recommender_recipe_name ⇒ String
The name of the recipe used by the recommender to generate recommendations.
-
#status ⇒ String
The current status of the recommender, indicating whether it is active, creating, updating, or in another state.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#training_metrics ⇒ Array<Types::TrainingMetrics>
A set of metrics that provide information about the recommender’s training performance and accuracy.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the recommender was created.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A detailed description of the recommender providing information about its purpose and functionality.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#failure_reason ⇒ String
If the recommender fails, provides the reason for the failure.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the recommender was edited.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#latest_recommender_update ⇒ Types::RecommenderUpdate
Information about the most recent update performed on the recommender, including status and timestamp.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_config ⇒ Types::RecommenderConfig
The configuration settings for the recommender, including parameters and settings that define its behavior.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_name ⇒ String
The name of the recommender.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#recommender_recipe_name ⇒ String
The name of the recipe used by the recommender to generate recommendations.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
The current status of the recommender, indicating whether it is active, creating, updating, or in another state.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |
#training_metrics ⇒ Array<Types::TrainingMetrics>
A set of metrics that provide information about the recommender’s training performance and accuracy.
4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4590 class GetRecommenderResponse < Struct.new( :recommender_name, :recommender_recipe_name, :recommender_config, :description, :status, :last_updated_at, :created_at, :failure_reason, :latest_recommender_update, :training_metrics, :tags) SENSITIVE = [:description] include Aws::Structure end |