Class: Aws::CustomerProfiles::Types::GetRecommenderSchemaResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the recommender schema was created.

Returns:

  • (Time)


4938
4939
4940
4941
4942
4943
4944
4945
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4938

class GetRecommenderSchemaResponse < Struct.new(
  :recommender_schema_name,
  :fields,
  :created_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#fieldsHash<String,Array<Types::RecommenderSchemaField>>

A map of dataset type to column definitions included in the schema.

Returns:



4938
4939
4940
4941
4942
4943
4944
4945
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4938

class GetRecommenderSchemaResponse < Struct.new(
  :recommender_schema_name,
  :fields,
  :created_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#recommender_schema_nameString

The name of the recommender schema.

Returns:

  • (String)


4938
4939
4940
4941
4942
4943
4944
4945
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4938

class GetRecommenderSchemaResponse < Struct.new(
  :recommender_schema_name,
  :fields,
  :created_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the recommender schema.

Returns:

  • (String)


4938
4939
4940
4941
4942
4943
4944
4945
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4938

class GetRecommenderSchemaResponse < Struct.new(
  :recommender_schema_name,
  :fields,
  :created_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end