Class: Aws::CustomerProfiles::Types::GetSegmentSubscriptionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetSegmentSubscriptionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_updated_at ⇒ Time
The timestamp of the most recent configuration change.
-
#message ⇒ String
A status message providing additional context, such as a failure reason.
-
#schedule_configuration ⇒ Types::ScheduleConfiguration
The schedule configuration for periodic membership event notifications.
-
#scheduled_executions ⇒ Types::ScheduledExecutions
Information about scheduled execution timestamps.
-
#started_at ⇒ Time
The timestamp of when the subscription was first started.
-
#status ⇒ String
The current lifecycle status of the subscription.
Instance Attribute Details
#last_updated_at ⇒ Time
The timestamp of the most recent configuration change.
5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563 class GetSegmentSubscriptionResponse < Struct.new( :status, :message, :schedule_configuration, :scheduled_executions, :started_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A status message providing additional context, such as a failure reason.
5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563 class GetSegmentSubscriptionResponse < Struct.new( :status, :message, :schedule_configuration, :scheduled_executions, :started_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#schedule_configuration ⇒ Types::ScheduleConfiguration
The schedule configuration for periodic membership event notifications.
5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563 class GetSegmentSubscriptionResponse < Struct.new( :status, :message, :schedule_configuration, :scheduled_executions, :started_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#scheduled_executions ⇒ Types::ScheduledExecutions
Information about scheduled execution timestamps.
5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563 class GetSegmentSubscriptionResponse < Struct.new( :status, :message, :schedule_configuration, :scheduled_executions, :started_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when the subscription was first started.
5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563 class GetSegmentSubscriptionResponse < Struct.new( :status, :message, :schedule_configuration, :scheduled_executions, :started_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current lifecycle status of the subscription. The following are valid values:
-
STARTING: Initial snapshot is in progress.
-
RUNNING: Notifications are active and running.
-
STOPPED: Notifications have been stopped.
-
FAILED: Notifications failed (for example, the Amazon Kinesis data stream became inaccessible).
5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5563 class GetSegmentSubscriptionResponse < Struct.new( :status, :message, :schedule_configuration, :scheduled_executions, :started_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |