Class: Aws::CustomerProfiles::Types::GetSimilarProfilesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4885

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#match_typeString

Specify the type of matching to get similar profiles for.

Returns:

  • (String)


4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4885

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of objects returned per page.

Returns:

  • (Integer)


4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4885

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token from the previous ‘GetSimilarProfiles` API call.

Returns:

  • (String)


4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4885

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#search_keyString

The string indicating the search key to be used.

Returns:

  • (String)


4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4885

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#search_valueString

The string based on ‘SearchKey` to be searched for similar profiles.

Returns:

  • (String)


4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-customerprofiles/types.rb', line 4885

class GetSimilarProfilesRequest < Struct.new(
  :next_token,
  :max_results,
  :domain_name,
  :match_type,
  :search_key,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end