Class: Aws::CustomerProfiles::Types::GetSimilarProfilesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetSimilarProfilesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#confidence_score ⇒ Float
It only has value when the ‘MatchType` is `ML_BASED_MATCHING`.A number between 0 and 1, where a higher score means higher similarity.
-
#match_id ⇒ String
The string ‘matchId` that the similar profiles belong to.
-
#match_type ⇒ String
Specify the type of matching to get similar profiles for.
-
#next_token ⇒ String
The pagination token from the previous ‘GetSimilarProfiles` API call.
-
#profile_ids ⇒ Array<String>
Set of ‘profileId`s that belong to the same matching group.
-
#rule_level ⇒ Integer
The integer rule level that the profiles matched on.
Instance Attribute Details
#confidence_score ⇒ Float
It only has value when the ‘MatchType` is `ML_BASED_MATCHING`.A number between 0 and 1, where a higher score means higher similarity. Examining match confidence scores lets you distinguish between groups of similar records in which the system is highly confident (which you may decide to merge), groups of similar records about which the system is uncertain (which you may decide to have reviewed by a human), and groups of similar records that the system deems to be unlikely (which you may decide to reject). Given confidence scores vary as per the data input, it should not be used as an absolute measure of matching quality.
5381 5382 5383 5384 5385 5386 5387 5388 5389 5390 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5381 class GetSimilarProfilesResponse < Struct.new( :profile_ids, :match_id, :match_type, :rule_level, :confidence_score, :next_token) SENSITIVE = [] include Aws::Structure end |
#match_id ⇒ String
The string ‘matchId` that the similar profiles belong to.
5381 5382 5383 5384 5385 5386 5387 5388 5389 5390 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5381 class GetSimilarProfilesResponse < Struct.new( :profile_ids, :match_id, :match_type, :rule_level, :confidence_score, :next_token) SENSITIVE = [] include Aws::Structure end |
#match_type ⇒ String
Specify the type of matching to get similar profiles for.
5381 5382 5383 5384 5385 5386 5387 5388 5389 5390 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5381 class GetSimilarProfilesResponse < Struct.new( :profile_ids, :match_id, :match_type, :rule_level, :confidence_score, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token from the previous ‘GetSimilarProfiles` API call.
5381 5382 5383 5384 5385 5386 5387 5388 5389 5390 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5381 class GetSimilarProfilesResponse < Struct.new( :profile_ids, :match_id, :match_type, :rule_level, :confidence_score, :next_token) SENSITIVE = [] include Aws::Structure end |
#profile_ids ⇒ Array<String>
Set of ‘profileId`s that belong to the same matching group.
5381 5382 5383 5384 5385 5386 5387 5388 5389 5390 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5381 class GetSimilarProfilesResponse < Struct.new( :profile_ids, :match_id, :match_type, :rule_level, :confidence_score, :next_token) SENSITIVE = [] include Aws::Structure end |
#rule_level ⇒ Integer
The integer rule level that the profiles matched on.
5381 5382 5383 5384 5385 5386 5387 5388 5389 5390 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5381 class GetSimilarProfilesResponse < Struct.new( :profile_ids, :match_id, :match_type, :rule_level, :confidence_score, :next_token) SENSITIVE = [] include Aws::Structure end |