Class: Aws::CustomerProfiles::Types::GetSimilarProfilesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#confidence_scoreFloat

It only has value when the ‘MatchType` is `ML_BASED_MATCHING`.A number between 0 and 1, where a higher score means higher similarity. Examining match confidence scores lets you distinguish between groups of similar records in which the system is highly confident (which you may decide to merge), groups of similar records about which the system is uncertain (which you may decide to have reviewed by a human), and groups of similar records that the system deems to be unlikely (which you may decide to reject). Given confidence scores vary as per the data input, it should not be used as an absolute measure of matching quality.

Returns:

  • (Float)


5121
5122
5123
5124
5125
5126
5127
5128
5129
5130
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5121

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#match_idString

The string ‘matchId` that the similar profiles belong to.

Returns:

  • (String)


5121
5122
5123
5124
5125
5126
5127
5128
5129
5130
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5121

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#match_typeString

Specify the type of matching to get similar profiles for.

Returns:

  • (String)


5121
5122
5123
5124
5125
5126
5127
5128
5129
5130
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5121

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token from the previous ‘GetSimilarProfiles` API call.

Returns:

  • (String)


5121
5122
5123
5124
5125
5126
5127
5128
5129
5130
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5121

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idsArray<String>

Set of ‘profileId`s that belong to the same matching group.

Returns:

  • (Array<String>)


5121
5122
5123
5124
5125
5126
5127
5128
5129
5130
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5121

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#rule_levelInteger

The integer rule level that the profiles matched on.

Returns:

  • (Integer)


5121
5122
5123
5124
5125
5126
5127
5128
5129
5130
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5121

class GetSimilarProfilesResponse < Struct.new(
  :profile_ids,
  :match_id,
  :match_type,
  :rule_level,
  :confidence_score,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end