Class: Aws::CustomerProfiles::Types::GetWorkflowStepsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::GetWorkflowStepsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#workflow_id ⇒ String
Unique identifier for the workflow.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5173 class GetWorkflowStepsRequest < Struct.new( :domain_name, :workflow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5173 class GetWorkflowStepsRequest < Struct.new( :domain_name, :workflow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5173 class GetWorkflowStepsRequest < Struct.new( :domain_name, :workflow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#workflow_id ⇒ String
Unique identifier for the workflow.
5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5173 class GetWorkflowStepsRequest < Struct.new( :domain_name, :workflow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |