Class: Aws::CustomerProfiles::Types::LayoutItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::LayoutItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
The layout object that contains LayoutDefinitionName, Description, DisplayName, IsDefault, LayoutType, Tags, CreatedAt, LastUpdatedAt
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the layout was created.
-
#description ⇒ String
The description of the layout.
-
#display_name ⇒ String
The display name of the layout.
-
#is_default ⇒ Boolean
If set to true for a layout, this layout will be used by default to view data.
-
#last_updated_at ⇒ Time
The timestamp of when the layout was most recently updated.
-
#layout_definition_name ⇒ String
The unique name of the layout.
-
#layout_type ⇒ String
The type of layout that can be used to view data under customer profiles domain.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the layout was created.
5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5915 class LayoutItem < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :tags, :created_at, :last_updated_at) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the layout
5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5915 class LayoutItem < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :tags, :created_at, :last_updated_at) SENSITIVE = [:description] include Aws::Structure end |
#display_name ⇒ String
The display name of the layout
5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5915 class LayoutItem < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :tags, :created_at, :last_updated_at) SENSITIVE = [:description] include Aws::Structure end |
#is_default ⇒ Boolean
If set to true for a layout, this layout will be used by default to view data. If set to false, then layout will not be used by default but it can be used to view data by explicit selection on UI.
5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5915 class LayoutItem < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :tags, :created_at, :last_updated_at) SENSITIVE = [:description] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the layout was most recently updated.
5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5915 class LayoutItem < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :tags, :created_at, :last_updated_at) SENSITIVE = [:description] include Aws::Structure end |
#layout_definition_name ⇒ String
The unique name of the layout.
5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5915 class LayoutItem < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :tags, :created_at, :last_updated_at) SENSITIVE = [:description] include Aws::Structure end |
#layout_type ⇒ String
The type of layout that can be used to view data under customer profiles domain.
5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5915 class LayoutItem < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :tags, :created_at, :last_updated_at) SENSITIVE = [:description] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5915 class LayoutItem < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :tags, :created_at, :last_updated_at) SENSITIVE = [:description] include Aws::Structure end |