Class: Aws::CustomerProfiles::Types::LayoutItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The layout object that contains LayoutDefinitionName, Description, DisplayName, IsDefault, LayoutType, Tags, CreatedAt, LastUpdatedAt

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the layout was created.

Returns:

  • (Time)


5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5655

class LayoutItem < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :tags,
  :created_at,
  :last_updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the layout

Returns:

  • (String)


5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5655

class LayoutItem < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :tags,
  :created_at,
  :last_updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#display_nameString

The display name of the layout

Returns:

  • (String)


5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5655

class LayoutItem < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :tags,
  :created_at,
  :last_updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#is_defaultBoolean

If set to true for a layout, this layout will be used by default to view data. If set to false, then layout will not be used by default but it can be used to view data by explicit selection on UI.

Returns:

  • (Boolean)


5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5655

class LayoutItem < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :tags,
  :created_at,
  :last_updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the layout was most recently updated.

Returns:

  • (Time)


5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5655

class LayoutItem < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :tags,
  :created_at,
  :last_updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#layout_definition_nameString

The unique name of the layout.

Returns:

  • (String)


5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5655

class LayoutItem < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :tags,
  :created_at,
  :last_updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#layout_typeString

The type of layout that can be used to view data under customer profiles domain.

Returns:

  • (String)


5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5655

class LayoutItem < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :tags,
  :created_at,
  :last_updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
# File 'lib/aws-sdk-customerprofiles/types.rb', line 5655

class LayoutItem < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :tags,
  :created_at,
  :last_updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end