Class: Aws::CustomerProfiles::Types::ListIdentityResolutionJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ListIdentityResolutionJobsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
6729 6730 6731 6732 6733 6734 6735 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6729 class ListIdentityResolutionJobsRequest < Struct.new( :domain_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
6729 6730 6731 6732 6733 6734 6735 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6729 class ListIdentityResolutionJobsRequest < Struct.new( :domain_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
6729 6730 6731 6732 6733 6734 6735 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6729 class ListIdentityResolutionJobsRequest < Struct.new( :domain_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |