Class: Aws::CustomerProfiles::Types::ListObjectTypeAttributeValuesItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ListObjectTypeAttributeValuesItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Represents an item in the list of object type attribute values with its associated metadata.
Constant Summary collapse
- SENSITIVE =
[:value]
Instance Attribute Summary collapse
-
#last_updated_at ⇒ Time
The timestamp of when the object type attribute value was most recently updated.
-
#value ⇒ String
The actual value of the object type attribute.
Instance Attribute Details
#last_updated_at ⇒ Time
The timestamp of when the object type attribute value was most recently updated.
6913 6914 6915 6916 6917 6918 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6913 class ListObjectTypeAttributeValuesItem < Struct.new( :value, :last_updated_at) SENSITIVE = [:value] include Aws::Structure end |
#value ⇒ String
The actual value of the object type attribute.
6913 6914 6915 6916 6917 6918 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 6913 class ListObjectTypeAttributeValuesItem < Struct.new( :value, :last_updated_at) SENSITIVE = [:value] include Aws::Structure end |