Class: Aws::CustomerProfiles::Types::ListProfileObjectTypeItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ListProfileObjectTypeItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
A ProfileObjectType instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the domain was created.
-
#description ⇒ String
Description of the profile object type.
-
#last_updated_at ⇒ Time
The timestamp of when the profile object type was most recently edited.
-
#max_available_profile_object_count ⇒ Integer
The amount of provisioned profile object max count available.
-
#max_profile_object_count ⇒ Integer
The amount of profile object max count assigned to the object type.
-
#object_type_name ⇒ String
The name of the profile object type.
-
#source_priority ⇒ Integer
An integer that determines the priority of this object type when data from multiple sources is ingested.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the domain was created.
7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7126 class ListProfileObjectTypeItem < Struct.new( :object_type_name, :description, :created_at, :last_updated_at, :max_profile_object_count, :max_available_profile_object_count, :source_priority, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the profile object type.
7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7126 class ListProfileObjectTypeItem < Struct.new( :object_type_name, :description, :created_at, :last_updated_at, :max_profile_object_count, :max_available_profile_object_count, :source_priority, :tags) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the profile object type was most recently edited.
7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7126 class ListProfileObjectTypeItem < Struct.new( :object_type_name, :description, :created_at, :last_updated_at, :max_profile_object_count, :max_available_profile_object_count, :source_priority, :tags) SENSITIVE = [] include Aws::Structure end |
#max_available_profile_object_count ⇒ Integer
The amount of provisioned profile object max count available.
7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7126 class ListProfileObjectTypeItem < Struct.new( :object_type_name, :description, :created_at, :last_updated_at, :max_profile_object_count, :max_available_profile_object_count, :source_priority, :tags) SENSITIVE = [] include Aws::Structure end |
#max_profile_object_count ⇒ Integer
The amount of profile object max count assigned to the object type.
7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7126 class ListProfileObjectTypeItem < Struct.new( :object_type_name, :description, :created_at, :last_updated_at, :max_profile_object_count, :max_available_profile_object_count, :source_priority, :tags) SENSITIVE = [] include Aws::Structure end |
#object_type_name ⇒ String
The name of the profile object type.
7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7126 class ListProfileObjectTypeItem < Struct.new( :object_type_name, :description, :created_at, :last_updated_at, :max_profile_object_count, :max_available_profile_object_count, :source_priority, :tags) SENSITIVE = [] include Aws::Structure end |
#source_priority ⇒ Integer
An integer that determines the priority of this object type when data from multiple sources is ingested. Lower values take priority. Object types without a specified source priority default to the lowest priority.
7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7126 class ListProfileObjectTypeItem < Struct.new( :object_type_name, :description, :created_at, :last_updated_at, :max_profile_object_count, :max_available_profile_object_count, :source_priority, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7126 class ListProfileObjectTypeItem < Struct.new( :object_type_name, :description, :created_at, :last_updated_at, :max_profile_object_count, :max_available_profile_object_count, :source_priority, :tags) SENSITIVE = [] include Aws::Structure end |