Class: Aws::CustomerProfiles::Types::ListRecommenderRecipesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ListRecommenderRecipesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of recommender recipes to return in the response.
-
#next_token ⇒ String
A token received from a previous ListRecommenderRecipes call to retrieve the next page of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of recommender recipes to return in the response. The default value is 100.
7373 7374 7375 7376 7377 7378 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7373 class ListRecommenderRecipesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token received from a previous ListRecommenderRecipes call to retrieve the next page of results.
7373 7374 7375 7376 7377 7378 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7373 class ListRecommenderRecipesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |