Class: Aws::CustomerProfiles::Types::ListRecommenderSchemasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ListRecommenderSchemasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#max_results ⇒ Integer
The maximum number of recommender schemas to return in the response.
-
#next_token ⇒ String
A token received from a previous ListRecommenderSchemas call to retrieve the next page of results.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
7414 7415 7416 7417 7418 7419 7420 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7414 class ListRecommenderSchemasRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of recommender schemas to return in the response. The default value is 100.
7414 7415 7416 7417 7418 7419 7420 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7414 class ListRecommenderSchemasRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token received from a previous ListRecommenderSchemas call to retrieve the next page of results.
7414 7415 7416 7417 7418 7419 7420 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7414 class ListRecommenderSchemasRequest < Struct.new( :domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |