Class: Aws::CustomerProfiles::Types::ListSegmentSubscriptionEventsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ListSegmentSubscriptionEventsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#max_results ⇒ Integer
The maximum number of events to return per page.
-
#next_token ⇒ String
The pagination token from the previous call to retrieve the next page of results.
-
#segment_definition_name ⇒ String
The unique name of the segment definition.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7582 class ListSegmentSubscriptionEventsRequest < Struct.new( :domain_name, :segment_definition_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of events to return per page.
7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7582 class ListSegmentSubscriptionEventsRequest < Struct.new( :domain_name, :segment_definition_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token from the previous call to retrieve the next page of results.
7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7582 class ListSegmentSubscriptionEventsRequest < Struct.new( :domain_name, :segment_definition_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#segment_definition_name ⇒ String
The unique name of the segment definition.
7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7582 class ListSegmentSubscriptionEventsRequest < Struct.new( :domain_name, :segment_definition_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |