Class: Aws::CustomerProfiles::Types::ListUploadJobsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ListUploadJobsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::UploadJobItem>
The list of upload jobs for the specified domain.
-
#next_token ⇒ String
The pagination token to use to retrieve the next page of results.
Instance Attribute Details
#items ⇒ Array<Types::UploadJobItem>
The list of upload jobs for the specified domain.
7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7666 class ListUploadJobsResponse < Struct.new( :next_token, :items) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use to retrieve the next page of results.
7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7666 class ListUploadJobsResponse < Struct.new( :next_token, :items) SENSITIVE = [] include Aws::Structure end |