Class: Aws::CustomerProfiles::Types::MergeProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::MergeProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#field_source_profile_ids ⇒ Types::FieldSourceProfileIds
The identifiers of the fields in the profile that has the information you want to apply to the merge.
-
#main_profile_id ⇒ String
The identifier of the profile to be taken.
-
#profile_ids_to_be_merged ⇒ Array<String>
The identifier of the profile to be merged into MainProfileId.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
7470 7471 7472 7473 7474 7475 7476 7477 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7470 class MergeProfilesRequest < Struct.new( :domain_name, :main_profile_id, :profile_ids_to_be_merged, :field_source_profile_ids) SENSITIVE = [] include Aws::Structure end |
#field_source_profile_ids ⇒ Types::FieldSourceProfileIds
The identifiers of the fields in the profile that has the information you want to apply to the merge. For example, say you want to merge EmailAddress from Profile1 into MainProfile. This would be the identifier of the EmailAddress field in Profile1.
7470 7471 7472 7473 7474 7475 7476 7477 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7470 class MergeProfilesRequest < Struct.new( :domain_name, :main_profile_id, :profile_ids_to_be_merged, :field_source_profile_ids) SENSITIVE = [] include Aws::Structure end |
#main_profile_id ⇒ String
The identifier of the profile to be taken.
7470 7471 7472 7473 7474 7475 7476 7477 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7470 class MergeProfilesRequest < Struct.new( :domain_name, :main_profile_id, :profile_ids_to_be_merged, :field_source_profile_ids) SENSITIVE = [] include Aws::Structure end |
#profile_ids_to_be_merged ⇒ Array<String>
The identifier of the profile to be merged into MainProfileId.
7470 7471 7472 7473 7474 7475 7476 7477 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7470 class MergeProfilesRequest < Struct.new( :domain_name, :main_profile_id, :profile_ids_to_be_merged, :field_source_profile_ids) SENSITIVE = [] include Aws::Structure end |