Class: Aws::CustomerProfiles::Types::MergeProfilesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


7022
7023
7024
7025
7026
7027
7028
7029
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7022

class MergeProfilesRequest < Struct.new(
  :domain_name,
  :main_profile_id,
  :profile_ids_to_be_merged,
  :field_source_profile_ids)
  SENSITIVE = []
  include Aws::Structure
end

#field_source_profile_idsTypes::FieldSourceProfileIds

The identifiers of the fields in the profile that has the information you want to apply to the merge. For example, say you want to merge EmailAddress from Profile1 into MainProfile. This would be the identifier of the EmailAddress field in Profile1.



7022
7023
7024
7025
7026
7027
7028
7029
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7022

class MergeProfilesRequest < Struct.new(
  :domain_name,
  :main_profile_id,
  :profile_ids_to_be_merged,
  :field_source_profile_ids)
  SENSITIVE = []
  include Aws::Structure
end

#main_profile_idString

The identifier of the profile to be taken.

Returns:

  • (String)


7022
7023
7024
7025
7026
7027
7028
7029
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7022

class MergeProfilesRequest < Struct.new(
  :domain_name,
  :main_profile_id,
  :profile_ids_to_be_merged,
  :field_source_profile_ids)
  SENSITIVE = []
  include Aws::Structure
end

#profile_ids_to_be_mergedArray<String>

The identifier of the profile to be merged into MainProfileId.

Returns:

  • (Array<String>)


7022
7023
7024
7025
7026
7027
7028
7029
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7022

class MergeProfilesRequest < Struct.new(
  :domain_name,
  :main_profile_id,
  :profile_ids_to_be_merged,
  :field_source_profile_ids)
  SENSITIVE = []
  include Aws::Structure
end