Class: Aws::CustomerProfiles::Types::ProfileAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::ProfileAttributes
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
The object used to segment on attributes within the customer profile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_number ⇒ Types::ProfileDimension
A field to describe values to segment on within account number.
-
#additional_information ⇒ Types::ExtraLengthValueProfileDimension
A field to describe values to segment on within additional information.
-
#address ⇒ Types::AddressDimension
A field to describe values to segment on within address.
-
#attributes ⇒ Hash<String,Types::AttributeDimension>
A field to describe values to segment on within attributes.
-
#billing_address ⇒ Types::AddressDimension
A field to describe values to segment on within billing address.
-
#birth_date ⇒ Types::DateDimension
A field to describe values to segment on within birthDate.
-
#business_email_address ⇒ Types::ProfileDimension
A field to describe values to segment on within business email address.
-
#business_name ⇒ Types::ProfileDimension
A field to describe values to segment on within business name.
-
#business_phone_number ⇒ Types::ProfileDimension
A field to describe values to segment on within business phone number.
-
#email_address ⇒ Types::ProfileDimension
A field to describe values to segment on within email address.
-
#first_name ⇒ Types::ProfileDimension
A field to describe values to segment on within first name.
-
#gender_string ⇒ Types::ProfileDimension
A field to describe values to segment on within genderString.
-
#home_phone_number ⇒ Types::ProfileDimension
A field to describe values to segment on within home phone number.
-
#last_name ⇒ Types::ProfileDimension
A field to describe values to segment on within last name.
-
#mailing_address ⇒ Types::AddressDimension
A field to describe values to segment on within mailing address.
-
#middle_name ⇒ Types::ProfileDimension
A field to describe values to segment on within middle name.
-
#mobile_phone_number ⇒ Types::ProfileDimension
A field to describe values to segment on within mobile phone number.
-
#party_type_string ⇒ Types::ProfileDimension
A field to describe values to segment on within partyTypeString.
-
#personal_email_address ⇒ Types::ProfileDimension
A field to describe values to segment on within personal email address.
-
#phone_number ⇒ Types::ProfileDimension
A field to describe values to segment on within phone number.
-
#profile_type ⇒ Types::ProfileTypeDimension
A field to describe values to segment on within profile type.
-
#shipping_address ⇒ Types::AddressDimension
A field to describe values to segment on within shipping address.
Instance Attribute Details
#account_number ⇒ Types::ProfileDimension
A field to describe values to segment on within account number.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#additional_information ⇒ Types::ExtraLengthValueProfileDimension
A field to describe values to segment on within additional information.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#address ⇒ Types::AddressDimension
A field to describe values to segment on within address.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#attributes ⇒ Hash<String,Types::AttributeDimension>
A field to describe values to segment on within attributes.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#billing_address ⇒ Types::AddressDimension
A field to describe values to segment on within billing address.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#birth_date ⇒ Types::DateDimension
A field to describe values to segment on within birthDate.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#business_email_address ⇒ Types::ProfileDimension
A field to describe values to segment on within business email address.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#business_name ⇒ Types::ProfileDimension
A field to describe values to segment on within business name.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#business_phone_number ⇒ Types::ProfileDimension
A field to describe values to segment on within business phone number.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#email_address ⇒ Types::ProfileDimension
A field to describe values to segment on within email address.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#first_name ⇒ Types::ProfileDimension
A field to describe values to segment on within first name.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#gender_string ⇒ Types::ProfileDimension
A field to describe values to segment on within genderString.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#home_phone_number ⇒ Types::ProfileDimension
A field to describe values to segment on within home phone number.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#last_name ⇒ Types::ProfileDimension
A field to describe values to segment on within last name.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#mailing_address ⇒ Types::AddressDimension
A field to describe values to segment on within mailing address.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#middle_name ⇒ Types::ProfileDimension
A field to describe values to segment on within middle name.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#mobile_phone_number ⇒ Types::ProfileDimension
A field to describe values to segment on within mobile phone number.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#party_type_string ⇒ Types::ProfileDimension
A field to describe values to segment on within partyTypeString.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#personal_email_address ⇒ Types::ProfileDimension
A field to describe values to segment on within personal email address.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#phone_number ⇒ Types::ProfileDimension
A field to describe values to segment on within phone number.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#profile_type ⇒ Types::ProfileTypeDimension
A field to describe values to segment on within profile type.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |
#shipping_address ⇒ Types::AddressDimension
A field to describe values to segment on within shipping address.
7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7496 class ProfileAttributes < Struct.new( :account_number, :additional_information, :first_name, :last_name, :middle_name, :gender_string, :party_type_string, :birth_date, :phone_number, :business_name, :business_phone_number, :home_phone_number, :mobile_phone_number, :email_address, :personal_email_address, :business_email_address, :address, :shipping_address, :mailing_address, :billing_address, :attributes, :profile_type) SENSITIVE = [] include Aws::Structure end |