Class: Aws::CustomerProfiles::Types::PutIntegrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::PutIntegrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:flow_definition]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#event_trigger_names ⇒ Array<String>
A list of unique names for active event triggers associated with the integration.
-
#flow_definition ⇒ Types::FlowDefinition
The configuration that controls how Customer Profiles retrieves data from the source.
-
#object_type_name ⇒ String
The name of the profile object type.
-
#object_type_names ⇒ Hash<String,String>
A map in which each key is an event type from an external application such as Segment or Shopify, and each value is an ‘ObjectTypeName` (template) used to ingest the event.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role.
-
#scope ⇒ String
Specifies whether the integration applies to profile level data (associated with profiles) or domain level data (not associated with any specific profile).
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#uri ⇒ String
The URI of the S3 bucket or any other type of data source.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
7791 7792 7793 7794 7795 7796 7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7791 class PutIntegrationRequest < Struct.new( :domain_name, :uri, :object_type_name, :object_type_names, :tags, :flow_definition, :role_arn, :event_trigger_names, :scope) SENSITIVE = [:flow_definition] include Aws::Structure end |
#event_trigger_names ⇒ Array<String>
A list of unique names for active event triggers associated with the integration.
7791 7792 7793 7794 7795 7796 7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7791 class PutIntegrationRequest < Struct.new( :domain_name, :uri, :object_type_name, :object_type_names, :tags, :flow_definition, :role_arn, :event_trigger_names, :scope) SENSITIVE = [:flow_definition] include Aws::Structure end |
#flow_definition ⇒ Types::FlowDefinition
The configuration that controls how Customer Profiles retrieves data from the source.
7791 7792 7793 7794 7795 7796 7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7791 class PutIntegrationRequest < Struct.new( :domain_name, :uri, :object_type_name, :object_type_names, :tags, :flow_definition, :role_arn, :event_trigger_names, :scope) SENSITIVE = [:flow_definition] include Aws::Structure end |
#object_type_name ⇒ String
The name of the profile object type.
7791 7792 7793 7794 7795 7796 7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7791 class PutIntegrationRequest < Struct.new( :domain_name, :uri, :object_type_name, :object_type_names, :tags, :flow_definition, :role_arn, :event_trigger_names, :scope) SENSITIVE = [:flow_definition] include Aws::Structure end |
#object_type_names ⇒ Hash<String,String>
A map in which each key is an event type from an external application such as Segment or Shopify, and each value is an ‘ObjectTypeName` (template) used to ingest the event. It supports the following event types: `SegmentIdentify`, `ShopifyCreateCustomers`, `ShopifyUpdateCustomers`, `ShopifyCreateDraftOrders`, `ShopifyUpdateDraftOrders`, `ShopifyCreateOrders`, and `ShopifyUpdatedOrders`.
7791 7792 7793 7794 7795 7796 7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7791 class PutIntegrationRequest < Struct.new( :domain_name, :uri, :object_type_name, :object_type_names, :tags, :flow_definition, :role_arn, :event_trigger_names, :scope) SENSITIVE = [:flow_definition] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role. The Integration uses this role to make Customer Profiles requests on your behalf.
7791 7792 7793 7794 7795 7796 7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7791 class PutIntegrationRequest < Struct.new( :domain_name, :uri, :object_type_name, :object_type_names, :tags, :flow_definition, :role_arn, :event_trigger_names, :scope) SENSITIVE = [:flow_definition] include Aws::Structure end |
#scope ⇒ String
Specifies whether the integration applies to profile level data (associated with profiles) or domain level data (not associated with any specific profile). The default value is PROFILE.
7791 7792 7793 7794 7795 7796 7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7791 class PutIntegrationRequest < Struct.new( :domain_name, :uri, :object_type_name, :object_type_names, :tags, :flow_definition, :role_arn, :event_trigger_names, :scope) SENSITIVE = [:flow_definition] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
7791 7792 7793 7794 7795 7796 7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7791 class PutIntegrationRequest < Struct.new( :domain_name, :uri, :object_type_name, :object_type_names, :tags, :flow_definition, :role_arn, :event_trigger_names, :scope) SENSITIVE = [:flow_definition] include Aws::Structure end |
#uri ⇒ String
The URI of the S3 bucket or any other type of data source.
7791 7792 7793 7794 7795 7796 7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7791 class PutIntegrationRequest < Struct.new( :domain_name, :uri, :object_type_name, :object_type_names, :tags, :flow_definition, :role_arn, :event_trigger_names, :scope) SENSITIVE = [:flow_definition] include Aws::Structure end |