Class: Aws::CustomerProfiles::Types::PutProfileObjectTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::PutProfileObjectTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :fields, :keys]
Instance Attribute Summary collapse
-
#allow_profile_creation ⇒ Boolean
Indicates whether a profile should be created when data is received if one doesn’t exist for an object of this type.
-
#description ⇒ String
Description of the profile object type.
-
#domain_name ⇒ String
The unique name of the domain.
-
#encryption_key ⇒ String
The customer-provided key to encrypt the profile object that will be created in this profile object type.
-
#expiration_days ⇒ Integer
The number of days until the data in the object expires.
-
#fields ⇒ Hash<String,Types::ObjectTypeField>
A map of the name and ObjectType field.
-
#keys ⇒ Hash<String,Array<Types::ObjectTypeKey>>
A list of unique keys that can be used to map data to the profile.
-
#max_profile_object_count ⇒ Integer
The amount of profile object max count assigned to the object type.
-
#object_type_name ⇒ String
The name of the profile object type.
-
#source_last_updated_timestamp_format ⇒ String
The format of your ‘sourceLastUpdatedTimestamp` that was previously set up.
-
#source_priority ⇒ Integer
An integer that determines the priority of this object type when data from multiple sources is ingested.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#template_id ⇒ String
A unique identifier for the object template.
Instance Attribute Details
#allow_profile_creation ⇒ Boolean
Indicates whether a profile should be created when data is received if one doesn’t exist for an object of this type. The default is ‘FALSE`. If the AllowProfileCreation flag is set to `FALSE`, then the service tries to fetch a standard profile and associate this object with the profile. If it is set to `TRUE`, and if no match is found, then the service creates a new standard profile.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#description ⇒ String
Description of the profile object type.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#encryption_key ⇒ String
The customer-provided key to encrypt the profile object that will be created in this profile object type.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#expiration_days ⇒ Integer
The number of days until the data in the object expires.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#fields ⇒ Hash<String,Types::ObjectTypeField>
A map of the name and ObjectType field.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#keys ⇒ Hash<String,Array<Types::ObjectTypeKey>>
A list of unique keys that can be used to map data to the profile.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#max_profile_object_count ⇒ Integer
The amount of profile object max count assigned to the object type
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#object_type_name ⇒ String
The name of the profile object type.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#source_last_updated_timestamp_format ⇒ String
The format of your ‘sourceLastUpdatedTimestamp` that was previously set up.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#source_priority ⇒ Integer
An integer that determines the priority of this object type when data from multiple sources is ingested. Lower values take priority. Object types without a specified source priority default to the lowest priority.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |
#template_id ⇒ String
A unique identifier for the object template. For some attributes in the request, the service will use the default value from the object template when TemplateId is present. If these attributes are present in the request, the service may return a ‘BadRequestException`. These attributes include: AllowProfileCreation, SourceLastUpdatedTimestampFormat, Fields, and Keys. For example, if AllowProfileCreation is set to true when TemplateId is set, the service may return a `BadRequestException`.
8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8457 class PutProfileObjectTypeRequest < Struct.new( :domain_name, :object_type_name, :description, :template_id, :expiration_days, :encryption_key, :allow_profile_creation, :source_last_updated_timestamp_format, :max_profile_object_count, :source_priority, :fields, :keys, :tags) SENSITIVE = [:description, :fields, :keys] include Aws::Structure end |