Class: Aws::CustomerProfiles::Types::PutProfileObjectTypeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :fields, :keys]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_profile_creationBoolean

Indicates whether a profile should be created when data is received if one doesn’t exist for an object of this type. The default is ‘FALSE`. If the AllowProfileCreation flag is set to `FALSE`, then the service tries to fetch a standard profile and associate this object with the profile. If it is set to `TRUE`, and if no match is found, then the service creates a new standard profile.

Returns:

  • (Boolean)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#descriptionString

Description of the profile object type.

Returns:

  • (String)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#domain_nameString

The unique name of the domain.

Returns:

  • (String)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#encryption_keyString

The customer-provided key to encrypt the profile object that will be created in this profile object type.

Returns:

  • (String)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#expiration_daysInteger

The number of days until the data in the object expires.

Returns:

  • (Integer)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#fieldsHash<String,Types::ObjectTypeField>

A map of the name and ObjectType field.

Returns:



7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#keysHash<String,Array<Types::ObjectTypeKey>>

A list of unique keys that can be used to map data to the profile.

Returns:



7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#max_profile_object_countInteger

The amount of profile object max count assigned to the object type

Returns:

  • (Integer)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#object_type_nameString

The name of the profile object type.

Returns:

  • (String)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#source_last_updated_timestamp_formatString

The format of your ‘sourceLastUpdatedTimestamp` that was previously set up.

Returns:

  • (String)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#source_priorityInteger

An integer that determines the priority of this object type when data from multiple sources is ingested. Lower values take priority. Object types without a specified source priority default to the lowest priority.

Returns:

  • (Integer)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end

#template_idString

A unique identifier for the object template. For some attributes in the request, the service will use the default value from the object template when TemplateId is present. If these attributes are present in the request, the service may return a ‘BadRequestException`. These attributes include: AllowProfileCreation, SourceLastUpdatedTimestampFormat, Fields, and Keys. For example, if AllowProfileCreation is set to true when TemplateId is set, the service may return a `BadRequestException`.

Returns:

  • (String)


7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
# File 'lib/aws-sdk-customerprofiles/types.rb', line 7993

class PutProfileObjectTypeRequest < Struct.new(
  :domain_name,
  :object_type_name,
  :description,
  :template_id,
  :expiration_days,
  :encryption_key,
  :allow_profile_creation,
  :source_last_updated_timestamp_format,
  :max_profile_object_count,
  :source_priority,
  :fields,
  :keys,
  :tags)
  SENSITIVE = [:description, :fields, :keys]
  include Aws::Structure
end