Class: Aws::CustomerProfiles::Types::PutSegmentSubscriptionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::PutSegmentSubscriptionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the domain.
-
#schedule_configuration ⇒ Types::ScheduleConfiguration
The optional schedule configuration that controls how often membership snapshots are run.
-
#segment_definition_name ⇒ String
The unique name of the segment definition.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the domain.
9080 9081 9082 9083 9084 9085 9086 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9080 class PutSegmentSubscriptionRequest < Struct.new( :domain_name, :segment_definition_name, :schedule_configuration) SENSITIVE = [] include Aws::Structure end |
#schedule_configuration ⇒ Types::ScheduleConfiguration
The optional schedule configuration that controls how often membership snapshots are run. If not provided, the subscription defaults to a 24-hour interval.
9080 9081 9082 9083 9084 9085 9086 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9080 class PutSegmentSubscriptionRequest < Struct.new( :domain_name, :segment_definition_name, :schedule_configuration) SENSITIVE = [] include Aws::Structure end |
#segment_definition_name ⇒ String
The unique name of the segment definition.
9080 9081 9082 9083 9084 9085 9086 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9080 class PutSegmentSubscriptionRequest < Struct.new( :domain_name, :segment_definition_name, :schedule_configuration) SENSITIVE = [] include Aws::Structure end |