Class: Aws::CustomerProfiles::Types::Range

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

The relative time period over which data is included in the aggregation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#timestamp_formatString

The format the timestamp field in your JSON object is specified. This value should be one of EPOCHMILLI (for Unix epoch timestamps with second/millisecond level precision) or ISO_8601 (following ISO_8601 format with second/millisecond level precision, with an optional offset of Z or in the format HH:MM or HHMM.). E.g. if your object type is MyType and source JSON is {“timestamp”: “2001-07-04T12:08:56.235-0700”}, then TimestampFormat should be “ISO_8601”.

Returns:

  • (String)


8152
8153
8154
8155
8156
8157
8158
8159
8160
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8152

class Range < Struct.new(
  :value,
  :unit,
  :value_range,
  :timestamp_source,
  :timestamp_format)
  SENSITIVE = []
  include Aws::Structure
end

#timestamp_sourceString

An expression specifying the field in your JSON object from which the date should be parsed. The expression should follow the structure of \“of timestamp field in JSON pointer format&gt;\”. E.g. if your object type is MyType and source JSON is {“timestamp”: “1737587945945”}, then TimestampSource should be “MyType.generatedAt.timestamp”.

Returns:

  • (String)


8152
8153
8154
8155
8156
8157
8158
8159
8160
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8152

class Range < Struct.new(
  :value,
  :unit,
  :value_range,
  :timestamp_source,
  :timestamp_format)
  SENSITIVE = []
  include Aws::Structure
end

#unitString

The unit of time.

Returns:

  • (String)


8152
8153
8154
8155
8156
8157
8158
8159
8160
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8152

class Range < Struct.new(
  :value,
  :unit,
  :value_range,
  :timestamp_source,
  :timestamp_format)
  SENSITIVE = []
  include Aws::Structure
end

#valueInteger

The amount of time of the specified unit.

Returns:

  • (Integer)


8152
8153
8154
8155
8156
8157
8158
8159
8160
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8152

class Range < Struct.new(
  :value,
  :unit,
  :value_range,
  :timestamp_source,
  :timestamp_format)
  SENSITIVE = []
  include Aws::Structure
end

#value_rangeTypes::ValueRange

A structure letting customers specify a relative time window over which over which data is included in the Calculated Attribute. Use positive numbers to indicate that the endpoint is in the past, and negative numbers to indicate it is in the future. ValueRange overrides Value.

Returns:



8152
8153
8154
8155
8156
8157
8158
8159
8160
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8152

class Range < Struct.new(
  :value,
  :unit,
  :value_range,
  :timestamp_source,
  :timestamp_format)
  SENSITIVE = []
  include Aws::Structure
end