Class: Aws::CustomerProfiles::Types::RecommenderConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Configuration settings that define the behavior and parameters of a recommender.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#diversity_configTypes::DiversityConfig

Configuration for diversity-aware recommendations. When set, the recommender applies diversity constraints defined per item column to reduce over-concentration of similar items in the results.



8928
8929
8930
8931
8932
8933
8934
8935
8936
8937
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8928

class RecommenderConfig < Struct.new(
  :events_config,
  :training_frequency,
  :inference_config,
  :included_columns,
  :excluded_columns,
  :diversity_config)
  SENSITIVE = []
  include Aws::Structure
end

#events_configTypes::EventsConfig

Configuration settings for how the recommender processes and uses events.

Returns:



8928
8929
8930
8931
8932
8933
8934
8935
8936
8937
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8928

class RecommenderConfig < Struct.new(
  :events_config,
  :training_frequency,
  :inference_config,
  :included_columns,
  :excluded_columns,
  :diversity_config)
  SENSITIVE = []
  include Aws::Structure
end

#excluded_columnsHash<String,Array<String>>

A map of dataset type to a list of column names to exclude from training. The _webAnalytics and _catalogItem keys are supported. The column names must be valid columns defined in the recommender schema. All columns in the schema except the listed columns will be used for training. The following columns are mandatory and cannot be excluded: Item.Id, EventTimestamp, and EventType for _webAnalytics; Id for _catalogItem. Mutually exclusive with IncludedColumns — both cannot be specified in the same request.

Returns:

  • (Hash<String,Array<String>>)


8928
8929
8930
8931
8932
8933
8934
8935
8936
8937
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8928

class RecommenderConfig < Struct.new(
  :events_config,
  :training_frequency,
  :inference_config,
  :included_columns,
  :excluded_columns,
  :diversity_config)
  SENSITIVE = []
  include Aws::Structure
end

#included_columnsHash<String,Array<String>>

A map of dataset type to a list of column names to train on. The _webAnalytics and _catalogItem keys are supported. The column names must be a subset of the columns defined in the recommender schema. If not specified, all columns in the schema are used for training. The following columns are always included in training and do not need to be specified: Item.Id, EventTimestamp, and EventType for _webAnalytics; Id for _catalogItem. Mutually exclusive with ExcludedColumns — both cannot be specified in the same request.

Returns:

  • (Hash<String,Array<String>>)


8928
8929
8930
8931
8932
8933
8934
8935
8936
8937
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8928

class RecommenderConfig < Struct.new(
  :events_config,
  :training_frequency,
  :inference_config,
  :included_columns,
  :excluded_columns,
  :diversity_config)
  SENSITIVE = []
  include Aws::Structure
end

#inference_configTypes::InferenceConfig

Configuration settings for how the recommender handles inference requests.



8928
8929
8930
8931
8932
8933
8934
8935
8936
8937
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8928

class RecommenderConfig < Struct.new(
  :events_config,
  :training_frequency,
  :inference_config,
  :included_columns,
  :excluded_columns,
  :diversity_config)
  SENSITIVE = []
  include Aws::Structure
end

#training_frequencyInteger

How often the recommender should retrain its model with new data. If set to 0, automatic retraining will not be enabled.

Returns:

  • (Integer)


8928
8929
8930
8931
8932
8933
8934
8935
8936
8937
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8928

class RecommenderConfig < Struct.new(
  :events_config,
  :training_frequency,
  :inference_config,
  :included_columns,
  :excluded_columns,
  :diversity_config)
  SENSITIVE = []
  include Aws::Structure
end