Class: Aws::CustomerProfiles::Types::RecommenderConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::RecommenderConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Configuration settings that define the behavior and parameters of a recommender.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events_config ⇒ Types::EventsConfig
Configuration settings for how the recommender processes and uses events.
-
#excluded_columns ⇒ Hash<String,Array<String>>
A map of dataset type to a list of column names to exclude from training.
-
#included_columns ⇒ Hash<String,Array<String>>
A map of dataset type to a list of column names to train on.
-
#inference_config ⇒ Types::InferenceConfig
Configuration settings for how the recommender handles inference requests.
-
#training_frequency ⇒ Integer
How often the recommender should retrain its model with new data.
Instance Attribute Details
#events_config ⇒ Types::EventsConfig
Configuration settings for how the recommender processes and uses events.
8838 8839 8840 8841 8842 8843 8844 8845 8846 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8838 class RecommenderConfig < Struct.new( :events_config, :training_frequency, :inference_config, :included_columns, :excluded_columns) SENSITIVE = [] include Aws::Structure end |
#excluded_columns ⇒ Hash<String,Array<String>>
A map of dataset type to a list of column names to exclude from training. The ‘_webAnalytics` and `_catalogItem` keys are supported. The column names must be valid columns defined in the recommender schema. All columns in the schema except the listed columns will be used for training. The following columns are mandatory and cannot be excluded: `Item.Id`, `EventTimestamp`, and `EventType` for `_webAnalytics`; `Id` for `_catalogItem`. Mutually exclusive with IncludedColumns — both cannot be specified in the same request.
8838 8839 8840 8841 8842 8843 8844 8845 8846 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8838 class RecommenderConfig < Struct.new( :events_config, :training_frequency, :inference_config, :included_columns, :excluded_columns) SENSITIVE = [] include Aws::Structure end |
#included_columns ⇒ Hash<String,Array<String>>
A map of dataset type to a list of column names to train on. The ‘_webAnalytics` and `_catalogItem` keys are supported. The column names must be a subset of the columns defined in the recommender schema. If not specified, all columns in the schema are used for training. The following columns are always included in training and do not need to be specified: `Item.Id`, `EventTimestamp`, and `EventType` for `_webAnalytics`; `Id` for `_catalogItem`. Mutually exclusive with ExcludedColumns — both cannot be specified in the same request.
8838 8839 8840 8841 8842 8843 8844 8845 8846 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8838 class RecommenderConfig < Struct.new( :events_config, :training_frequency, :inference_config, :included_columns, :excluded_columns) SENSITIVE = [] include Aws::Structure end |
#inference_config ⇒ Types::InferenceConfig
Configuration settings for how the recommender handles inference requests.
8838 8839 8840 8841 8842 8843 8844 8845 8846 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8838 class RecommenderConfig < Struct.new( :events_config, :training_frequency, :inference_config, :included_columns, :excluded_columns) SENSITIVE = [] include Aws::Structure end |
#training_frequency ⇒ Integer
How often the recommender should retrain its model with new data. If set to 0, automatic retraining will not be enabled.
8838 8839 8840 8841 8842 8843 8844 8845 8846 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8838 class RecommenderConfig < Struct.new( :events_config, :training_frequency, :inference_config, :included_columns, :excluded_columns) SENSITIVE = [] include Aws::Structure end |