Class: Aws::CustomerProfiles::Types::RecommenderConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Configuration settings that define the behavior and parameters of a recommender.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#events_configTypes::EventsConfig

Configuration settings for how the recommender processes and uses events.

Returns:



8720
8721
8722
8723
8724
8725
8726
8727
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8720

class RecommenderConfig < Struct.new(
  :events_config,
  :training_frequency,
  :inference_config,
  :included_columns)
  SENSITIVE = []
  include Aws::Structure
end

#included_columnsHash<String,Array<String>>

A map of dataset type to a list of column names to train on. The column names must be a subset of the columns defined in the recommender schema. If not specified, all columns in the schema are used for training. The following columns are always included and do not need to be specified: ‘Item.Id`, `ItemList[].Id`, `EventTimestamp`, `EventType`, and `EventValue`.

Returns:

  • (Hash<String,Array<String>>)


8720
8721
8722
8723
8724
8725
8726
8727
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8720

class RecommenderConfig < Struct.new(
  :events_config,
  :training_frequency,
  :inference_config,
  :included_columns)
  SENSITIVE = []
  include Aws::Structure
end

#inference_configTypes::InferenceConfig

Configuration settings for how the recommender handles inference requests.



8720
8721
8722
8723
8724
8725
8726
8727
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8720

class RecommenderConfig < Struct.new(
  :events_config,
  :training_frequency,
  :inference_config,
  :included_columns)
  SENSITIVE = []
  include Aws::Structure
end

#training_frequencyInteger

How often the recommender should retrain its model with new data.

Returns:

  • (Integer)


8720
8721
8722
8723
8724
8725
8726
8727
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8720

class RecommenderConfig < Struct.new(
  :events_config,
  :training_frequency,
  :inference_config,
  :included_columns)
  SENSITIVE = []
  include Aws::Structure
end