Class: Aws::CustomerProfiles::Types::RecommenderSchemaField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Defines a column in a recommender schema, including the target field name and optional feature and content type settings for training.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_typeString

The data type of the column value. Valid values are ‘String` and `Number`. The default value is `String`.

Returns:

  • (String)


8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8883

class RecommenderSchemaField < Struct.new(
  :target_field_name,
  :content_type,
  :feature_type)
  SENSITIVE = []
  include Aws::Structure
end

#feature_typeString

How the column is treated for model training. Valid values are ‘CATEGORICAL` and `TEXTUAL`.

Returns:

  • (String)


8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8883

class RecommenderSchemaField < Struct.new(
  :target_field_name,
  :content_type,
  :feature_type)
  SENSITIVE = []
  include Aws::Structure
end

#target_field_nameString

The name of the target field in the dataset, such as ‘Location.City` or `Attributes.MealTime`.

Returns:

  • (String)


8883
8884
8885
8886
8887
8888
8889
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8883

class RecommenderSchemaField < Struct.new(
  :target_field_name,
  :content_type,
  :feature_type)
  SENSITIVE = []
  include Aws::Structure
end