Class: Aws::CustomerProfiles::Types::RecommenderSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Provides a summary of a recommender’s configuration and current state.

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp when the recommender was created.

Returns:

  • (Time)


9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

A description of the recommender’s purpose and characteristics.

Returns:

  • (String)


9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#failure_reasonString

If the recommender is in a failed state, provides the reason for the failure.

Returns:

  • (String)


9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the recommender was edited.

Returns:

  • (Time)


9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#latest_recommender_updateTypes::RecommenderUpdate

Information about the most recent update performed on the recommender, including its status and timing.



9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recipe_nameString

The name of the recipe used by this recommender.

Returns:

  • (String)


9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_configTypes::RecommenderConfig

The configuration settings applied to this recommender.



9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_nameString

The name of the recommender.

Returns:

  • (String)


9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#recommender_schema_nameString

The name of the recommender schema associated with this recommender.

Returns:

  • (String)


9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#statusString

The current operational status of the recommender.

Returns:

  • (String)


9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9092

class RecommenderSummary < Struct.new(
  :recommender_name,
  :recipe_name,
  :recommender_schema_name,
  :recommender_config,
  :created_at,
  :description,
  :status,
  :last_updated_at,
  :tags,
  :failure_reason,
  :latest_recommender_update)
  SENSITIVE = [:description]
  include Aws::Structure
end