Class: Aws::CustomerProfiles::Types::RecommenderSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::RecommenderSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Provides a summary of a recommender’s configuration and current state.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the recommender was created.
-
#description ⇒ String
A description of the recommender’s purpose and characteristics.
-
#failure_reason ⇒ String
If the recommender is in a failed state, provides the reason for the failure.
-
#last_updated_at ⇒ Time
The timestamp of when the recommender was edited.
-
#latest_recommender_update ⇒ Types::RecommenderUpdate
Information about the most recent update performed on the recommender, including its status and timing.
-
#recipe_name ⇒ String
The name of the recipe used by this recommender.
-
#recommender_config ⇒ Types::RecommenderConfig
The configuration settings applied to this recommender.
-
#recommender_name ⇒ String
The name of the recommender.
-
#recommender_schema_name ⇒ String
The name of the recommender schema associated with this recommender.
-
#status ⇒ String
The current operational status of the recommender.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the recommender was created.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A description of the recommender’s purpose and characteristics.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |
#failure_reason ⇒ String
If the recommender is in a failed state, provides the reason for the failure.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the recommender was edited.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |
#latest_recommender_update ⇒ Types::RecommenderUpdate
Information about the most recent update performed on the recommender, including its status and timing.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |
#recipe_name ⇒ String
The name of the recipe used by this recommender.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |
#recommender_config ⇒ Types::RecommenderConfig
The configuration settings applied to this recommender.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |
#recommender_name ⇒ String
The name of the recommender.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |
#recommender_schema_name ⇒ String
The name of the recommender schema associated with this recommender.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
The current operational status of the recommender.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8973 class RecommenderSummary < Struct.new( :recommender_name, :recipe_name, :recommender_schema_name, :recommender_config, :created_at, :description, :status, :last_updated_at, :tags, :failure_reason, :latest_recommender_update) SENSITIVE = [:description] include Aws::Structure end |