Class: Aws::CustomerProfiles::Types::SalesforceSourceProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::SalesforceSourceProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
The properties that are applied when Salesforce is being used as a source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_dynamic_field_update ⇒ Boolean
The flag that enables dynamic fetching of new (recently added) fields in the Salesforce objects while running a flow.
-
#include_deleted_records ⇒ Boolean
Indicates whether Amazon AppFlow includes deleted files in the flow run.
-
#object ⇒ String
The object specified in the Salesforce flow source.
Instance Attribute Details
#enable_dynamic_field_update ⇒ Boolean
The flag that enables dynamic fetching of new (recently added) fields in the Salesforce objects while running a flow.
8647 8648 8649 8650 8651 8652 8653 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8647 class SalesforceSourceProperties < Struct.new( :object, :enable_dynamic_field_update, :include_deleted_records) SENSITIVE = [] include Aws::Structure end |
#include_deleted_records ⇒ Boolean
Indicates whether Amazon AppFlow includes deleted files in the flow run.
8647 8648 8649 8650 8651 8652 8653 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8647 class SalesforceSourceProperties < Struct.new( :object, :enable_dynamic_field_update, :include_deleted_records) SENSITIVE = [] include Aws::Structure end |
#object ⇒ String
The object specified in the Salesforce flow source.
8647 8648 8649 8650 8651 8652 8653 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8647 class SalesforceSourceProperties < Struct.new( :object, :enable_dynamic_field_update, :include_deleted_records) SENSITIVE = [] include Aws::Structure end |