Class: Aws::CustomerProfiles::Types::SearchProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::SearchProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_search_keys ⇒ Array<Types::AdditionalSearchKey>
A list of ‘AdditionalSearchKey` objects that are each searchable identifiers of a profile.
-
#domain_name ⇒ String
The unique name of the domain.
-
#key_name ⇒ String
A searchable identifier of a customer profile.
-
#logical_operator ⇒ String
Relationship between all specified search keys that will be used to search for profiles.
-
#max_results ⇒ Integer
The maximum number of objects returned per page.
-
#next_token ⇒ String
The pagination token from the previous SearchProfiles API call.
-
#values ⇒ Array<String>
A list of key values.
Instance Attribute Details
#additional_search_keys ⇒ Array<Types::AdditionalSearchKey>
A list of ‘AdditionalSearchKey` objects that are each searchable identifiers of a profile. Each `AdditionalSearchKey` object contains a `KeyName` and a list of `Values` associated with that specific key (i.e., a key-value(s) pair). These additional search keys will be used in conjunction with the `LogicalOperator` and the required `KeyName` and `Values` parameters to search for profiles that satisfy the search criteria.
8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8733 class SearchProfilesRequest < Struct.new( :next_token, :max_results, :domain_name, :key_name, :values, :additional_search_keys, :logical_operator) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8733 class SearchProfilesRequest < Struct.new( :next_token, :max_results, :domain_name, :key_name, :values, :additional_search_keys, :logical_operator) SENSITIVE = [] include Aws::Structure end |
#key_name ⇒ String
A searchable identifier of a customer profile. The predefined keys you can use to search include: _account, _profileId, _assetId, _caseId, _orderId, _fullName, _phone, _email, _ctrContactId, _marketoLeadId, _salesforceAccountId, _salesforceContactId, _salesforceAssetId, _zendeskUserId, _zendeskExternalId, _zendeskTicketId, _serviceNowSystemId, _serviceNowIncidentId, _segmentUserId, _shopifyCustomerId, _shopifyOrderId.
8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8733 class SearchProfilesRequest < Struct.new( :next_token, :max_results, :domain_name, :key_name, :values, :additional_search_keys, :logical_operator) SENSITIVE = [] include Aws::Structure end |
#logical_operator ⇒ String
Relationship between all specified search keys that will be used to search for profiles. This includes the required ‘KeyName` and `Values` parameters as well as any key-value(s) pairs specified in the `AdditionalSearchKeys` list.
This parameter influences which profiles will be returned in the response in the following manner:
-
‘AND` - The response only includes profiles that match all of the search keys.
-
‘OR` - The response includes profiles that match at least one of the search keys.
The ‘OR` relationship is the default behavior if this parameter is not included in the request.
8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8733 class SearchProfilesRequest < Struct.new( :next_token, :max_results, :domain_name, :key_name, :values, :additional_search_keys, :logical_operator) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of objects returned per page.
The default is 20 if this parameter is not included in the request.
8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8733 class SearchProfilesRequest < Struct.new( :next_token, :max_results, :domain_name, :key_name, :values, :additional_search_keys, :logical_operator) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token from the previous SearchProfiles API call.
8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8733 class SearchProfilesRequest < Struct.new( :next_token, :max_results, :domain_name, :key_name, :values, :additional_search_keys, :logical_operator) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
A list of key values.
8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 8733 class SearchProfilesRequest < Struct.new( :next_token, :max_results, :domain_name, :key_name, :values, :additional_search_keys, :logical_operator) SENSITIVE = [] include Aws::Structure end |