Class: Aws::CustomerProfiles::Types::SubscriptionEventItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::SubscriptionEventItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Represents a single segment membership event.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event ⇒ String
Whether the profile joined or left the segment.
-
#event_type ⇒ String
The type of event that triggered the membership change.
-
#profile_id ⇒ String
The unique identifier of a customer profile.
-
#updated_at ⇒ Time
The timestamp of when the membership change was detected.
Instance Attribute Details
#event ⇒ String
Whether the profile joined or left the segment. The following are valid values:
-
JOINED: The profile joined the segment.
-
LEFT: The profile left the segment.
10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10442 class SubscriptionEventItem < Struct.new( :profile_id, :updated_at, :event_type, :event) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
The type of event that triggered the membership change. The following are valid values:
-
LIVE: Real-time event triggered by a profile or calculated attribute change (Classic segments only).
-
SCHEDULE: Event generated during a scheduled execution.
10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10442 class SubscriptionEventItem < Struct.new( :profile_id, :updated_at, :event_type, :event) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier of a customer profile.
10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10442 class SubscriptionEventItem < Struct.new( :profile_id, :updated_at, :event_type, :event) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the membership change was detected.
10442 10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10442 class SubscriptionEventItem < Struct.new( :profile_id, :updated_at, :event_type, :event) SENSITIVE = [] include Aws::Structure end |