Class: Aws::CustomerProfiles::Types::TrainingMetrics
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::TrainingMetrics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Contains metrics and performance indicators from the training of a recommender model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metrics ⇒ Hash<String,Float>
A collection of performance metrics and statistics from the training process.
-
#recommender_version_name ⇒ String
The name of the recommender version that produced these training metrics.
-
#time ⇒ Time
The timestamp when these training metrics were recorded.
Instance Attribute Details
#metrics ⇒ Hash<String,Float>
A collection of performance metrics and statistics from the training process.
10562 10563 10564 10565 10566 10567 10568 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10562 class TrainingMetrics < Struct.new( :time, :metrics, :recommender_version_name) SENSITIVE = [] include Aws::Structure end |
#recommender_version_name ⇒ String
The name of the recommender version that produced these training metrics.
10562 10563 10564 10565 10566 10567 10568 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10562 class TrainingMetrics < Struct.new( :time, :metrics, :recommender_version_name) SENSITIVE = [] include Aws::Structure end |
#time ⇒ Time
The timestamp when these training metrics were recorded.
10562 10563 10564 10565 10566 10567 10568 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10562 class TrainingMetrics < Struct.new( :time, :metrics, :recommender_version_name) SENSITIVE = [] include Aws::Structure end |