Class: Aws::CustomerProfiles::Types::TrainingMetrics
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::TrainingMetrics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Contains metrics and performance indicators from the training of a recommender model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metrics ⇒ Hash<String,Float>
A collection of performance metrics and statistics from the training process.
-
#time ⇒ Time
The timestamp when these training metrics were recorded.
Instance Attribute Details
#metrics ⇒ Hash<String,Float>
A collection of performance metrics and statistics from the training process.
9175 9176 9177 9178 9179 9180 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9175 class TrainingMetrics < Struct.new( :time, :metrics) SENSITIVE = [] include Aws::Structure end |
#time ⇒ Time
The timestamp when these training metrics were recorded.
9175 9176 9177 9178 9179 9180 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9175 class TrainingMetrics < Struct.new( :time, :metrics) SENSITIVE = [] include Aws::Structure end |