Class: Aws::CustomerProfiles::Types::UpdateCalculatedAttributeDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::UpdateCalculatedAttributeDefinitionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :statistic, :conditions, :attribute_details]
Instance Attribute Summary collapse
-
#attribute_details ⇒ Types::AttributeDetails
The mathematical expression and a list of attribute items specified in that expression.
-
#calculated_attribute_name ⇒ String
The unique name of the calculated attribute.
-
#conditions ⇒ Types::Conditions
The conditions including range, object count, and threshold for the calculated attribute.
-
#created_at ⇒ Time
The timestamp of when the calculated attribute definition was created.
-
#description ⇒ String
The description of the calculated attribute.
-
#display_name ⇒ String
The display name of the calculated attribute.
-
#last_updated_at ⇒ Time
The timestamp of when the calculated attribute definition was most recently edited.
-
#readiness ⇒ Types::Readiness
Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.
-
#statistic ⇒ String
The aggregation operation to perform for the calculated attribute.
-
#status ⇒ String
Status of the Calculated Attribute creation (whether all historical data has been indexed.).
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#use_historical_data ⇒ Boolean
Whether historical data ingested before the Calculated Attribute was created should be included in calculations.
Instance Attribute Details
#attribute_details ⇒ Types::AttributeDetails
The mathematical expression and a list of attribute items specified in that expression.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#calculated_attribute_name ⇒ String
The unique name of the calculated attribute.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#conditions ⇒ Types::Conditions
The conditions including range, object count, and threshold for the calculated attribute.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the calculated attribute definition was created.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#description ⇒ String
The description of the calculated attribute.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#display_name ⇒ String
The display name of the calculated attribute.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the calculated attribute definition was most recently edited.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#readiness ⇒ Types::Readiness
Information indicating if the Calculated Attribute is ready for use by confirming all historical data has been processed and reflected.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#statistic ⇒ String
The aggregation operation to perform for the calculated attribute.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#status ⇒ String
Status of the Calculated Attribute creation (whether all historical data has been indexed.)
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |
#use_historical_data ⇒ Boolean
Whether historical data ingested before the Calculated Attribute was created should be included in calculations.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10214 class UpdateCalculatedAttributeDefinitionResponse < Struct.new( :calculated_attribute_name, :display_name, :description, :created_at, :last_updated_at, :statistic, :conditions, :attribute_details, :use_historical_data, :status, :readiness, :tags) SENSITIVE = [:description, :statistic, :conditions, :attribute_details] include Aws::Structure end |