Class: Aws::CustomerProfiles::Types::UpdateDomainLayoutRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::UpdateDomainLayoutRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :layout]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the layout.
-
#display_name ⇒ String
The display name of the layout.
-
#domain_name ⇒ String
The unique name of the domain.
-
#is_default ⇒ Boolean
If set to true for a layout, this layout will be used by default to view data.
-
#layout ⇒ String
A customizable layout that can be used to view data under a Customer Profiles domain.
-
#layout_definition_name ⇒ String
The unique name of the layout.
-
#layout_type ⇒ String
The type of layout that can be used to view data under a Customer Profiles domain.
Instance Attribute Details
#description ⇒ String
The description of the layout
9867 9868 9869 9870 9871 9872 9873 9874 9875 9876 9877 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9867 class UpdateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout) SENSITIVE = [:description, :layout] include Aws::Structure end |
#display_name ⇒ String
The display name of the layout
9867 9868 9869 9870 9871 9872 9873 9874 9875 9876 9877 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9867 class UpdateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout) SENSITIVE = [:description, :layout] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
9867 9868 9869 9870 9871 9872 9873 9874 9875 9876 9877 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9867 class UpdateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout) SENSITIVE = [:description, :layout] include Aws::Structure end |
#is_default ⇒ Boolean
If set to true for a layout, this layout will be used by default to view data. If set to false, then the layout will not be used by default, but it can be used to view data by explicitly selecting it in the console.
9867 9868 9869 9870 9871 9872 9873 9874 9875 9876 9877 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9867 class UpdateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout) SENSITIVE = [:description, :layout] include Aws::Structure end |
#layout ⇒ String
A customizable layout that can be used to view data under a Customer Profiles domain.
9867 9868 9869 9870 9871 9872 9873 9874 9875 9876 9877 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9867 class UpdateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout) SENSITIVE = [:description, :layout] include Aws::Structure end |
#layout_definition_name ⇒ String
The unique name of the layout.
9867 9868 9869 9870 9871 9872 9873 9874 9875 9876 9877 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9867 class UpdateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout) SENSITIVE = [:description, :layout] include Aws::Structure end |
#layout_type ⇒ String
The type of layout that can be used to view data under a Customer Profiles domain.
9867 9868 9869 9870 9871 9872 9873 9874 9875 9876 9877 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9867 class UpdateDomainLayoutRequest < Struct.new( :domain_name, :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout) SENSITIVE = [:description, :layout] include Aws::Structure end |