Class: Aws::CustomerProfiles::Types::UpdateDomainLayoutResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::UpdateDomainLayoutResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :layout]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the layout was created.
-
#description ⇒ String
The description of the layout.
-
#display_name ⇒ String
The display name of the layout.
-
#is_default ⇒ Boolean
If set to true for a layout, this layout will be used by default to view data.
-
#last_updated_at ⇒ Time
The timestamp of when the layout was most recently updated.
-
#layout ⇒ String
A customizable layout that can be used to view data under a Customer Profiles domain.
-
#layout_definition_name ⇒ String
The unique name of the layout.
-
#layout_type ⇒ String
The type of layout that can be used to view data under a Customer Profiles domain.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#version ⇒ String
The version used to create layout.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the layout was created.
10223 10224 10225 10226 10227 10228 10229 10230 10231 10232 10233 10234 10235 10236 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10223 class UpdateDomainLayoutResponse < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :version, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#description ⇒ String
The description of the layout
10223 10224 10225 10226 10227 10228 10229 10230 10231 10232 10233 10234 10235 10236 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10223 class UpdateDomainLayoutResponse < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :version, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#display_name ⇒ String
The display name of the layout
10223 10224 10225 10226 10227 10228 10229 10230 10231 10232 10233 10234 10235 10236 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10223 class UpdateDomainLayoutResponse < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :version, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#is_default ⇒ Boolean
If set to true for a layout, this layout will be used by default to view data. If set to false, then the layout will not be used by default, but it can be used to view data by explicitly selecting it in the console.
10223 10224 10225 10226 10227 10228 10229 10230 10231 10232 10233 10234 10235 10236 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10223 class UpdateDomainLayoutResponse < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :version, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the layout was most recently updated.
10223 10224 10225 10226 10227 10228 10229 10230 10231 10232 10233 10234 10235 10236 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10223 class UpdateDomainLayoutResponse < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :version, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#layout ⇒ String
A customizable layout that can be used to view data under a Customer Profiles domain.
10223 10224 10225 10226 10227 10228 10229 10230 10231 10232 10233 10234 10235 10236 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10223 class UpdateDomainLayoutResponse < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :version, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#layout_definition_name ⇒ String
The unique name of the layout.
10223 10224 10225 10226 10227 10228 10229 10230 10231 10232 10233 10234 10235 10236 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10223 class UpdateDomainLayoutResponse < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :version, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#layout_type ⇒ String
The type of layout that can be used to view data under a Customer Profiles domain.
10223 10224 10225 10226 10227 10228 10229 10230 10231 10232 10233 10234 10235 10236 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10223 class UpdateDomainLayoutResponse < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :version, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
10223 10224 10225 10226 10227 10228 10229 10230 10231 10232 10233 10234 10235 10236 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10223 class UpdateDomainLayoutResponse < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :version, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |
#version ⇒ String
The version used to create layout.
10223 10224 10225 10226 10227 10228 10229 10230 10231 10232 10233 10234 10235 10236 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10223 class UpdateDomainLayoutResponse < Struct.new( :layout_definition_name, :description, :display_name, :is_default, :layout_type, :layout, :version, :created_at, :last_updated_at, :tags) SENSITIVE = [:description, :layout] include Aws::Structure end |