Class: Aws::CustomerProfiles::Types::UpdateDomainLayoutResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-customerprofiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :layout]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the layout was created.

Returns:

  • (Time)


9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9927

class UpdateDomainLayoutResponse < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :version,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#descriptionString

The description of the layout

Returns:

  • (String)


9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9927

class UpdateDomainLayoutResponse < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :version,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#display_nameString

The display name of the layout

Returns:

  • (String)


9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9927

class UpdateDomainLayoutResponse < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :version,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#is_defaultBoolean

If set to true for a layout, this layout will be used by default to view data. If set to false, then the layout will not be used by default, but it can be used to view data by explicitly selecting it in the console.

Returns:

  • (Boolean)


9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9927

class UpdateDomainLayoutResponse < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :version,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the layout was most recently updated.

Returns:

  • (Time)


9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9927

class UpdateDomainLayoutResponse < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :version,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#layoutString

A customizable layout that can be used to view data under a Customer Profiles domain.

Returns:

  • (String)


9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9927

class UpdateDomainLayoutResponse < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :version,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#layout_definition_nameString

The unique name of the layout.

Returns:

  • (String)


9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9927

class UpdateDomainLayoutResponse < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :version,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#layout_typeString

The type of layout that can be used to view data under a Customer Profiles domain.

Returns:

  • (String)


9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9927

class UpdateDomainLayoutResponse < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :version,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9927

class UpdateDomainLayoutResponse < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :version,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end

#versionString

The version used to create layout.

Returns:

  • (String)


9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-customerprofiles/types.rb', line 9927

class UpdateDomainLayoutResponse < Struct.new(
  :layout_definition_name,
  :description,
  :display_name,
  :is_default,
  :layout_type,
  :layout,
  :version,
  :created_at,
  :last_updated_at,
  :tags)
  SENSITIVE = [:description, :layout]
  include Aws::Structure
end