Class: Aws::CustomerProfiles::Types::UpdateEventTriggerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CustomerProfiles::Types::UpdateEventTriggerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-customerprofiles/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :event_trigger_conditions]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the event trigger.
-
#domain_name ⇒ String
The unique name of the domain.
-
#event_trigger_conditions ⇒ Array<Types::EventTriggerCondition>
A list of conditions that determine when an event should trigger the destination.
-
#event_trigger_limits ⇒ Types::EventTriggerLimits
Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.
-
#event_trigger_name ⇒ String
The unique name of the event trigger.
-
#object_type_name ⇒ String
The unique name of the object type.
-
#segment_filter ⇒ String
The destination is triggered only for profiles that meet the criteria of a segment definition.
Instance Attribute Details
#description ⇒ String
The description of the event trigger.
10534 10535 10536 10537 10538 10539 10540 10541 10542 10543 10544 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10534 class UpdateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#domain_name ⇒ String
The unique name of the domain.
10534 10535 10536 10537 10538 10539 10540 10541 10542 10543 10544 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10534 class UpdateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#event_trigger_conditions ⇒ Array<Types::EventTriggerCondition>
A list of conditions that determine when an event should trigger the destination.
10534 10535 10536 10537 10538 10539 10540 10541 10542 10543 10544 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10534 class UpdateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#event_trigger_limits ⇒ Types::EventTriggerLimits
Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.
10534 10535 10536 10537 10538 10539 10540 10541 10542 10543 10544 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10534 class UpdateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#event_trigger_name ⇒ String
The unique name of the event trigger.
10534 10535 10536 10537 10538 10539 10540 10541 10542 10543 10544 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10534 class UpdateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#object_type_name ⇒ String
The unique name of the object type.
10534 10535 10536 10537 10538 10539 10540 10541 10542 10543 10544 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10534 class UpdateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |
#segment_filter ⇒ String
The destination is triggered only for profiles that meet the criteria of a segment definition.
10534 10535 10536 10537 10538 10539 10540 10541 10542 10543 10544 |
# File 'lib/aws-sdk-customerprofiles/types.rb', line 10534 class UpdateEventTriggerRequest < Struct.new( :domain_name, :event_trigger_name, :object_type_name, :description, :event_trigger_conditions, :segment_filter, :event_trigger_limits) SENSITIVE = [:description, :event_trigger_conditions] include Aws::Structure end |